@@ -19,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- *  $Id: rar-ext.c,v 1.10.2.4 2003/06/11 06:41:17 makeinu Exp $
+ *  $Id: rar-ext.c,v 1.13 2003/06/18 09:26:53 makeinu Exp $
  */
 
 #include <stdlib.h>
@@ -31,7 +31,7 @@
 #include "fileutil.h"
 #include "fr-archive.h"
 #include "fr-command.h"
-#include "image_info.h"
+#include "gimv_image_info.h"
 #include "gimv_plugin.h"
 #include "rar-ext.h"
 
@@ -49,7 +49,7 @@ GimvPluginInfo gimv_plugin_info =
 {
    if_version:    GIMV_PLUGIN_IF_VERSION,
    name:          N_("RAR archive support"),
-   version:       "0.1.0",
+   version:       "0.1.1",
    author:        N_("Takuro Ashie"),
    description:   NULL,
    get_implement: gimv_plugin_get_impl,
@@ -190,11 +190,11 @@ process_line (char *line, gpointer data)
          filename = name_field;
       }
 
-      rar_comm->fdata = image_info_get_with_archive (filename,
-                                                     FR_ARCHIVE (comm->archive),
-                                                     NULL);
+      rar_comm->fdata = gimv_image_info_get_with_archive (filename,
+                                                          FR_ARCHIVE (comm->archive),
+                                                          NULL);
    } else {
-      ImageInfo *fdata;
+      GimvImageInfo *fdata;
       struct stat *st;
       /*
         size_t size;
@@ -213,13 +213,13 @@ process_line (char *line, gpointer data)
       g_strfreev (fields);
 
       rar_comm->fdata
-         = image_info_get_with_archive (fdata->filename,
-                                        image_info_get_archive (fdata),
-                                        st);
+         = gimv_image_info_get_with_archive (fdata->filename,
+                                             gimv_image_info_get_archive (fdata),
+                                             st);
       g_free (st);
 
       if (*fdata->filename == 0)
-         image_info_unref (fdata);
+         gimv_image_info_unref (fdata);
       else
          comm->file_list = g_list_prepend (comm->file_list, fdata);
 
