@@ -19,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- *  $Id: tar-ext.c,v 1.11.2.7 2003/06/11 06:41:17 makeinu Exp $
+ *  $Id: tar-ext.c,v 1.14 2003/06/18 09:26:53 makeinu Exp $
  */
 
 #include <sys/types.h>
@@ -31,10 +31,10 @@
 
 #include "gimageview.h"
 
-#include "image_info.h"
 #include "fileutil.h"
 #include "fr-archive.h"
 #include "fr-command.h"
+#include "gimv_image_info.h"
 #include "gimv_plugin.h"
 #include "tar-ext.h"
 
@@ -85,7 +85,7 @@ GimvPluginInfo gimv_plugin_info =
 {
    if_version:    GIMV_PLUGIN_IF_VERSION,
    name:          N_("TAR archive support"),
-   version:       "0.1.0",
+   version:       "0.1.1",
    author:        N_("Takuro Ashie"),
    description:   NULL,
    get_implement: gimv_plugin_get_impl,
@@ -277,7 +277,7 @@ get_last_field (char *line)
 static void
 process_line (char *line, gpointer data)
 {
-   ImageInfo *fdata = NULL;
+   GimvImageInfo *fdata = NULL;
    FRCommand *comm = FR_COMMAND (data);
    char **fields;
    char *name_field;
@@ -311,13 +311,13 @@ process_line (char *line, gpointer data)
    }
 
    if (*filename && *comm->filename) {
-      fdata = image_info_get_with_archive (filename,
-                                           FR_ARCHIVE (comm->archive),
-                                           &st);
+      fdata = gimv_image_info_get_with_archive (filename,
+                                                FR_ARCHIVE (comm->archive),
+                                                &st);
    }
    if (fdata) {
       if (fields[1])
-         image_info_set_link (fdata, fields[1]);
+         gimv_image_info_set_link (fdata, fields[1]);
       comm->file_list = g_list_prepend (comm->file_list, fdata);
    }
 
