@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bmp.c,v 1.4.2.10 2003/05/13 11:25:53 makeinu Exp $
+ * $Id: bmp.c,v 1.8 2003/06/14 03:39:49 makeinu Exp $
  */
 
 /*
@@ -65,7 +65,7 @@ gboolean bmp_read_color_map (GimvIO *gio,
                              gint *grey);
 gboolean bmp_read_bitmasks  (GimvIO *gio,
                              BmpBitFields *bf);
-guchar  *bmp_read_image     (ImageLoader *loader,
+guchar  *bmp_read_image     (GimvImageLoader *loader,
                              gint len,
                              gint height,
                              guchar cmap[256][3],
@@ -77,7 +77,7 @@ guchar  *bmp_read_image     (ImageLoader *loader,
                              gint grey);
 
 
-static ImageLoaderPlugin gimv_bmp_loader[] =
+static GimvImageLoaderPlugin gimv_bmp_loader[] =
 {
    {
       if_version:    GIMV_IMAGE_LOADER_IF_VERSION,
@@ -126,7 +126,7 @@ GimvPluginInfo gimv_plugin_info =
 {
    if_version:    GIMV_PLUGIN_IF_VERSION,
    name:          N_("Windows Bitmap Image Loader"),
-   version:       "0.1.0",
+   version:       "0.1.1",
    author:        N_("Takuro Ashie"),
    description:   NULL,
    get_implement: gimv_plugin_get_impl,
@@ -214,7 +214,7 @@ bmp_get_header(GimvIO   *gio,
 }
 
 GimvImage *
-bmp_load (ImageLoader *loader, gpointer data)
+bmp_load (GimvImageLoader *loader, gpointer data)
 {
    GimvIO *gio;
    GimvImage *image;
@@ -229,9 +229,9 @@ bmp_load (ImageLoader *loader, gpointer data)
    guint bytes_read;
    gboolean has_alpha = FALSE;
 
-   g_return_val_if_fail (IS_IMAGE_LOADER (loader), NULL);
+   g_return_val_if_fail (GIMV_IS_IMAGE_LOADER (loader), NULL);
 
-   gio = image_loader_get_gio (loader);
+   gio = gimv_image_loader_get_gio (loader);
    if (!gio) return NULL;
 
    status = gimv_io_read (gio, buffer, 2, &bytes_read);
@@ -302,7 +302,7 @@ bmp_load (ImageLoader *loader, gpointer data)
       }
    }
 
-   if (!image_loader_progress_update (loader)) return NULL;
+   if (!gimv_image_loader_progress_update (loader)) return NULL;
 
    /* read image!! */
    dest = bmp_read_image(loader, cinfo.width, cinfo.height, ColorMap, &bf,
@@ -407,7 +407,7 @@ bmp_read_bitmasks (GimvIO *gio,
 
 /* FIXME!! Too long ;-P */
 guchar *
-bmp_read_image (ImageLoader *loader,
+bmp_read_image (GimvImageLoader *loader,
                 gint len,
                 gint height,
                 guchar cmap[256][3],
@@ -428,7 +428,7 @@ bmp_read_image (ImageLoader *loader,
    guint bytes_read, step = 65536;  /* 64kB */
    gulong total_bytes_read = 0;
 
-   gio = image_loader_get_gio (loader);
+   gio = gimv_image_loader_get_gio (loader);
    g_return_val_if_fail (gio, NULL);
 
    ypos = height - 1;	/* Bitmaps begin in the lower left corner */
@@ -483,7 +483,7 @@ bmp_read_image (ImageLoader *loader,
          bytes_count_tmp = total_bytes_read / step;
          if (bytes_count_tmp > bytes_count) {
             bytes_count = bytes_count_tmp;
-            if (!image_loader_progress_update (loader))
+            if (!gimv_image_loader_progress_update (loader))
                goto ERROR;
          }
 
@@ -514,7 +514,7 @@ bmp_read_image (ImageLoader *loader,
          bytes_count_tmp = total_bytes_read / step;
          if (bytes_count_tmp > bytes_count) {
             bytes_count = bytes_count_tmp;
-            if (!image_loader_progress_update (loader))
+            if (!gimv_image_loader_progress_update (loader))
                goto ERROR;
          }
 
@@ -542,7 +542,7 @@ bmp_read_image (ImageLoader *loader,
          bytes_count_tmp = total_bytes_read / step;
          if (bytes_count_tmp > bytes_count) {
             bytes_count = bytes_count_tmp;
-            if (!image_loader_progress_update (loader))
+            if (!gimv_image_loader_progress_update (loader))
                goto ERROR;
          }
 
@@ -588,7 +588,7 @@ bmp_read_image (ImageLoader *loader,
          bytes_count_tmp = total_bytes_read / step;
          if (bytes_count_tmp > bytes_count) {
             bytes_count = bytes_count_tmp;
-            if (!image_loader_progress_update (loader))
+            if (!gimv_image_loader_progress_update (loader))
                goto ERROR;
          }
 
@@ -615,7 +615,7 @@ bmp_read_image (ImageLoader *loader,
          bytes_count_tmp = total_bytes_read / step;
          if (bytes_count_tmp > bytes_count) {
             bytes_count = bytes_count_tmp;
-            if (!image_loader_progress_update (loader))
+            if (!gimv_image_loader_progress_update (loader))
                goto ERROR;
          }
 
@@ -649,7 +649,7 @@ bmp_read_image (ImageLoader *loader,
             bytes_count_tmp = total_bytes_read / step;
             if (bytes_count_tmp > bytes_count) {
                bytes_count = bytes_count_tmp;
-               if (!image_loader_progress_update (loader))
+               if (!gimv_image_loader_progress_update (loader))
                   goto ERROR;
             }
 
@@ -667,7 +667,7 @@ bmp_read_image (ImageLoader *loader,
             bytes_count_tmp = total_bytes_read / step;
             if (bytes_count_tmp > bytes_count) {
                bytes_count = bytes_count_tmp;
-               if (!image_loader_progress_update (loader))
+               if (!gimv_image_loader_progress_update (loader))
                   goto ERROR;
             }
 
@@ -699,7 +699,7 @@ bmp_read_image (ImageLoader *loader,
                   bytes_count_tmp = total_bytes_read / step;
                   if (bytes_count_tmp > bytes_count) {
                      bytes_count = bytes_count_tmp;
-                     if (!image_loader_progress_update (loader))
+                     if (!gimv_image_loader_progress_update (loader))
                         goto ERROR;
                   }
 
@@ -723,7 +723,7 @@ bmp_read_image (ImageLoader *loader,
                bytes_count_tmp = total_bytes_read / step;
                if (bytes_count_tmp > bytes_count) {
                   bytes_count = bytes_count_tmp;
-                  if (!image_loader_progress_update (loader))
+                  if (!gimv_image_loader_progress_update (loader))
                      goto ERROR;
                }
             }
