@@ -53,7 +53,7 @@
  */
 #undef HAVE_STDDEF_H
 #undef HAVE_STDLIB_H
-#include "image_loader.h"
+#include "gimv_image_loader.h"
 #include "gimv_mime_types.h"
 #include "gimv_plugin.h"
 
@@ -75,10 +75,10 @@ typedef struct
 } ErrorHandlerData;
 
 
-static GimvImage *jpeg_loader_load (ImageLoader *loader,
-                                    gpointer     data);
+static GimvImage *jpeg_loader_load (GimvImageLoader *loader,
+                                    gpointer         data);
 
-static ImageLoaderPlugin gimv_jpeg_loader[] =
+static GimvImageLoaderPlugin gimv_jpeg_loader[] =
 {
    {
       if_version:    GIMV_IMAGE_LOADER_IF_VERSION,
@@ -113,7 +113,7 @@ GimvPluginInfo gimv_plugin_info =
 {
    if_version:    GIMV_PLUGIN_IF_VERSION,
    name:          N_("JPEG Image Loader"),
-   version:       "0.0.1",
+   version:       "0.0.3",
    author:        N_("Takuro Ashie"),
    description:   NULL,
    get_implement: gimv_plugin_get_impl,
@@ -219,7 +219,7 @@ calculate_divisor (int width,
                    int target_width,
                    int target_height)
 {
-   if (target_width < 0 || target_width < 0) {
+   if (target_width < 0 || target_height < 0) {
       return 1;
    }
    if (width / 8 > target_width && height / 8 > target_height) {
@@ -269,7 +269,7 @@ convert_cmyk_to_rgb (struct jpeg_decompress_struct *cinfo,
 
 
 static GimvImage *
-jpeg_loader_load (ImageLoader *loader,
+jpeg_loader_load (GimvImageLoader *loader,
                   gpointer data)
 {
    struct jpeg_decompress_struct cinfo;
@@ -277,24 +277,32 @@ jpeg_loader_load (ImageLoader *loader,
    ErrorHandlerData jerr;
    GimvIO *gio;
    unsigned char *lines[1];
-   guchar *buffer;
-   guchar *pixels;
+   guchar *buffer = NULL;
+   guchar *pixels = NULL;
    guchar *ptr;
    int out_n_components;
    gboolean has_alpha;
    int target_width;
    int target_height;
-   gint bytes_count = 0, bytes_count_tmp = 0;
+   gboolean keep_aspect;
+   gint bytes_count, bytes_count_tmp = 0;
    guint step = 65536;
 
-   g_return_val_if_fail (IS_IMAGE_LOADER (loader), NULL);
+   static guchar *buffer_prv = NULL;
 
-   gio = image_loader_get_gio (loader);
+   g_return_val_if_fail (GIMV_IS_IMAGE_LOADER (loader), NULL);
+
+   gio = gimv_image_loader_get_gio (loader);
    if (!gio) return NULL;
 
-   if (!image_loader_get_size_request (loader, &target_width, &target_height)) {
+   if (!gimv_image_loader_get_size_request (loader,
+                                            &target_width,
+                                            &target_height,
+                                            &keep_aspect))
+   {
       target_width  = -1;
       target_height = -1;
+      keep_aspect   = TRUE;
    }
 
    cinfo.src = NULL;
@@ -302,12 +310,14 @@ jpeg_loader_load (ImageLoader *loader,
    jerr.pub.error_exit = fatal_error_handler;
    jerr.pub.output_message = output_message_handler;
 
-   buffer = NULL;
-   pixels = NULL;
+#warning FIXME!
    if (setjmp (jerr.setjmp_buffer)) {
       /* Handle a JPEG error. */
       jpeg_destroy_decompress (&cinfo);
-      g_free (buffer);
+      if(buffer != buffer_prv){
+         buffer_prv = buffer;
+         g_free (buffer);
+      }
       g_free (pixels);
       return NULL;
    }
@@ -321,10 +331,11 @@ jpeg_loader_load (ImageLoader *loader,
 
    /* set image info */
    if (loader->info) {
-      ImageInfoFlags flags = IMAGE_INFO_SYNCED_FLAG;
+      GimvImageInfoFlags flags = GIMV_IMAGE_INFO_SYNCED_FLAG;
 
-      image_info_set_size (loader->info, cinfo.image_width, cinfo.image_height);
-      image_info_set_flags (loader->info, flags);
+      gimv_image_info_set_size (loader->info,
+                                cinfo.image_width, cinfo.image_height);
+      gimv_image_info_set_flags (loader->info, flags);
    }
 
    cinfo.scale_num = 1;
@@ -333,7 +344,9 @@ jpeg_loader_load (ImageLoader *loader,
                                           target_width,
                                           target_height);
 
-   if (image_loader_get_load_type (loader) == IMAGE_LOADER_LOAD_THUMBNAIL) {
+   if (gimv_image_loader_get_load_type (loader)
+          == GIMV_IMAGE_LOADER_LOAD_THUMBNAIL)
+   {
       cinfo.dct_method = JDCT_FASTEST;
       cinfo.do_fancy_upsampling = FALSE;
    }
@@ -368,6 +381,8 @@ jpeg_loader_load (ImageLoader *loader,
       lines[0] = pixels;
    }
 
+   bytes_count = 0;
+
    while (cinfo.output_scanline < cinfo.output_height) {
       guint i;
 
@@ -376,7 +391,7 @@ jpeg_loader_load (ImageLoader *loader,
       bytes_count_tmp = ((Source *) cinfo.src)->bytes_read / step;
       if (bytes_count_tmp > bytes_count) {
          bytes_count = bytes_count_tmp;
-         if (!image_loader_progress_update (loader))
+         if (!gimv_image_loader_progress_update (loader))
             break;
       }
 
@@ -397,6 +412,7 @@ jpeg_loader_load (ImageLoader *loader,
       }
    }
 
+   buffer_prv = buffer;
    g_free (buffer);
    buffer = NULL;
 
