@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: svg.h,v 1.3.2.1 2002/11/14 13:25:24 makeinu Exp $
+ * $Id: svg.h,v 1.6 2003/06/14 03:39:50 makeinu Exp $
  */
 
 #ifndef __SVG_H__
@@ -31,10 +31,10 @@
 #ifdef ENABLE_SVG
 
 #include "gimv_image.h"
-#include "image_loader.h"
+#include "gimv_image_loader.h"
 
-GimvImage *svg_load_image (ImageLoader *loader,
-                           gpointer     data);
+GimvImage *svg_load_image (GimvImageLoader *loader,
+                           gpointer         data);
 
 #endif /* ENABLE_SVG */
 
