@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: xcf.c,v 1.5.2.7 2003/05/13 11:25:54 makeinu Exp $
+ * $Id: xcf.c,v 1.10 2003/07/20 14:38:10 makeinu Exp $
  */
 
 #include <stdio.h>
@@ -178,46 +178,46 @@ typedef struct
 } XcfImage;
 
 
-guint    xcf_read_int32              (GimvIO       *gio,
-                                      guint32      *data,
-                                      gint          count);
-guint    xcf_read_int8               (GimvIO       *gio,
-                                      guint8       *data,
-                                      gint          count);
-guint    xcf_read_string             (GimvIO       *gio,
-                                      gchar        *data);
-gboolean xcf_load_image              (ImageLoader  *loader,
-                                      XcfImage     *image);
-gboolean xcf_load_layer              (ImageLoader  *loader,
-                                      XcfImage     *image);
-gboolean xcf_load_channel            (ImageLoader  *loader,
-                                      XcfImage     *image);
-gboolean xcf_load_layer_mask         (ImageLoader  *loader,
-                                      XcfImage     *image,
-                                      XcfHierarchy *hierarchy);
-gboolean xcf_load_hierarchy	       (ImageLoader  *loader,
-                                      XcfImage     *image,
-                                      XcfHierarchy *hierarchy);
-gboolean xcf_load_level		          (ImageLoader  *loader,
-                                      XcfImage     *image,
-                                      XcfHierarchy *hierarchy);
-gboolean xcf_load_tile		          (ImageLoader  *loader,
-                                      XcfImage     *image,
-                                      XcfHierarchy *hierarchy);
-gboolean xcf_load_image_properties   (ImageLoader  *loader,
-                                      XcfImage     *image);
-gboolean xcf_load_layer_properties   (ImageLoader  *loader,
-                                      XcfLayer     *layer);
-gboolean xcf_load_channel_properties (ImageLoader  *loader,
-                                      XcfChannel   *channel);
-void     xcf_put_pixel_element	    (XcfImage     *image,
-                                      guchar       *line,
-                                      gint          x,
-                                      gint          off,
-                                      gint          ic);
+guint    xcf_read_int32              (GimvIO          *gio,
+                                      guint32         *data,
+                                      gint             count);
+guint    xcf_read_int8               (GimvIO          *gio,
+                                      guint8          *data,
+                                      gint             count);
+guint    xcf_read_string             (GimvIO          *gio,
+                                      gchar           *data);
+gboolean xcf_load_image              (GimvImageLoader *loader,
+                                      XcfImage        *image);
+gboolean xcf_load_layer              (GimvImageLoader *loader,
+                                      XcfImage        *image);
+gboolean xcf_load_channel            (GimvImageLoader *loader,
+                                      XcfImage        *image);
+gboolean xcf_load_layer_mask         (GimvImageLoader *loader,
+                                      XcfImage        *image,
+                                      XcfHierarchy    *hierarchy);
+gboolean xcf_load_hierarchy	       (GimvImageLoader *loader,
+                                      XcfImage        *image,
+                                      XcfHierarchy    *hierarchy);
+gboolean xcf_load_level		          (GimvImageLoader *loader,
+                                      XcfImage        *image,
+                                      XcfHierarchy    *hierarchy);
+gboolean xcf_load_tile		          (GimvImageLoader *loader,
+                                      XcfImage        *image,
+                                      XcfHierarchy    *hierarchy);
+gboolean xcf_load_image_properties   (GimvImageLoader *loader,
+                                      XcfImage        *image);
+gboolean xcf_load_layer_properties   (GimvImageLoader *loader,
+                                      XcfLayer        *layer);
+gboolean xcf_load_channel_properties (GimvImageLoader *loader,
+                                      XcfChannel      *channel);
+void     xcf_put_pixel_element	    (XcfImage        *image,
+                                      guchar          *line,
+                                      gint             x,
+                                      gint             off,
+                                      gint             ic);
 
 
-static ImageLoaderPlugin gimv_xcf_loader[] =
+static GimvImageLoaderPlugin gimv_xcf_loader[] =
 {
    {
       if_version:    GIMV_IMAGE_LOADER_IF_VERSION,
@@ -266,7 +266,7 @@ GimvPluginInfo gimv_plugin_info =
 {
    if_version:    GIMV_PLUGIN_IF_VERSION,
    name:          N_("XCF Image Loader"),
-   version:       "0.1.0",
+   version:       "0.1.1",
    author:        N_("Takuro Ashie"),
    description:   NULL,
    get_implement: gimv_plugin_get_impl,
@@ -331,7 +331,7 @@ xcf_get_header (GimvIO *gio, xcf_info *info)
 
 
 GimvImage *
-xcf_load (ImageLoader *loader, gpointer data)
+xcf_load (GimvImageLoader *loader, gpointer data)
 {
    GimvIO *gio;
    GimvImage *image = NULL;
@@ -340,7 +340,7 @@ xcf_load (ImageLoader *loader, gpointer data)
 
    g_return_val_if_fail (loader, NULL);
 
-   gio = image_loader_get_gio (loader);
+   gio = gimv_image_loader_get_gio (loader);
    if (!gio) return NULL;
 
    xcf_image.compression = COMPRESS_NONE;
@@ -360,7 +360,7 @@ xcf_load (ImageLoader *loader, gpointer data)
 
 
 gboolean
-xcf_load_image (ImageLoader *loader, XcfImage *image)
+xcf_load_image (GimvImageLoader *loader, XcfImage *image)
 {
    GimvIO *gio;
    guchar buf[10];
@@ -372,7 +372,7 @@ xcf_load_image (ImageLoader *loader, XcfImage *image)
    glong pos;
    gboolean success;
 
-   gio = image_loader_get_gio (loader);
+   gio = gimv_image_loader_get_gio (loader);
    g_return_val_if_fail (gio, FALSE);
 
    /* signature */
@@ -422,7 +422,7 @@ xcf_load_image (ImageLoader *loader, XcfImage *image)
             image->compression);
 #endif
 
-   if (!image_loader_progress_update (loader))
+   if (!gimv_image_loader_progress_update (loader))
       return FALSE;
 
    image->pixels = g_malloc (sizeof (guchar) * image->width * image->height * num_bytes);
@@ -474,7 +474,7 @@ ERROR:
 
 
 gboolean
-xcf_load_layer (ImageLoader *loader, XcfImage *image)
+xcf_load_layer (GimvImageLoader *loader, XcfImage *image)
 {
    GimvIO *gio;
    XcfHierarchy hierarchy;
@@ -487,7 +487,7 @@ xcf_load_layer (ImageLoader *loader, XcfImage *image)
    guchar name[256];
 #endif
 
-   gio = image_loader_get_gio (loader);
+   gio = gimv_image_loader_get_gio (loader);
    g_return_val_if_fail (gio, FALSE);
 
    layer.offset_x = 0;
@@ -499,7 +499,7 @@ xcf_load_layer (ImageLoader *loader, XcfImage *image)
    layer.apply_mask = 0;
    layer.edit_mask = 0;
    layer.show_mask = 0;
-   layer.mode = NORMAL_MODE;
+   layer.mode = GIMV_IMAGE_NORMAL_MODE;
 
    /* layer width, height, type */
    if (!xcf_read_int32(gio, &layer.width, 1)
@@ -596,7 +596,7 @@ xcf_load_layer (ImageLoader *loader, XcfImage *image)
 
 
 gboolean
-xcf_load_channel (ImageLoader *loader, XcfImage *image)
+xcf_load_channel (GimvImageLoader *loader, XcfImage *image)
 {
    GimvIO *gio;
    XcfHierarchy hierarchy;
@@ -609,7 +609,7 @@ xcf_load_channel (ImageLoader *loader, XcfImage *image)
    guchar name[256];
 #endif
 
-   gio = image_loader_get_gio (loader);
+   gio = gimv_image_loader_get_gio (loader);
    g_return_val_if_fail (gio, FALSE);
 
    channel.opacity = 255;
@@ -666,7 +666,7 @@ xcf_load_channel (ImageLoader *loader, XcfImage *image)
 
       gimv_image_add_layer (&hierarchy.data[i * channel.width * 4],
                             channel.width, 0, 4,
-                            image->pass, NORMAL_MODE, rgbbuffer);
+                            image->pass, GIMV_IMAGE_NORMAL_MODE, rgbbuffer);
    }
 
    image->pass++;
@@ -677,7 +677,7 @@ xcf_load_channel (ImageLoader *loader, XcfImage *image)
 
 
 gboolean
-xcf_load_layer_mask (ImageLoader *loader, XcfImage *image, XcfHierarchy *hierarchy)
+xcf_load_layer_mask (GimvImageLoader *loader, XcfImage *image, XcfHierarchy *hierarchy)
 {
    GimvIO *gio;
    guint32 width, height;
@@ -688,7 +688,7 @@ xcf_load_layer_mask (ImageLoader *loader, XcfImage *image, XcfHierarchy *hierarc
    guchar name[256];
 #endif
 
-   gio = image_loader_get_gio (loader);
+   gio = gimv_image_loader_get_gio (loader);
    g_return_val_if_fail (gio, FALSE);
 
    if (!xcf_read_int32 (gio, &width, 1)
@@ -718,13 +718,13 @@ xcf_load_layer_mask (ImageLoader *loader, XcfImage *image, XcfHierarchy *hierarc
 
 
 gboolean
-xcf_load_hierarchy (ImageLoader *loader, XcfImage *image, XcfHierarchy *hierarchy)
+xcf_load_hierarchy (GimvImageLoader *loader, XcfImage *image, XcfHierarchy *hierarchy)
 {
    GimvIO *gio;
    guint32 offset;
    glong pos;
 
-   gio = image_loader_get_gio (loader);
+   gio = gimv_image_loader_get_gio (loader);
    g_return_val_if_fail (gio, FALSE);
 
    /* hierarchy width, height, bpp(BYTEs Per Pixel) */
@@ -756,13 +756,13 @@ xcf_load_hierarchy (ImageLoader *loader, XcfImage *image, XcfHierarchy *hierarch
 
 
 gboolean
-xcf_load_level (ImageLoader *loader, XcfImage *image, XcfHierarchy *hierarchy)
+xcf_load_level (GimvImageLoader *loader, XcfImage *image, XcfHierarchy *hierarchy)
 {
    GimvIO *gio;
    guint32 offset;
    glong pos;
 
-   gio = image_loader_get_gio (loader);
+   gio = gimv_image_loader_get_gio (loader);
    g_return_val_if_fail (gio, FALSE);
 
    /* level width, height */
@@ -787,7 +787,7 @@ xcf_load_level (ImageLoader *loader, XcfImage *image, XcfHierarchy *hierarchy)
       gimv_io_seek (gio, pos, SEEK_SET);
       hierarchy->curtile++;
 
-      if (!image_loader_progress_update (loader))
+      if (!gimv_image_loader_progress_update (loader))
          return FALSE;
    }
 
@@ -796,7 +796,7 @@ xcf_load_level (ImageLoader *loader, XcfImage *image, XcfHierarchy *hierarchy)
 
 
 gboolean
-xcf_load_tile (ImageLoader *loader, XcfImage *image, XcfHierarchy *hierarchy)
+xcf_load_tile (GimvImageLoader *loader, XcfImage *image, XcfHierarchy *hierarchy)
 {
    GimvIO *gio;
    guint32 current, size, bpp, tile_height, tile_width;
@@ -806,7 +806,7 @@ xcf_load_tile (ImageLoader *loader, XcfImage *image, XcfHierarchy *hierarchy)
    gint rowi, columni;
    guchar *data;
 
-   gio = image_loader_get_gio (loader);
+   gio = gimv_image_loader_get_gio (loader);
    g_return_val_if_fail (gio, FALSE);
 
    ntile_rows = (hierarchy->level_height + TILE_HEIGHT - 1) / TILE_HEIGHT;
@@ -964,7 +964,7 @@ xcf_load_tile (ImageLoader *loader, XcfImage *image, XcfHierarchy *hierarchy)
 
 
 gboolean
-xcf_load_image_properties (ImageLoader *loader, XcfImage *image)
+xcf_load_image_properties (GimvImageLoader *loader, XcfImage *image)
 {
    GimvIO *gio;
    PropType prop_type;
@@ -972,7 +972,7 @@ xcf_load_image_properties (ImageLoader *loader, XcfImage *image)
    gint i, j;
    guint8 compression;
 
-   gio = image_loader_get_gio (loader);
+   gio = gimv_image_loader_get_gio (loader);
    g_return_val_if_fail (gio, FALSE);
 
    while (TRUE) {
@@ -1018,13 +1018,13 @@ xcf_load_image_properties (ImageLoader *loader, XcfImage *image)
 
 
 gboolean
-xcf_load_layer_properties (ImageLoader *loader, XcfLayer *layer)
+xcf_load_layer_properties (GimvImageLoader *loader, XcfLayer *layer)
 {
    GimvIO *gio;
    PropType prop_type;
    guint32 prop_size, dummy;
   
-   gio = image_loader_get_gio (loader);
+   gio = gimv_image_loader_get_gio (loader);
    g_return_val_if_fail (gio, FALSE);
 
    while (TRUE) {
@@ -1079,13 +1079,13 @@ xcf_load_layer_properties (ImageLoader *loader, XcfLayer *layer)
 
 
 gboolean
-xcf_load_channel_properties (ImageLoader *loader, XcfChannel *channel)
+xcf_load_channel_properties (GimvImageLoader *loader, XcfChannel *channel)
 {
    GimvIO *gio;
    PropType prop_type;
    guint32 prop_size;
 
-   gio = image_loader_get_gio (loader);
+   gio = gimv_image_loader_get_gio (loader);
    g_return_val_if_fail (gio, FALSE);
 
    while (TRUE) {
