@@ -766,6 +766,8 @@ gimv_mplayer_stop (GimvMPlayer *player)
    if (player->status == GimvMPlayerStatusPause)
       gimv_mplayer_toggle_pause (player);
 
+   gimv_mplayer_send_command (player, "q\n");
+   /* for old MPlayer */
    gimv_mplayer_send_command (player, "quit\n");
 
    waitpid (context->pid, NULL, WUNTRACED);
@@ -887,6 +889,8 @@ gimv_mplayer_set_file (GimvMPlayer *player,
       args = g_list_append (args, g_strdup ("null"));
       args = g_list_append (args, g_strdup ("-identify"));
       args = g_list_append (args, g_strdup (file));
+      args = g_list_append (args, g_strdup ("-frames"));
+      args = g_list_append (args, g_strdup ("0"));
       if (player->include_file && *player->include_file
           && !stat(player->include_file, &st))
       {
@@ -1540,7 +1544,7 @@ process_output (ChildContext *context)
    case EAGAIN:
       break;
    default:
-      g_warning ("GimvMPlayer: stderr: %s", strerror (errno));
+      /* g_warning ("GimvMPlayer: stderr: %s", strerror (errno)); */
       break;
    }
 
@@ -1572,7 +1576,7 @@ process_output (ChildContext *context)
          return TRUE;
       break;
    default:
-      g_warning ("GimvMPlayer: stdout: %s", strerror (errno));
+      /* g_warning ("GimvMPlayer: stdout: %s", strerror (errno)); */
       break;
    }
 
@@ -1660,9 +1664,7 @@ process_line (ChildContext *context,
    if (is_stderr) {
       /* fprintf (stderr, "%s\n", line); */
    } else {
-      if (!strcmp (line, "------ PAUSED -------") ||
-          !strcmp (line, "================= PAUSED ================="))
-      {
+      if (strstr (line, "PAUSE")) {
          player->status = GimvMPlayerStatusPause;
          gtk_signal_emit (GTK_OBJECT (player),
                           gimv_mplayer_signals[PAUSE_SIGNAL]);
