@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_xine.c,v 1.1.2.5 2003/05/21 09:13:06 makeinu Exp $
+ * $Id: gimv_xine.c,v 1.3 2003/06/15 16:14:52 makeinu Exp $
  *
  * the xine engine in a widget - implementation
  */
@@ -295,9 +295,9 @@ gimv_xine_destroy (GtkObject *object)
 #if defined(GDK_WINDOWING_X11)
 static void
 dest_size_cb (void *gxine_gen,
-				  int video_width, int video_height,
-				  double video_pixel_aspect,
-				  int *dest_width, int *dest_height,
+              int video_width, int video_height,
+              double video_pixel_aspect,
+              int *dest_width, int *dest_height,
               double *dest_pixel_aspect)
 {
    GimvXine *gxine = (GimvXine *) gxine_gen;
@@ -575,7 +575,8 @@ gimv_xine_realize (GtkWidget * widget)
    widget->window = gdk_window_foreign_new (priv->video_window);
 
    if (!XInitThreads ()) {
-      g_print ("gtkxine: XInitThreads failed - looks like you don't have a thread-safe xlib.\n");
+      g_print ("gtkxine: XInitThreads failed - "
+               "looks like you don't have a thread-safe xlib.\n");
       return;
    }
 
@@ -1336,7 +1337,7 @@ gimv_xine_config_register_string (GimvXine *gtx,
 
    return (gchar *) xine_config_register_string (priv->xine, key, def_value,
                                                  description, help,
-																 exp_level, changed_cb,
+                                                 exp_level, changed_cb,
                                                  cb_data);
 }
 
@@ -1360,8 +1361,8 @@ gimv_xine_config_register_range (GimvXine *gtx,
    g_return_val_if_fail (priv->xine, 0);
 
    return xine_config_register_range (priv->xine, key, def_value, min, max,
-												  description, help,
-												  exp_level, changed_cb, cb_data);
+                                      description, help,
+                                      exp_level, changed_cb, cb_data);
 }
 
 
@@ -1384,8 +1385,8 @@ gimv_xine_config_register_enum (GimvXine *gtx,
    g_return_val_if_fail (priv->xine, 0);
 
    return xine_config_register_enum (priv->xine, key, def_value, values,
-												 description, help,
-												 exp_level, changed_cb, cb_data);
+                                     description, help,
+                                     exp_level, changed_cb, cb_data);
 }
 
 
