@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: image_view_xine.c,v 1.1.2.8 2003/06/11 09:56:28 makeinu Exp $
+ * $Id: image_view_xine.c,v 1.6 2003/07/20 14:38:10 makeinu Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,21 +30,13 @@
 #include <stdlib.h>
 
 #include "gimv_image_view.h"
-#include "gimv_xine.h"
 #include "gimv_plugin.h"
+#include "gimv_thumb.h"
+#include "gimv_xine.h"
 #include "gtkutils.h"
 #include "prefs_xine.h"
-#include "thumbnail.h"
 
 /* callback functions */
-#ifndef GIMV_XINE_XINE1_API_IS_ENABLED
-static gint         idle_branched                    (gpointer   data);
-static void         cb_need_next_mrl                 (GimvXine  *gtx,
-                                                      gchar    **next_mrl_ret,
-                                                      GimvImageView *iv);
-static void         cb_branched                      (GimvXine  *gtx,
-                                                      GimvImageView *iv);
-#endif /* GIMV_XINE_XINE1_API_IS_ENABLED */
 static void         cb_playback_finished             (GimvXine  *gtx,
                                                       GimvImageView *iv);
 static void         cb_destroy                       (GtkWidget *widget,
@@ -63,13 +55,13 @@ static gboolean     imageview_xine_is_playing        (GimvImageView *iv);
 
 /* vertual functions */
 static gboolean     imageview_xine_is_supported      (GimvImageView *iv,
-                                                      ImageInfo *info);
+                                                      GimvImageInfo *info);
 static GtkWidget   *imageview_xine_create            (GimvImageView *iv);
 static void         imageview_xine_create_thumbnail  (GimvImageView *iv,
                                                       const gchar *type);
 
 static gboolean     imageview_xine_is_playable       (GimvImageView *iv,
-                                                      ImageInfo *info);
+                                                      GimvImageInfo *info);
 static gboolean     imageview_xine_is_seekable       (GimvImageView *iv);
 static guint        imageview_xine_get_position      (GimvImageView *iv);
 static guint        imageview_xine_get_length        (GimvImageView *iv);
@@ -244,7 +236,7 @@ GimvPluginInfo gimv_plugin_info =
 {
    if_version:    GIMV_PLUGIN_IF_VERSION,
    name:          N_("Xine Embeder"),
-   version:       "0.1.0",
+   version:       "0.1.1",
    author:        N_("Takuro Ashie"),
    description:   NULL,
    get_implement: gimv_plugin_get_impl,
@@ -277,77 +269,6 @@ gimv_xine_plugin_get_info (void)
  *   callback functions
  *
  *****************************************************************************/
-#ifndef GIMV_XINE_XINE1_API_IS_ENABLED
-static gint
-idle_branched (gpointer data)
-{
-   GimvImageView *iv = data;
-   gtk_signal_emit_by_name (GTK_OBJECT(iv), "image_changed");
-   return FALSE;
-}
-
-
-static void
-cb_branched (GimvXine *gtx, GimvImageView *iv)
-{
-   GList *node;
-   ImageInfo *info;
-
-   if (!iv->image_list) return;
-
-   node = iv->image_list->current;
-
-   g_return_if_fail (node);
-
-   info = node->data;
-   if (!info) return;
-   if (~info->flags & IMAGE_INFO_MRL_FLAG) return;
-
-   if (iv->info)
-      image_info_unref (iv->info);
-   iv->info = image_info_ref (info);
-
-   gtk_idle_add (idle_branched, iv);
-}
-
-
-static void
-cb_need_next_mrl (GimvXine *gtx, gchar **next_mrl_ret, GimvImageView *iv)
-{
-   GList *node, *current;
-   ImageInfo *info;
-   gchar *mrl;
-
-   g_return_if_fail (GIMV_IS_IMAGE_VIEW (iv));
-   g_return_if_fail (next_mrl_ret);
-
-   *next_mrl_ret = NULL;
-
-   if (!iv->image_list) return;
-   if (!iv->image_list->list || iv->image_list->owner != iv) return;
-
-   if (!iv->image_list->current)
-      current = iv->image_list->list;
-   else
-      current = iv->image_list->current;
-
-   node = g_list_next (current);
-   if (!node) return;
-
-   info = node->data;
-   if (!info) return;
-   if (~info->flags & IMAGE_INFO_MRL_FLAG) return;
-
-   iv->image_list->current = node;
-
-   mrl = (gchar *) image_info_get_path (info);
-   *next_mrl_ret = mrl;
-
-   gtk_signal_emit_by_name (GTK_OBJECT(iv), "image_changed");
-}
-#endif /* GIMV_XINE_XINE1_API_IS_ENABLED */
-
-
 static void
 cb_playback_finished (GimvXine *gtx, GimvImageView *iv)
 {
@@ -396,7 +317,7 @@ timeout_movie_status_listener (gpointer data)
 
    g_return_val_if_fail (iv, FALSE);
 
-   if (!iv->info || (!image_info_is_movie (iv->info) && !image_info_is_audio (iv->info))) {
+   if (!iv->info || (!gimv_image_info_is_movie (iv->info) && !gimv_image_info_is_audio (iv->info))) {
       if (movie_listener_id_table)
          g_hash_table_remove (movie_listener_id_table, iv);
       gimv_image_view_playable_set_status (iv, GimvImageViewPlayableStop);
@@ -513,19 +434,19 @@ imageview_xine_real_play (GimvImageView *iv, guint pos)
 
    g_return_if_fail (iv);
    if (!iv->info) return;
-   if (!image_info_is_movie (iv->info) && !image_info_is_audio (iv->info)) return;
+   if (!gimv_image_info_is_movie (iv->info) && !gimv_image_info_is_audio (iv->info)) return;
    g_return_if_fail (GTK_IS_BIN (iv->draw_area));
 
    gtx = GIMV_XINE (GTK_BIN (iv->draw_area)->child);
    if (!GIMV_IS_XINE (gtx)) return;
 
-   gimv_xine_set_mrl (gtx, image_info_get_path (iv->info));
+   gimv_xine_set_mrl (gtx, gimv_image_info_get_path (iv->info));
    gimv_xine_play (gtx, 0, pos);
 
-   filename = image_info_get_path_with_archive (iv->info);
-   cache_file = thumbnail_find_thumbcache (filename, NULL);
+   filename = gimv_image_info_get_path_with_archive (iv->info);
+   cache_file = gimv_thumb_find_thumbcache (filename, NULL);
 
-   if (!cache_file && !image_info_is_url (iv->info)) {
+   if (!cache_file && !gimv_image_info_is_url (iv->info)) {
       install_create_thumbnail_timer (iv);
    }
 
@@ -544,8 +465,8 @@ imageview_xine_is_playing (GimvImageView *iv)
 
    g_return_val_if_fail (iv, FALSE);
    g_return_val_if_fail (iv->info, FALSE);
-   g_return_val_if_fail (image_info_is_movie (iv->info)
-                         || image_info_is_audio (iv->info),
+   g_return_val_if_fail (gimv_image_info_is_movie (iv->info)
+                         || gimv_image_info_is_audio (iv->info),
                          FALSE);
    g_return_val_if_fail (GTK_IS_BIN (iv->draw_area), FALSE);
 
@@ -563,12 +484,12 @@ imageview_xine_is_playing (GimvImageView *iv)
  *
  *****************************************************************************/
 static gboolean
-imageview_xine_is_supported (GimvImageView *iv, ImageInfo *info)
+imageview_xine_is_supported (GimvImageView *iv, GimvImageInfo *info)
 {
    g_return_val_if_fail (GIMV_IS_IMAGE_VIEW (iv), FALSE);
    if (!info) return FALSE;
 
-   return image_info_is_movie (info) || image_info_is_audio (info);
+   return gimv_image_info_is_movie (info) || gimv_image_info_is_audio (info);
 }
 
 
@@ -590,12 +511,6 @@ imageview_xine_create (GimvImageView *iv)
    gtk_container_add (GTK_CONTAINER (widget), gxine);
    gtk_widget_show (gxine);
 
-#ifndef GIMV_XINE_XINE1_API_IS_ENABLED
-   gtk_signal_connect (GTK_OBJECT (gxine), "branched",
-                       GTK_SIGNAL_FUNC (cb_branched), iv);
-   gtk_signal_connect (GTK_OBJECT (gxine), "need_next_mrl",
-                       GTK_SIGNAL_FUNC (cb_need_next_mrl), iv);
-#endif /* GIMV_XINE_XINE1_API_IS_ENABLED */
    gtk_signal_connect (GTK_OBJECT (gxine), "playback_finished",
                        GTK_SIGNAL_FUNC (cb_playback_finished), iv);
    gtk_signal_connect (GTK_OBJECT (gxine), "destroy",
@@ -613,10 +528,9 @@ imageview_xine_create_thumbnail (GimvImageView *iv, const gchar *cache_write_typ
    gint width, height;
    guchar *rgb;
    GimvImage *image;
-   ThumbCacheSaveInfo *save_info;
    gchar *filename;
 
-   if (!image_info_is_movie (iv->info))
+   if (!gimv_image_info_is_movie (iv->info))
       return;
    if (!GTK_IS_BIN (iv->draw_area)) return;
 
@@ -635,15 +549,13 @@ imageview_xine_create_thumbnail (GimvImageView *iv, const gchar *cache_write_typ
       return;
    }
 
-   filename = image_info_get_path_with_archive (iv->info);
-   save_info = thumbsupport_save_info_new (iv->info, NULL);
+   filename = gimv_image_info_get_path_with_archive (iv->info);
 
-   imcache = thumbsupport_save_thumbnail_cache (filename,
-                                                cache_write_type,
-                                                image,
-                                                save_info);
+   imcache = gimv_thumb_cache_save (filename,
+                                    cache_write_type,
+                                    image,
+                                    iv->info);
 
-   thumbsupport_save_info_delete (save_info);
    g_free (filename);
    gimv_image_unref (image);
 
@@ -657,7 +569,7 @@ imageview_xine_create_thumbnail (GimvImageView *iv, const gchar *cache_write_typ
 
 
 static gboolean
-imageview_xine_is_playable (GimvImageView *iv, ImageInfo *info)
+imageview_xine_is_playable (GimvImageView *iv, GimvImageInfo *info)
 {
    return TRUE;
 }
@@ -698,7 +610,7 @@ imageview_xine_stop (GimvImageView *iv)
 
    g_return_if_fail (iv);
    if (!iv->info) return;
-   if (!image_info_is_movie (iv->info) && !image_info_is_audio (iv->info))
+   if (!gimv_image_info_is_movie (iv->info) && !gimv_image_info_is_audio (iv->info))
       return;
    g_return_if_fail (GTK_IS_BIN (iv->draw_area));
 
@@ -721,7 +633,7 @@ imageview_xine_pause (GimvImageView *iv)
 
    g_return_if_fail (iv);
    if (!iv->info) return;
-   if (!image_info_is_movie (iv->info) && !image_info_is_audio (iv->info))
+   if (!gimv_image_info_is_movie (iv->info) && !gimv_image_info_is_audio (iv->info))
       return;
    g_return_if_fail (GTK_IS_BIN (iv->draw_area));
 
@@ -741,7 +653,7 @@ imageview_xine_forward (GimvImageView *iv)
 
    g_return_if_fail (iv);
    if (!iv->info) return;
-   if (!image_info_is_movie (iv->info) && !image_info_is_audio (iv->info))
+   if (!gimv_image_info_is_movie (iv->info) && !gimv_image_info_is_audio (iv->info))
       return;
    g_return_if_fail (GTK_IS_BIN (iv->draw_area));
 
@@ -812,10 +724,10 @@ imageview_xine_eject (GimvImageView *iv)
 
    mrls = gimv_xine_get_autoplay_mrls (gtx, str, &num);
    for (i = 0; i < num; i++) {
-      ImageInfo *info;
-      info = image_info_get_url (mrls[i]);
-      info->flags |= IMAGE_INFO_MOVIE_FLAG;
-      info->flags |= IMAGE_INFO_MRL_FLAG;
+      GimvImageInfo *info;
+      info = gimv_image_info_get_url (mrls[i]);
+      info->flags |= GIMV_IMAGE_INFO_MOVIE_FLAG;
+      info->flags |= GIMV_IMAGE_INFO_MRL_FLAG;
       mrl_list = g_list_append (mrl_list, info);
    }
 
@@ -867,8 +779,8 @@ imageview_xine_get_position (GimvImageView *iv)
 
    g_return_val_if_fail (iv, 0);
    g_return_val_if_fail (iv->info, 0);
-   g_return_val_if_fail (image_info_is_movie (iv->info)
-                         || image_info_is_audio (iv->info),
+   g_return_val_if_fail (gimv_image_info_is_movie (iv->info)
+                         || gimv_image_info_is_audio (iv->info),
                          0);
    g_return_val_if_fail (GTK_IS_BIN (iv->draw_area), 0);
 
@@ -886,8 +798,8 @@ imageview_xine_get_length (GimvImageView *iv)
 
    g_return_val_if_fail (iv, 0);
    g_return_val_if_fail (iv->info, 0);
-   g_return_val_if_fail (image_info_is_movie (iv->info)
-                         || image_info_is_audio (iv->info),
+   g_return_val_if_fail (gimv_image_info_is_movie (iv->info)
+                         || gimv_image_info_is_audio (iv->info),
                          0);
    g_return_val_if_fail (GTK_IS_BIN (iv->draw_area), FALSE);
 
