@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: detailview.c,v 1.1.2.6 2003/05/13 11:25:56 makeinu Exp $
+ * $Id: detailview.c,v 1.4 2003/06/18 09:26:54 makeinu Exp $
  */
 
 #include "detailview.h"
@@ -30,10 +30,10 @@
 #include "detailview_priv.h"
 #include "detailview_prefs.h"
 #include "fileutil.h"
+#include "gimv_image_info.h"
+#include "gimv_thumb.h"
 #include "gimv_plugin.h"
-#include "thumbnail.h"
 #include "thumbnail_view.h"
-#include "image_info.h"
 
 static ThumbViewPlugin detailview_modes[] =
 {
@@ -98,7 +98,7 @@ GimvPluginInfo gimv_plugin_info =
 {
    if_version:    GIMV_PLUGIN_IF_VERSION,
    name:          N_("Thumbnail View Detail Mode"),
-   version:       "0.0.1",
+   version:       "0.0.2",
    author:        N_("Takuro Ashie"),
    description:   NULL,
    get_implement: gimv_plugin_get_impl,
@@ -108,17 +108,17 @@ GimvPluginInfo gimv_plugin_info =
 
 
 /* for setting clist text data */
-static gchar *column_data_filename   (Thumbnail *thumb);
-static gchar *column_data_image_size (Thumbnail *thumb);
-static gchar *column_data_size       (Thumbnail *thumb);
-static gchar *column_data_type       (Thumbnail *thumb);
-static gchar *column_data_atime      (Thumbnail *thumb);
-static gchar *column_data_mtime      (Thumbnail *thumb);
-static gchar *column_data_ctime      (Thumbnail *thumb);
-static gchar *column_data_uid        (Thumbnail *thumb);
-static gchar *column_data_gid        (Thumbnail *thumb);
-static gchar *column_data_mode       (Thumbnail *thumb);
-static gchar *column_data_cache      (Thumbnail *thumb);
+static gchar *column_data_filename   (GimvThumb *thumb);
+static gchar *column_data_image_size (GimvThumb *thumb);
+static gchar *column_data_size       (GimvThumb *thumb);
+static gchar *column_data_type       (GimvThumb *thumb);
+static gchar *column_data_atime      (GimvThumb *thumb);
+static gchar *column_data_mtime      (GimvThumb *thumb);
+static gchar *column_data_ctime      (GimvThumb *thumb);
+static gchar *column_data_uid        (GimvThumb *thumb);
+static gchar *column_data_gid        (GimvThumb *thumb);
+static gchar *column_data_mode       (GimvThumb *thumb);
+static gchar *column_data_cache      (GimvThumb *thumb);
 
 
 DetailViewColumn detailview_columns [] =
@@ -152,10 +152,10 @@ gint   detailview_title_idx_list_num = 0;
 #ifndef ENABLE_TREEVIEW
 
 #include "dnd.h"
-#include "gtk2-compat.h"
 #include "gimv_image.h"
-#include "thumbnail.h"
-#include "thumbnail_window.h"
+#include "gimv_thumb.h"
+#include "gimv_thumb_win.h"
+#include "gtk2-compat.h"
 
 typedef struct DetailViewData_Tag
 {
@@ -305,7 +305,7 @@ detailview_apply_config (void)
  *
  ******************************************************************************/
 static gchar *
-column_data_filename (Thumbnail *thumb)
+column_data_filename (GimvThumb *thumb)
 {
    ThumbView *tv;
 
@@ -324,9 +324,9 @@ column_data_filename (Thumbnail *thumb)
       gchar *retval;
 
       if (tv->mode == THUMB_VIEW_MODE_DIR)
-         filename = g_basename (image_info_get_path (thumb->info));
+         filename = g_basename (gimv_image_info_get_path (thumb->info));
       else
-         filename = image_info_get_path (thumb->info);
+         filename = gimv_image_info_get_path (thumb->info);
 
       retval = gimv_filename_to_internal (filename);
 
@@ -336,7 +336,7 @@ column_data_filename (Thumbnail *thumb)
 
 
 static gchar *
-column_data_image_size (Thumbnail *thumb)
+column_data_image_size (GimvThumb *thumb)
 {
    if (!thumb) return NULL;
 
@@ -349,7 +349,7 @@ column_data_image_size (Thumbnail *thumb)
 
 
 static gchar *
-column_data_size (Thumbnail *thumb)
+column_data_size (GimvThumb *thumb)
 {
    if (!thumb) return NULL;
 
@@ -358,7 +358,7 @@ column_data_size (Thumbnail *thumb)
 
 
 static gchar *
-column_data_type (Thumbnail *thumb)
+column_data_type (GimvThumb *thumb)
 {
    if (!thumb) return NULL;
 
@@ -367,7 +367,7 @@ column_data_type (Thumbnail *thumb)
 
 
 static gchar *
-column_data_atime (Thumbnail *thumb)
+column_data_atime (GimvThumb *thumb)
 {
    if (!thumb) return NULL;
 
@@ -376,7 +376,7 @@ column_data_atime (Thumbnail *thumb)
 
 
 static gchar *
-column_data_mtime (Thumbnail *thumb)
+column_data_mtime (GimvThumb *thumb)
 {
    if (!thumb) return NULL;
 
@@ -385,7 +385,7 @@ column_data_mtime (Thumbnail *thumb)
 
 
 static gchar *
-column_data_ctime (Thumbnail *thumb)
+column_data_ctime (GimvThumb *thumb)
 {
    if (!thumb) return NULL;
 
@@ -394,7 +394,7 @@ column_data_ctime (Thumbnail *thumb)
 
 
 static gchar *
-column_data_uid (Thumbnail *thumb)
+column_data_uid (GimvThumb *thumb)
 {
    if (!thumb) return NULL;
 
@@ -403,7 +403,7 @@ column_data_uid (Thumbnail *thumb)
 
 
 static gchar *
-column_data_gid (Thumbnail *thumb)
+column_data_gid (GimvThumb *thumb)
 {
    if (!thumb) return NULL;
 
@@ -412,7 +412,7 @@ column_data_gid (Thumbnail *thumb)
 
 
 static gchar *
-column_data_mode (Thumbnail *thumb)
+column_data_mode (GimvThumb *thumb)
 {
    if (!thumb) return NULL;
 
@@ -421,13 +421,13 @@ column_data_mode (Thumbnail *thumb)
 
 
 static gchar *
-column_data_cache (Thumbnail *thumb)
+column_data_cache (GimvThumb *thumb)
 {
    gchar *cache_type;
 
    if (!thumb) return NULL;
 
-   cache_type = thumbnail_get_cache_type (thumb);
+   cache_type = gimv_thumb_get_cache_type (thumb);
 
    return cache_type;
 }
@@ -450,7 +450,7 @@ cb_clist_key_press (GtkWidget *widget,
                     GdkEventKey *event,
                     ThumbView *tv)
 {
-   Thumbnail *thumb = NULL;
+   GimvThumb *thumb = NULL;
 
    g_return_val_if_fail (tv, FALSE);
 
@@ -502,7 +502,7 @@ cb_clist_button_press (GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
    ThumbView *tv = data;
    gint row;
-   Thumbnail *thumb;
+   GimvThumb *thumb;
    gboolean clear = TRUE, found = FALSE, success;
 
    detailview_dragging = FALSE;
@@ -561,7 +561,7 @@ cb_clist_button_release (GtkWidget *widget, GdkEventButton *event, gpointer data
 {
    ThumbView *tv = data;
    gint row;
-   Thumbnail *thumb;
+   GimvThumb *thumb;
    gboolean success;
 
    if (!tv) goto ERROR;
@@ -611,7 +611,7 @@ cb_clist_motion_notify (GtkWidget *widget, GdkEventMotion *event, gpointer data)
 {
    ThumbView *tv = data;
    gint row, on_row;
-   Thumbnail *thumb = NULL;
+   GimvThumb *thumb = NULL;
 
    detailview_dragging = TRUE;
 
@@ -630,7 +630,7 @@ cb_clist_motion_notify (GtkWidget *widget, GdkEventMotion *event, gpointer data)
 static void
 cb_click_column(GtkWidget *widget, gint col, ThumbView *tv)
 {
-   ThumbWindow *tw;
+   GimvThumbWin *tw;
    GtkWidget *sort_item;
    GList *node;
    gint idx;
@@ -686,7 +686,7 @@ cb_select_row (GtkCList *clist, gint row, gint column,
                GdkEventButton *event, gpointer user_data)
 {
    ThumbView *tv = user_data;
-   Thumbnail *thumb;
+   GimvThumb *thumb;
    GList *node;
 
    g_return_if_fail (tv);
@@ -706,7 +706,7 @@ cb_unselect_row (GtkCList *clist, gint row, gint column,
                  GdkEventButton *event, gpointer user_data)
 {
    ThumbView *tv = user_data;
-   Thumbnail *thumb;
+   GimvThumb *thumb;
    GList *node;
 
    g_return_if_fail (tv);
@@ -728,7 +728,7 @@ cb_drag_motion (GtkWidget *clist, GdkDragContext *context,
 {
    ThumbView *tv = data;
    DetailViewData *tv_data;
-   Thumbnail *thumb;
+   GimvThumb *thumb;
    gint row, on_row;
 
    g_return_if_fail (tv);
@@ -744,7 +744,7 @@ cb_drag_motion (GtkWidget *clist, GdkDragContext *context,
    if (!tv_data) return;
 
    /* hilight row under cursor */
-   if (thumb && thumbnail_is_dir (thumb) && tv_data->hilit_dir != row) {
+   if (thumb && gimv_thumb_is_dir (thumb) && tv_data->hilit_dir != row) {
       if (tv_data->hilit_dir != -1) {
          gtk_clist_set_foreground (GTK_CLIST (clist), tv_data->hilit_dir,
                                    &(clist->style->fg[GTK_STATE_NORMAL]));
@@ -792,7 +792,7 @@ cb_drag_data_received (GtkWidget *clist,
 {
 #if 0
    ThumbView *tv = data;
-   Thumbnail *thumb;
+   GimvThumb *thumb;
    gint row, on_row;
 
    g_return_if_fail (tv);
@@ -804,8 +804,8 @@ cb_drag_data_received (GtkWidget *clist,
    thumb = gtk_clist_get_row_data (GTK_CLIST (clist), row);
    if (!thumb) return;
 
-   if (thumbnail_is_dir (thumb))
-      tv->dnd_destdir = thumbnail_get_image_name (thumb);
+   if (gimv_thumb_is_dir (thumb))
+      tv->dnd_destdir = gimv_thumb_get_image_name (thumb);
 #endif
 
    thumbview_drag_data_received_cb (clist, context, x, y,
@@ -847,7 +847,7 @@ detailview_new (ThumbView *tv)
 static void
 detailview_set_text_data (ThumbView *tv, gchar *dest_mode, GList *start)
 {
-   Thumbnail *thumb;
+   GimvThumb *thumb;
    DetailViewData *tv_data;
    GList *node, *data_node;
    gint i, j, start_pos, num, colnum;
@@ -909,7 +909,7 @@ detailview_set_text_data (ThumbView *tv, gchar *dest_mode, GList *start)
 static void
 detailview_set_pixmaps (ThumbView *tv, gchar *dest_mode)
 {
-   Thumbnail *thumb;
+   GimvThumb *thumb;
    GList *node;
    gint i, num;
 
@@ -1009,7 +1009,7 @@ idle_reset_page_pos (gpointer data)
 /*
  *  detailview_remove_thumbview_data:
  *
- *  thumb : Pointer to the Thumbnail struct.
+ *  thumb : Pointer to the GimvThumb struct.
  */
 void
 detailview_remove_thumbview_data (ThumbView *tv)
@@ -1040,7 +1040,7 @@ detailview_append_thumb_frames (ThumbView *tv, GList *start, gchar *dest_mode)
 
 
 GtkWidget *
-detailview_add_thumbnail (Thumbnail *thumb,
+detailview_add_thumbnail (GimvThumb *thumb,
                           gchar *dest_mode,
                           ThumbLoadType type)
 {
@@ -1065,16 +1065,16 @@ detailview_add_thumbnail (Thumbnail *thumb,
    col = 0;
 
    /*
-   thumbnail = thumbnail_get_thumb (thumb);
+   thumbnail = gimv_thumb_get_thumb (thumb);
    if (!thumbnail)
       thumbnail = create_thumbnail_auto (thumb, tv->ThumbnailSize, type);
    */
 
    /* set thumbnail */
    if (!strcmp (DETAIL_ICON_LABEL, dest_mode)) {
-      thumbnail_get_icon (thumb, &pixmap, &mask);
+      gimv_thumb_get_icon (thumb, &pixmap, &mask);
    } else if (!strcmp (DETAIL_THUMB_LABEL, dest_mode)) {
-      thumbnail_get_thumb (thumb, &pixmap, &mask);
+      gimv_thumb_get_thumb (thumb, &pixmap, &mask);
    }
 
    if (!pixmap) return NULL;
@@ -1145,11 +1145,11 @@ detailview_redraw (ThumbView *tv, gchar *dest_mode,
    *loadlist = NULL;
    node = tv->thumblist;
    while (node) {
-      Thumbnail *thumb = node->data;
+      GimvThumb *thumb = node->data;
       GdkPixmap *pixmap = NULL;
       GdkBitmap *mask = NULL;
 
-      thumbnail_get_thumb (thumb, &pixmap, &mask);
+      gimv_thumb_get_thumb (thumb, &pixmap, &mask);
       if (!pixmap)
          *loadlist = g_list_append (*loadlist, thumb);
 
@@ -1159,7 +1159,7 @@ detailview_redraw (ThumbView *tv, gchar *dest_mode,
 
 
 gboolean
-detailview_refresh_thumbnail (Thumbnail *thumb, ThumbLoadType type)
+detailview_refresh_thumbnail (GimvThumb *thumb, ThumbLoadType type)
 {
    GtkWidget *widget;
    ThumbView *tv;
@@ -1179,7 +1179,7 @@ detailview_refresh_thumbnail (Thumbnail *thumb, ThumbLoadType type)
 
 
 void
-detailview_adjust (ThumbView *tv, Thumbnail *thumb)
+detailview_adjust (ThumbView *tv, GimvThumb *thumb)
 {
    DetailViewData *tv_data;
    GList *node;
@@ -1202,7 +1202,7 @@ detailview_adjust (ThumbView *tv, Thumbnail *thumb)
 
 
 gboolean
-detailview_set_selection (Thumbnail *thumb, gboolean select)
+detailview_set_selection (GimvThumb *thumb, gboolean select)
 {
    ThumbView *tv;
    DetailViewData *tv_data;
@@ -1232,7 +1232,7 @@ detailview_set_selection (Thumbnail *thumb, gboolean select)
 
 
 void
-detailview_set_focus (ThumbView *tv, Thumbnail *thumb)
+detailview_set_focus (ThumbView *tv, GimvThumb *thumb)
 {
    DetailViewData *tv_data;
    gint pos;
@@ -1257,7 +1257,7 @@ detailview_set_focus (ThumbView *tv, Thumbnail *thumb)
 }
 
 
-Thumbnail *
+GimvThumb *
 detailview_get_focus (ThumbView *tv)
 {
    DetailViewData *tv_data;
@@ -1285,7 +1285,7 @@ detailview_get_focus (ThumbView *tv)
 
 #define CELL_SPACING 1
 gboolean
-detailview_thumbnail_is_in_viewport (ThumbView *tv, Thumbnail *thumb)
+detailview_thumbnail_is_in_viewport (ThumbView *tv, GimvThumb *thumb)
 {
    DetailViewData *tv_data;
    GList *node;
