@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: detailview2.c,v 1.1.2.4 2003/05/12 13:00:31 makeinu Exp $
+ * $Id: detailview2.c,v 1.5 2003/07/06 16:46:20 makeinu Exp $
  */
 
 #ifndef GTK_DISABLE_DEPRECATED
@@ -38,14 +38,14 @@
 
 #include "charset.h"
 #include "dnd.h"
-#include "gtk2-compat.h"
-#include "fileutil.h"
-#include "gimv_image.h"
-#include "thumbnail.h"
 #include "detailview_prefs.h"
 #include "detailview_priv.h"
-#include "thumbnail_window.h"
-#include "gimv_cellrendererpixmap.h"
+#include "fileutil.h"
+#include "gimv_cell_pixmap.h"
+#include "gimv_image.h"
+#include "gimv_thumb.h"
+#include "gimv_thumb_win.h"
+#include "gtk2-compat.h"
 
 
 enum {
@@ -119,7 +119,7 @@ cb_tree_selected (GtkTreeSelection *selection, GtkTreeModel *model,
 {
    DetailViewData *tv_data;
    ThumbView *tv = data;
-   Thumbnail *thumb = NULL;
+   GimvThumb *thumb = NULL;
    GtkTreeIter iter;
    gint sel_row_pos = 0;
    gboolean success;
@@ -187,7 +187,7 @@ cb_treeview_key_press (GtkWidget *widget,
                        ThumbView *tv)
 {
    DetailViewData *tv_data;
-   Thumbnail *thumb = NULL;
+   GimvThumb *thumb = NULL;
    GtkTreePath *treepath;
 
    g_return_val_if_fail (tv, FALSE);
@@ -259,7 +259,7 @@ cb_treeview_button_press (GtkWidget *widget,
    GtkTreeIter iter;
    GtkTreePath *treepath;
    GtkTreeViewColumn *column;
-   Thumbnail *thumb = NULL;
+   GimvThumb *thumb = NULL;
    gboolean success, retval1 = FALSE, retval2 = FALSE;
 
    tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
@@ -315,7 +315,7 @@ cb_treeview_motion_notify (GtkWidget *widget,
    GtkTreeSelection *selection;
    GtkTreePath *treepath;
    GtkTreeViewColumn *column;
-   Thumbnail *thumb = NULL;
+   GimvThumb *thumb = NULL;
    gboolean success;
    gint dx, dy;
 
@@ -363,7 +363,7 @@ cb_treeview_button_release (GtkWidget *widget,
    GtkTreeIter iter;
    GtkTreePath *treepath;
    GtkTreeViewColumn *column;
-   Thumbnail *thumb = NULL;
+   GimvThumb *thumb = NULL;
    gboolean success, retval1 = FALSE, retval2 = FALSE;
 
    tv_data = g_hash_table_lookup (tv->disp_mode_data, DETAIL_VIEW_LABEL);
@@ -442,12 +442,12 @@ cb_treeview_drag_data_received (GtkWidget *widget,
 static void
 cb_column_clicked (GtkTreeViewColumn *column, ThumbView *tv)
 {
-   ThumbWindow *tw;
+   GimvThumbWin *tw;
    DetailViewData *tv_data;
    GList *col_list, *node;
    gint col, idx;
-   SortItem sort_item, current_item;
-   SortFlag sort_flag = 0, current_flag;
+   GimvSortItem sort_item, current_item;
+   GimvSortFlag sort_flag = 0, current_flag;
 
    if (!tv || tv->progress) return;
 
@@ -467,37 +467,38 @@ cb_column_clicked (GtkTreeViewColumn *column, ThumbView *tv)
 
    switch (idx) {
    case 1:
-      sort_item = SORT_NAME;
+      sort_item = GIMV_SORT_NAME;
       break;
    case 2:
-      sort_item = SORT_SIZE;
+      sort_item = GIMV_SORT_SIZE;
       break;
    case 3:
-      sort_item = SORT_TYPE;
+      sort_item = GIMV_SORT_TYPE;
       break;
    case 5:
-      sort_item = SORT_ATIME;
+      sort_item = GIMV_SORT_ATIME;
       break;
    case 6:
-      sort_item = SORT_MTIME;
+      sort_item = GIMV_SORT_MTIME;
       break;
    case 7:
-      sort_item = SORT_CTIME;
+      sort_item = GIMV_SORT_CTIME;
       break;
    default:
       return;
    }
 
-   current_item = thumbwin_get_sort_type (tw, &current_flag);
+   current_item = gimv_thumb_win_get_sort_type (tw, &current_flag);
 
    if (current_item == sort_item) {
-      if (current_flag & SORT_REVERSE)
-         sort_flag &= ~SORT_REVERSE;
+      if (current_flag & GIMV_SORT_REVERSE)
+         sort_flag &= ~GIMV_SORT_REVERSE;
       else
-         sort_flag |= SORT_REVERSE;
+         sort_flag |= GIMV_SORT_REVERSE;
    }
 
-   thumbwin_sort_thumbnail (tw, sort_item, sort_flag, THUMBWIN_CURRENT_PAGE);
+   gimv_thumb_win_sort_thumbnail (tw, sort_item, sort_flag,
+                                  GIMV_THUMB_WIN_CURRENT_PAGE);
 }
 
 
@@ -613,7 +614,7 @@ set_column_types (ThumbView *tv, DetailViewData *tv_data,
 static void
 detailview_set_text_data (ThumbView *tv, gchar *dest_mode, GList *start)
 {
-   Thumbnail *thumb;
+   GimvThumb *thumb;
    DetailViewData *tv_data;
    GtkTreeModel *model;
    GList *node, *data_node;
@@ -671,7 +672,7 @@ detailview_set_text_data (ThumbView *tv, gchar *dest_mode, GList *start)
 static void
 detailview_set_pixmaps (ThumbView *tv, gchar *dest_mode)
 {
-   Thumbnail *thumb;
+   GimvThumb *thumb;
    GList *node;
    gint i, num;
 
@@ -724,7 +725,7 @@ detailview_append_thumb_frames (ThumbView *tv, GList *start, gchar *dest_mode)
 
 
 GtkWidget *
-detailview_add_thumbnail (Thumbnail *thumb,
+detailview_add_thumbnail (GimvThumb *thumb,
                           gchar *dest_mode,
                           ThumbLoadType type)
 {
@@ -753,9 +754,9 @@ detailview_add_thumbnail (Thumbnail *thumb,
 
    /* set thumbnail */
    if (!strcmp (DETAIL_ICON_LABEL, dest_mode)) {
-      thumbnail_get_icon (thumb, &pixmap, &mask);
+      gimv_thumb_get_icon (thumb, &pixmap, &mask);
    } else if (!strcmp (DETAIL_THUMB_LABEL, dest_mode)) {
-      thumbnail_get_thumb (thumb, &pixmap, &mask);
+      gimv_thumb_get_thumb (thumb, &pixmap, &mask);
    }
 
    if (!pixmap) return NULL;
@@ -825,11 +826,11 @@ detailview_redraw (ThumbView *tv, gchar *dest_mode,
    /* create thumbnail load list */
    *loadlist = NULL;
    for (node = tv->thumblist; node; node = g_list_next (node)) {
-      Thumbnail *thumb = node->data;
+      GimvThumb *thumb = node->data;
       GdkPixmap *pixmap = NULL;
       GdkBitmap *mask = NULL;
 
-      thumbnail_get_thumb (thumb, &pixmap, &mask);
+      gimv_thumb_get_thumb (thumb, &pixmap, &mask);
       if (!pixmap)
          *loadlist = g_list_append (*loadlist, thumb);
    }
@@ -837,7 +838,7 @@ detailview_redraw (ThumbView *tv, gchar *dest_mode,
 
 
 gboolean
-detailview_refresh_thumbnail (Thumbnail *thumb, ThumbLoadType type)
+detailview_refresh_thumbnail (GimvThumb *thumb, ThumbLoadType type)
 {
    GtkWidget *widget;
    ThumbView *tv;
@@ -857,7 +858,7 @@ detailview_refresh_thumbnail (Thumbnail *thumb, ThumbLoadType type)
 
 
 void
-detailview_adjust (ThumbView *tv, Thumbnail *thumb)
+detailview_adjust (ThumbView *tv, GimvThumb *thumb)
 {
    DetailViewData *tv_data;
    GList *node;
@@ -892,7 +893,7 @@ detailview_adjust (ThumbView *tv, Thumbnail *thumb)
 
 
 gboolean
-detailview_set_selection (Thumbnail *thumb, gboolean select)
+detailview_set_selection (GimvThumb *thumb, gboolean select)
 {
    ThumbView *tv;
    DetailViewData *tv_data;
@@ -936,7 +937,7 @@ detailview_set_selection (Thumbnail *thumb, gboolean select)
 
 
 void
-detailview_set_focus (ThumbView *tv, Thumbnail *thumb)
+detailview_set_focus (ThumbView *tv, GimvThumb *thumb)
 {
    DetailViewData *tv_data;
    gint pos;
@@ -967,10 +968,10 @@ detailview_set_focus (ThumbView *tv, Thumbnail *thumb)
 }
 
 
-Thumbnail *
+GimvThumb *
 detailview_get_focus (ThumbView *tv)
 {
-   Thumbnail *thumb = NULL;
+   GimvThumb *thumb = NULL;
    DetailViewData *tv_data;
 
    g_return_val_if_fail (tv, NULL);
@@ -1000,7 +1001,7 @@ detailview_get_focus (ThumbView *tv)
 
 
 gboolean
-detailview_thumbnail_is_in_viewport (ThumbView *tv, Thumbnail *thumb)
+detailview_thumbnail_is_in_viewport (ThumbView *tv, GimvThumb *thumb)
 {
    DetailViewData *tv_data;
    GList *node;
@@ -1010,7 +1011,7 @@ detailview_thumbnail_is_in_viewport (ThumbView *tv, Thumbnail *thumb)
    GtkTreeModel *model;
    GtkTreeIter iter;
    GtkTreePath *treepath;
-   Thumbnail *tmp_thumb;
+   GimvThumb *tmp_thumb;
    gboolean success;
 
    g_return_val_if_fail (tv, FALSE);
