@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: listview.c,v 1.3 2003/06/18 09:26:54 makeinu Exp $
+ * $Id: listview.c,v 1.5 2004/02/24 10:54:45 makeinu Exp $
  */
 
 #include <string.h>
@@ -792,10 +792,8 @@ listview_redraw (ThumbView *tv, gchar *dest_mode,
 
    tv_data->dest_mode = dest_mode;
 
-   if (tv_data->eventbox) {
-      gtk_widget_destroy (tv_data->eventbox);
-      tv_data->eventbox = NULL;
-   }
+   /*
+   */
 
    if (scroll_win) {
       if (GTK_BIN (tv->container)->child)
@@ -804,6 +802,10 @@ listview_redraw (ThumbView *tv, gchar *dest_mode,
       scrollwin = GTK_SCROLLED_WINDOW (scroll_win);
       gtk_scrolled_window_add_with_viewport (scrollwin, tv_data->eventbox);
    }
+   else if (tv_data->eventbox) {
+      gtk_widget_destroy (tv_data->eventbox);
+      tv_data->eventbox = NULL;
+   }
 
    if (!loadlist) return;
 
