@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: thumbtable.c,v 1.1.2.6 2003/05/14 19:32:11 makeinu Exp $
+ * $Id: thumbtable.c,v 1.8 2003/08/14 09:08:49 makeinu Exp $
  */
 
 #include <string.h>
@@ -30,10 +30,10 @@
 #include "fileutil.h"
 #include "gfileutil.h"
 #include "gimv_plugin.h"
+#include "gimv_thumb.h"
+#include "gimv_thumb_win.h"
 #include "gtk2-compat.h"
-#include "thumbnail.h"
 #include "thumbnail_view.h"
-#include "thumbnail_window.h"
 #include "thumbtable.h"
 #include "thumbtable_prefs.h"
 
@@ -83,7 +83,7 @@ GimvPluginInfo gimv_plugin_info =
 {
    if_version:    GIMV_PLUGIN_IF_VERSION,
    name:          N_("Thumbnail View Thumbnail Mode"),
-   version:       "0.0.1",
+   version:       "0.0.2",
    author:        N_("Takuro Ashie"),
    description:   NULL,
    get_implement: gimv_plugin_get_impl,
@@ -109,7 +109,7 @@ typedef struct ThumbTableData_Tag
    GtkWidget   *event_box;
    gint         colnum;
 
-   Thumbnail   *focused;   /* focused thumbnail */
+   GimvThumb   *focused;   /* focused thumbnail */
    gfloat       page_pos_x;
    gfloat       page_pos_y;
 } ThumbTableData;
@@ -124,34 +124,34 @@ static void       cb_thumbbutton_toggle         (GtkWidget      *button,
                                                  gpointer        data);
 static gboolean   cb_button_focus_in            (GtkWidget      *button,
                                                  GdkEventFocus  *event,
-                                                 Thumbnail      *thumb);
+                                                 GimvThumb      *thumb);
 static gboolean   cb_expose                     (GtkWidget      *widget,
                                                  GdkEventExpose *event,
                                                  ThumbView      *tv);
 static void       cb_entry_activate             (GtkWidget      *entry,
-                                                 Thumbnail      *thumb);
+                                                 GimvThumb      *thumb);
 static gboolean   cb_entry_focus_in             (GtkWidget      *entry,
                                                  GdkEventFocus  *event,
-                                                 Thumbnail      *thumb);
+                                                 GimvThumb      *thumb);
 static gboolean   cb_entry_focus_out            (GtkWidget      *entry,
                                                  GdkEventFocus  *event,
-                                                 Thumbnail      *thumb);
+                                                 GimvThumb      *thumb);
 static gboolean   cb_entry_key_press            (GtkWidget      *entry,
                                                  GdkEventKey    *event,
-                                                 Thumbnail      *thumb);
+                                                 GimvThumb      *thumb);
 
 /* private functions */
 static ThumbTableData *thumbtable_new           (ThumbView *tv);
 static guint      calc_thumbtable_col_row_num   (ThumbView *tv,
                                                  gint       num);
-static gboolean   calc_thumbbutton_pos          (Thumbnail *thumb,
+static gboolean   calc_thumbbutton_pos          (GimvThumb *thumb,
                                                  gint      *col,
                                                  gint      *row);
-static GtkWidget *create_thumbnail_button       (Thumbnail *thumb,
+static GtkWidget *create_thumbnail_button       (GimvThumb *thumb,
                                                  gint       thumb_size,
                                                  gchar     *dest_mode);
 static gboolean   thumbtable_append_thumb_frame (ThumbView *tv,
-                                                 Thumbnail *thumb,
+                                                 GimvThumb *thumb,
                                                  gchar     *dest_mode);
 static gint       idle_thumbtable_redraw        (gpointer   data);
 
@@ -173,7 +173,7 @@ const gint thumbtable_dnd_targets_num = sizeof(thumbtable_dnd_targets) / sizeof(
 static gboolean
 cb_thumb_button_press (GtkWidget *button, GdkEventButton *event, gpointer data)
 {
-   Thumbnail *thumb = data;
+   GimvThumb *thumb = data;
    ThumbView *tv;
    gboolean found = FALSE;
 
@@ -200,7 +200,7 @@ cb_thumb_button_press (GtkWidget *button, GdkEventButton *event, gpointer data)
 static gboolean
 cb_thumb_button_release (GtkWidget *button, GdkEventButton *event, gpointer data)
 {
-   Thumbnail *thumb = data;
+   GimvThumb *thumb = data;
 
    return thumbview_thumb_button_release_cb (button, event, thumb);
 }
@@ -226,7 +226,7 @@ cb_thumbbutton_enter (GtkWidget *button, gpointer data)
 static void
 cb_thumbbutton_toggle (GtkWidget *button, gpointer data)
 {
-   Thumbnail *thumb = data;
+   GimvThumb *thumb = data;
 
    g_return_if_fail (thumb);
 
@@ -244,7 +244,7 @@ cb_thumbbutton_toggle (GtkWidget *button, gpointer data)
 
 
 static gboolean
-cb_button_focus_in (GtkWidget *button, GdkEventFocus *event, Thumbnail *thumb)
+cb_button_focus_in (GtkWidget *button, GdkEventFocus *event, GimvThumb *thumb)
 {
    ThumbView *tv;
    ThumbTableData *tt;
@@ -282,7 +282,7 @@ cb_thumbview_drag_begin (GtkWidget *widget,
                          GdkDragContext *context,
                          gpointer data)
 {
-   Thumbnail *thumb = data;
+   GimvThumb *thumb = data;
    ThumbView *tv;
 
    g_return_if_fail (thumb);
@@ -299,9 +299,9 @@ cb_thumbview_drag_begin (GtkWidget *widget,
 
 
 static void
-cb_entry_activate (GtkWidget *entry, Thumbnail *thumb)
+cb_entry_activate (GtkWidget *entry, GimvThumb *thumb)
 {
-   ThumbWindow *tw;
+   GimvThumbWin *tw;
    ThumbView *tv;
    const gchar *filename;
    gchar *dest_filename = NULL, *dest_path, *dirname;
@@ -309,22 +309,22 @@ cb_entry_activate (GtkWidget *entry, Thumbnail *thumb)
    gboolean success;
 
    g_return_if_fail (thumb);
-   g_return_if_fail (!image_info_is_in_archive (thumb->info));
+   g_return_if_fail (!gimv_image_info_is_in_archive (thumb->info));
 
-   tv = thumbnail_get_parent_thumbview (thumb);
+   tv = gimv_thumb_get_parent_thumbview (thumb);
    g_return_if_fail (tv);
 
    tw = tv->thumb_window;
    g_return_if_fail (tw);
 
-   filename = image_info_get_path (thumb->info);
+   filename = gimv_image_info_get_path (thumb->info);
    if (!filename || !*filename) goto ERROR0;
    if (!file_exists (filename)) {
       g_snprintf (error_message, BUF_SIZE,
                   _("File not exist!!:\n%s"),
                   filename);
       gtkutil_message_dialog ("Error!!", error_message,
-                              GTK_WINDOW (tw->window));
+                              GTK_WINDOW (tw));
       goto ERROR0;
    }
 
@@ -332,7 +332,7 @@ cb_entry_activate (GtkWidget *entry, Thumbnail *thumb)
    if (!filename || !*filename) goto ERROR0;
    dest_filename = gimv_filename_to_locale (filename);
 
-   dirname = g_dirname (image_info_get_path (thumb->info));
+   dirname = g_dirname (gimv_image_info_get_path (thumb->info));
    if (!dirname) goto ERROR0;
    if (!*dirname) goto ERROR1;
 
@@ -341,7 +341,7 @@ cb_entry_activate (GtkWidget *entry, Thumbnail *thumb)
                   _("Permission denied!!:\n%s"),
                   dirname);
       gtkutil_message_dialog ("Error!!", error_message,
-                              GTK_WINDOW (tw->window));
+                              GTK_WINDOW (tw));
       goto ERROR1;
    }
 
@@ -351,18 +351,18 @@ cb_entry_activate (GtkWidget *entry, Thumbnail *thumb)
                   _("File exist!!:\n%s"),
                   dest_path);
       gtkutil_message_dialog (_("Error!!"), error_message,
-                              GTK_WINDOW (tw->window));
+                              GTK_WINDOW (tw));
       goto ERROR2;
    }
 
    /* do rename !! */
-   success = image_info_rename_image (thumb->info, dest_path);
+   success = gimv_image_info_rename_image (thumb->info, dest_path);
 
    if (!success) {
       g_snprintf (error_message, BUF_SIZE,
                   _("Faild to rename!!"));
       gtkutil_message_dialog (_("Error!!"), error_message,
-                              GTK_WINDOW (tw->window));
+                              GTK_WINDOW (tw));
    }
 
 ERROR2:
@@ -371,7 +371,7 @@ ERROR1:
    g_free (dirname);
 ERROR0:
    g_free (dest_filename);
-   filename = g_basename (image_info_get_path (thumb->info));
+   filename = g_basename (gimv_image_info_get_path (thumb->info));
 
    if (filename && *filename) {
       gchar *tmpstr;
@@ -384,23 +384,23 @@ ERROR0:
 
 
 static gboolean
-cb_entry_focus_in (GtkWidget *widget, GdkEventFocus *event, Thumbnail *thumb)
+cb_entry_focus_in (GtkWidget *widget, GdkEventFocus *event, GimvThumb *thumb)
 {
 #ifdef USE_GTK2
-   thumbwin_remove_key_accel (thumb->thumb_view->thumb_window);
+   gimv_thumb_win_remove_key_accel (thumb->thumb_view->thumb_window);
 #endif /* USE_GTK2 */
    return FALSE;
 }
 
 
 static gboolean
-cb_entry_focus_out (GtkWidget *entry, GdkEventFocus *event, Thumbnail *thumb)
+cb_entry_focus_out (GtkWidget *entry, GdkEventFocus *event, GimvThumb *thumb)
 {
    const gchar *filename;
 
    g_return_val_if_fail (thumb, FALSE);
 
-   filename = g_basename (image_info_get_path (thumb->info));
+   filename = g_basename (gimv_image_info_get_path (thumb->info));
 
    if (filename && *filename) {
       gchar *tmpstr;
@@ -411,7 +411,7 @@ cb_entry_focus_out (GtkWidget *entry, GdkEventFocus *event, Thumbnail *thumb)
    }
 
 #ifdef USE_GTK2
-   thumbwin_reset_key_accel (thumb->thumb_view->thumb_window);
+   gimv_thumb_win_reset_key_accel (thumb->thumb_view->thumb_window);
 #endif /* USE_GTK2 */
    return FALSE;
 }
@@ -420,11 +420,11 @@ cb_entry_focus_out (GtkWidget *entry, GdkEventFocus *event, Thumbnail *thumb)
 static gboolean
 cb_entry_key_press (GtkWidget *entry,
                     GdkEventKey *event,
-                    Thumbnail *thumb)
+                    GimvThumb *thumb)
 {
    ThumbView *tv;
-   ThumbWindow *tw;
-   Thumbnail *n_thumb;
+   GimvThumbWin *tw;
+   GimvThumb *n_thumb;
    ThumbData *thumb_data;
    GList *next, *current;
 
@@ -438,7 +438,7 @@ cb_entry_key_press (GtkWidget *entry,
 
    switch (event->keyval) {
    case GDK_Escape:
-      gtk_window_set_focus (GTK_WINDOW (thumb->thumb_view->thumb_window->window), NULL);
+      gtk_window_set_focus (GTK_WINDOW (thumb->thumb_view->thumb_window), NULL);
       return TRUE;
    case GDK_Tab:
    case GDK_ISO_Left_Tab:
@@ -477,14 +477,14 @@ cb_entry_key_press (GtkWidget *entry,
 static gboolean
 cb_thumb_key_press (GtkWidget *widget,
                     GdkEventKey *event,
-                    Thumbnail *thumb)
+                    GimvThumb *thumb)
 {
    ThumbView *tv;
 
    g_return_val_if_fail (event, FALSE);
    if (!thumb) return FALSE;
 
-   tv = thumbnail_get_parent_thumbview (thumb);
+   tv = gimv_thumb_get_parent_thumbview (thumb);
    g_return_val_if_fail (tv, FALSE);
 
    if (thumbview_thumb_key_press_cb(widget, event, thumb))
@@ -568,7 +568,7 @@ thumbtable_new (ThumbView *tv)
 static guint
 calc_thumbtable_col_row_num (ThumbView *tv, gint num)
 {
-   ThumbWindow *tw;
+   GimvThumbWin *tw;
    ThumbTableData *tt = g_hash_table_lookup (tv->disp_mode_data, THUMB_TABLE_LABEL);
    GtkAdjustment *hadj;
    gint table_rows = 0, container_width;
@@ -580,7 +580,7 @@ calc_thumbtable_col_row_num (ThumbView *tv, gint num)
 
    container_width = hadj->page_size;
    if (container_width < 10)
-      container_width = tw->window->allocation.width;
+      container_width = GTK_WIDGET (tw)->allocation.width;
 
    thumbtable_prefs_get_value ("colnum_min", (gpointer) &ncol_min);
    thumbtable_prefs_get_value ("colnum_max", (gpointer) &ncol_max);
@@ -608,13 +608,13 @@ calc_thumbtable_col_row_num (ThumbView *tv, gint num)
  *  calc_thumbbutton_pos:
  *     @ calculate thumbnail position in the table (column and row).
  *
- *  thumb  : Pointer to the Thumbnail widget.
+ *  thumb  : Pointer to the GimvThumb widget.
  *  col    : column num for return. 
  *  row    : row num for return.
  *  Return : TRUE if success.
  */
 static gboolean
-calc_thumbbutton_pos (Thumbnail *thumb, gint *col, gint *row)
+calc_thumbbutton_pos (GimvThumb *thumb, gint *col, gint *row)
 {
    ThumbView *tv;
    ThumbTableData *tt;
@@ -647,13 +647,13 @@ calc_thumbbutton_pos (Thumbnail *thumb, gint *col, gint *row)
  *  create_thumbnail_button:
  *     @ Create a thumbnail button. 
  *
- *  thumb      : Pointer to Thumbnail struture.
+ *  thumb      : Pointer to GimvThumb struture.
  *  thumb_size : Size of thumbnail.
  *  mode       :
  *  Return     : Pointer to GtkButton widget.
  */
 static GtkWidget *
-create_thumbnail_button (Thumbnail *thumb, gint thumb_size, gchar *dest_mode)
+create_thumbnail_button (GimvThumb *thumb, gint thumb_size, gchar *dest_mode)
 {
    GtkWidget *button;
    GtkWidget *label;
@@ -722,12 +722,19 @@ create_thumbnail_button (Thumbnail *thumb, gint thumb_size, gchar *dest_mode)
    gtk_object_set_data (GTK_OBJECT (button), "gimv-tab", tv);
 
    /* set tooltip */
-   filename = image_info_get_path (thumb->info);
+   filename = gimv_image_info_get_path (thumb->info);
 
    str = gimv_filename_to_internal (filename);
 
-   g_snprintf(buf, BUF_SIZE, "%s (%dkB)", str,
-              (gint) (thumb->info->st.st_size) / 1024);
+   if (thumb->info->st.st_size < 1024) {
+      g_snprintf(buf, BUF_SIZE, "%s (%ld Bytes)", str, thumb->info->st.st_size);
+   } else if (thumb->info->st.st_size < 1024 * 1024) {
+      g_snprintf(buf, BUF_SIZE, "%s (%.1f KB)", str,
+                 ((gdouble) (thumb->info->st.st_size)) / 1024.0);
+   } else if (thumb->info->st.st_size < 1024 * 1024 * 1024) {
+      g_snprintf(buf, BUF_SIZE, "%s (%.1f MB)", str,
+                 ((gdouble) (thumb->info->st.st_size)) / ((gdouble) (1024 * 1024)));
+   }
 
    g_free (str);
    str = NULL;
@@ -747,7 +754,7 @@ create_thumbnail_button (Thumbnail *thumb, gint thumb_size, gchar *dest_mode)
    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), thumb->selected);
 
    /* get filename */
-   filename = g_basename (image_info_get_path (thumb->info));
+   filename = g_basename (gimv_image_info_get_path (thumb->info));
    str = gimv_filename_to_internal (filename);
 
    mode_label = dest_mode;
@@ -766,7 +773,7 @@ create_thumbnail_button (Thumbnail *thumb, gint thumb_size, gchar *dest_mode)
    } else if (mode_label && !strcmp (RENAME_MODE_LABEL, mode_label)) {
       gchar *dirname;
 
-      dirname = g_dirname (image_info_get_path (thumb->info));
+      dirname = g_dirname (gimv_image_info_get_path (thumb->info));
 
       thumb_data->entry = gtk_entry_new ();
       if (str)
@@ -776,7 +783,7 @@ create_thumbnail_button (Thumbnail *thumb, gint thumb_size, gchar *dest_mode)
       gtk_box_pack_end (GTK_BOX(thumb_data->vbox), thumb_data->entry, FALSE, FALSE, 0);
       gtk_widget_show (thumb_data->entry);
 
-      if (!iswritable (dirname) || image_info_is_in_archive (thumb->info)) {
+      if (!iswritable (dirname) || gimv_image_info_is_in_archive (thumb->info)) {
          gtk_widget_set_sensitive (thumb_data->entry, FALSE);
       } else {
          gtk_signal_connect (GTK_OBJECT(thumb_data->entry), "activate",
@@ -803,11 +810,11 @@ create_thumbnail_button (Thumbnail *thumb, gint thumb_size, gchar *dest_mode)
  *     @ append a thumbnail button to the table.
  *
  *  tv     : Pointer to the ThumbView struct.
- *  thumb  : Pointer to the Thumbnail struct to create frame.
+ *  thumb  : Pointer to the GimvThumb struct to create frame.
  *  Return : Added thumbnail button widget.
  */
 static gboolean
-thumbtable_append_thumb_frame (ThumbView *tv, Thumbnail *thumb, gchar *dest_mode)
+thumbtable_append_thumb_frame (ThumbView *tv, GimvThumb *thumb, gchar *dest_mode)
 {
    GtkWidget *button;
    GdkPixmap *pixmap;
@@ -836,7 +843,7 @@ thumbtable_append_thumb_frame (ThumbView *tv, Thumbnail *thumb, gchar *dest_mode
 
    button = create_thumbnail_button (thumb, tv->ThumbnailSize, dest_mode);
 
-   thumbnail_get_thumb (thumb, &pixmap, &mask);
+   gimv_thumb_get_thumb (thumb, &pixmap, &mask);
    if (pixmap) {
       thumbtable_add_thumbnail (thumb, dest_mode, LOAD_CACHE);
       retval = TRUE;
@@ -932,10 +939,10 @@ thumbtable_remove_thumbview_data (ThumbView *tv)
 /*
  *  thumbtable_remove_thumbnail_data:
  *
- *  thumb : Pointer to the Thumbnail struct.
+ *  thumb : Pointer to the GimvThumb struct.
  */
 void
-thumbtable_remove_thumbnail_data (Thumbnail *thumb)
+thumbtable_remove_thumbnail_data (GimvThumb *thumb)
 {
    ThumbData *thumb_data;
 
@@ -963,7 +970,7 @@ thumbtable_remove_thumbnail_data (Thumbnail *thumb)
 GList *
 thumbtable_append_thumb_frames (ThumbView *tv, GList *start, gchar *dest_mode)
 {
-   Thumbnail  *thumb;
+   GimvThumb  *thumb;
    GList *node, *loadlist = NULL;
    gboolean thumb_loaded = FALSE;
 
@@ -972,7 +979,7 @@ thumbtable_append_thumb_frames (ThumbView *tv, GList *start, gchar *dest_mode)
 
    node = start;
    while (node) {
-      thumb = (Thumbnail *) node->data;
+      thumb = (GimvThumb *) node->data;
 
       /* add button */
       thumb_loaded = thumbtable_append_thumb_frame (tv, thumb, dest_mode);
@@ -990,12 +997,12 @@ thumbtable_append_thumb_frames (ThumbView *tv, GList *start, gchar *dest_mode)
  *  thumbtable_add_thumbnail:
  *     @ append thumbnail to thumbnail frame.
  *
- *  thumb     : Pointer to the Thumbnail struct.
+ *  thumb     : Pointer to the GimvThumb struct.
  *  dest_mode : New thumbnail view display mode.
  *  Return    : Added thumbnail pixmap widget.
  */
 GtkWidget *
-thumbtable_add_thumbnail (Thumbnail *thumb, gchar *dest_mode,
+thumbtable_add_thumbnail (GimvThumb *thumb, gchar *dest_mode,
                           ThumbLoadType type)
 {
    ThumbView *tv = thumb->thumb_view;
@@ -1009,10 +1016,10 @@ thumbtable_add_thumbnail (Thumbnail *thumb, gchar *dest_mode,
    thumb_data = g_hash_table_lookup (thumb->mode_data, THUMB_TABLE_LABEL);
    g_return_val_if_fail (thumb_data, NULL);
 
-   thumbnail_get_thumb (thumb, &thumbnail, &mask);
+   gimv_thumb_get_thumb (thumb, &thumbnail, &mask);
    if (!thumbnail)
-      if (thumbnail_create (thumb, tv->ThumbnailSize, type))
-         thumbnail_get_thumb (thumb, &thumbnail, &mask);
+      if (gimv_thumb_load (thumb, tv->ThumbnailSize, type))
+         gimv_thumb_get_thumb (thumb, &thumbnail, &mask);
 
    if (thumbnail) {
       if (thumb_data->pixmap) {
@@ -1023,7 +1030,7 @@ thumbtable_add_thumbnail (Thumbnail *thumb, gchar *dest_mode,
          gtk_pixmap_set (GTK_PIXMAP (thumb_data->pixmap), thumbnail, mask);
 #endif /* USE_GTK2 */
       } else {
-         pixmap = thumbnail_get_thumb_by_widget (thumb);
+         pixmap = gimv_thumb_get_thumb_by_widget (thumb);
          gtk_container_add (GTK_CONTAINER (thumb_data->button), pixmap);
          gtk_widget_show (pixmap);
          thumb_data->pixmap = pixmap;
@@ -1090,11 +1097,11 @@ thumbtable_redraw (ThumbView *tv, gchar *dest_mode,
    *loadlist = NULL;
    node = tv->thumblist;
    while (node) {
-      Thumbnail *thumb = node->data;
+      GimvThumb *thumb = node->data;
       GdkPixmap *pixmap = NULL;
       GdkBitmap *mask = NULL;
 
-      thumbnail_get_thumb (thumb, &pixmap, &mask);
+      gimv_thumb_get_thumb (thumb, &pixmap, &mask);
       if (!pixmap)
          *loadlist = g_list_append (*loadlist, thumb);
       node = g_list_next (node);
@@ -1112,11 +1119,11 @@ thumbtable_redraw (ThumbView *tv, gchar *dest_mode,
  *  thumbtable_refresh_thumbnail:
  *     @ Create thumbnail from original image, and recreate thumbnail button.
  *
- *  thumb  : Pointer to the Thumbnail struct.
+ *  thumb  : Pointer to the GimvThumb struct.
  *  Return : TRUE if success.
  */
 gboolean
-thumbtable_refresh_thumbnail (Thumbnail *thumb, ThumbLoadType type)
+thumbtable_refresh_thumbnail (GimvThumb *thumb, ThumbLoadType type)
 {
    ThumbView *tv;
    ThumbTableData *tt;
@@ -1196,7 +1203,7 @@ thumbtable_resize (ThumbView *tv)
 
 
 void
-thumbtable_adjust (ThumbView *tv, Thumbnail *thumb)
+thumbtable_adjust (ThumbView *tv, GimvThumb *thumb)
 {
    ThumbTableData *tt;
    ThumbData *thumb_data;   
@@ -1254,7 +1261,7 @@ thumbtable_adjust (ThumbView *tv, Thumbnail *thumb)
 
 
 gboolean
-thumbtable_set_selection (Thumbnail *thumb, gboolean select)
+thumbtable_set_selection (GimvThumb *thumb, gboolean select)
 {
    ThumbData *thumb_data;
    GtkWidget *button;
@@ -1283,7 +1290,7 @@ thumbtable_set_selection (Thumbnail *thumb, gboolean select)
 
 
 void
-thumbtable_set_focus (ThumbView *tv, Thumbnail *thumb)
+thumbtable_set_focus (ThumbView *tv, GimvThumb *thumb)
 {
    ThumbTableData *tt;
    ThumbData *thumb_data;
@@ -1304,7 +1311,7 @@ thumbtable_set_focus (ThumbView *tv, Thumbnail *thumb)
 }
 
 
-Thumbnail *
+GimvThumb *
 thumbtable_get_focus (ThumbView *tv)
 {
    ThumbTableData *tt;
@@ -1319,7 +1326,7 @@ thumbtable_get_focus (ThumbView *tv)
 
 
 gboolean
-thumbtable_thumbnail_is_in_viewport (ThumbView *tv, Thumbnail *thumb)
+thumbtable_thumbnail_is_in_viewport (ThumbView *tv, GimvThumb *thumb)
 {
    ThumbData *thumb_data;
    GdkRectangle area, cell_area, intersect_area;
