@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: dirview.c,v 1.64.2.17 2003/06/11 09:40:09 makeinu Exp $
+ * $Id: dirview.c,v 1.77 2003/07/24 15:33:03 makeinu Exp $
  */
 
 /*
@@ -49,9 +49,9 @@
 #include "gtk_prop.h"
 #include "gtkutils.h"
 #include "gimv_icon_stock.h"
+#include "gimv_thumb_win.h"
 #include "menu.h"
 #include "prefs.h"
-#include "thumbnail_window.h"
 
 
 /* for auto-scroll and auto-expand at drag */
@@ -749,7 +749,7 @@ idle_dirview_button_action (gpointer data)
 static gboolean
 dirview_button_action (DirView *dv, GdkEventButton *event, gint num)
 {
-   ThumbWindow *tw;
+   GimvThumbWin *tw;
    GtkWidget *dirtree;
    GtkCTreeNode *node;
    DirNode *dirnode;
@@ -1204,7 +1204,7 @@ cb_refresh_dir_tree (DirView *dv, guint action, GtkWidget *menuitem)
 static void
 cb_file_property (DirView *dv, guint action, GtkWidget *menuitem)
 {
-   ImageInfo *info;
+   GimvImageInfo *info;
    gchar *path, *tmpstr;
 
    g_return_if_fail (dv);
@@ -1215,7 +1215,7 @@ cb_file_property (DirView *dv, guint action, GtkWidget *menuitem)
    path = remove_slash (tmpstr);
    g_free(tmpstr);
 
-   info = image_info_get (path);
+   info = gimv_image_info_get (path);
    if (!info) {
       g_free (path);
       return;
@@ -1223,7 +1223,7 @@ cb_file_property (DirView *dv, guint action, GtkWidget *menuitem)
 
    dlg_prop_from_image_info (info, 0);
 
-   image_info_unref (info);
+   gimv_image_info_unref (info);
    g_free (path);
 }
 
@@ -1476,7 +1476,7 @@ cb_drag_data_get (GtkWidget *dirtree,
 
    tmpstr = remove_slash (dirnode->path);
 
-   uri = g_strconcat ("file:", tmpstr, "\r\n", NULL);
+   uri = g_strconcat ("file://", tmpstr, "\r\n", NULL);
 
    gtk_selection_data_set(seldata, seldata->target,
                           8, uri, strlen(uri));
@@ -1584,7 +1584,7 @@ cb_toolbar_drag_data_get (GtkWidget *widget,
 
 typedef struct SwapCom_Tag
 {
-   ThumbWindow *tw;
+   GimvThumbWin *tw;
    gint src;
    gint dest;
 } SwapCom;
@@ -1594,7 +1594,7 @@ static gint
 idle_thumbwin_swap_component (gpointer data)
 {
    SwapCom *swap = data;
-   thumbwin_swap_component (swap->tw, swap->src, swap->dest);
+   gimv_thumb_win_swap_component (swap->tw, swap->src, swap->dest);
    return FALSE;
 }
 
@@ -1608,7 +1608,7 @@ cb_com_swap_drag_data_received (GtkWidget *widget,
                                 guint time,
                                 gpointer data)
 {
-   ThumbWindow *tw = data;
+   GimvThumbWin *tw = data;
    GtkWidget *src_widget;
    gpointer p;
    gint src, dest;
@@ -1980,7 +1980,7 @@ dirview_create_toolbar (DirView *dv)
    g_return_val_if_fail (dv, NULL);
 
    if (dv->tw)
-      container = dv->tw->window;
+      container = GTK_WIDGET (dv->tw);
    else
       container = dv->window;
 
@@ -2063,7 +2063,7 @@ idle_change_root (gpointer data)
  *
  ******************************************************************************/
 DirView *
-dirview_create (const gchar *root_dir, GtkWidget *parent_win, ThumbWindow *tw)
+dirview_create (const gchar *root_dir, GtkWidget *parent_win, GimvThumbWin *tw)
 {
    DirView *dv;
    GtkWidget *eventbox;
@@ -2078,7 +2078,7 @@ dirview_create (const gchar *root_dir, GtkWidget *parent_win, ThumbWindow *tw)
       dv->root_dir = g_strdup (home);
 
    if (tw)
-      dv->window = tw->window;
+      dv->window = GTK_WIDGET (tw);
    else
       dv->window = NULL;
    dv->popup_menu        = NULL;
