@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: dirview.h,v 1.12.2.3 2003/04/08 16:31:31 makeinu Exp $
+ * $Id: dirview.h,v 1.15 2003/06/15 16:14:53 makeinu Exp $
  */
 
 #ifndef __DIRVIEW_H__
@@ -39,20 +39,20 @@ typedef enum
 
 struct DirView_Tag
 {
-   GtkWidget   *container;
-   GtkWidget   *window;
-   GtkWidget   *toolbar;
-   GtkWidget   *toolbar_eventbox;
-   GtkWidget   *scroll_win;
-   GtkWidget   *dirtree;
-   GtkWidget   *popup_menu;
+   GtkWidget      *container;
+   GtkWidget      *window;
+   GtkWidget      *toolbar;
+   GtkWidget      *toolbar_eventbox;
+   GtkWidget      *scroll_win;
+   GtkWidget      *dirtree;
+   GtkWidget      *popup_menu;
 
-   ThumbWindow *tw;
+   GimvThumbWin   *tw;
 
-   gchar       *root_dir;
-   DirViewMode  mode;
-   gboolean     show_toolbar;
-   gboolean     show_dotfile;
+   gchar          *root_dir;
+   DirViewMode     mode;
+   gboolean        show_toolbar;
+   gboolean        show_dotfile;
 
    DirViewPrivate *priv;
 };
@@ -78,6 +78,6 @@ void       dirview_hide_toolbar          (DirView     *dv);
 
 DirView   *dirview_create                (const gchar *root_dir,
                                           GtkWidget   *parent_win,
-                                          ThumbWindow *tw);
+                                          GimvThumbWin *tw);
 
 #endif /* __DIRVIEW_H__ */
