@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: dirview2.c,v 1.18.2.15 2003/06/11 06:41:18 makeinu Exp $
+ * $Id: dirview2.c,v 1.31 2003/07/24 15:33:03 makeinu Exp $
  */
 
 #ifndef GTK_DISABLE_DEPRECATED
@@ -39,9 +39,9 @@
 #include "gtk2-compat.h"
 #include "gtk_prop.h"
 #include "gimv_icon_stock.h"
+#include "gimv_thumb_win.h"
 #include "menu.h"
 #include "prefs.h"
-#include "thumbnail_window.h"
 
 
 typedef enum {
@@ -495,7 +495,7 @@ cb_refresh_dir_tree (DirView *dv, guint action, GtkWidget *menuitem)
 static void
 cb_file_property (DirView *dv, guint action, GtkWidget *menuitem)
 {
-   ImageInfo *info;
+   GimvImageInfo *info;
    gchar *path, *tmpstr;
 
    g_return_if_fail (dv);
@@ -506,7 +506,7 @@ cb_file_property (DirView *dv, guint action, GtkWidget *menuitem)
    path = remove_slash (tmpstr);
    g_free(tmpstr);
 
-   info = image_info_get (path);
+   info = gimv_image_info_get (path);
    if (!info) {
       g_free (path);
       return;
@@ -514,7 +514,7 @@ cb_file_property (DirView *dv, guint action, GtkWidget *menuitem)
 
    dlg_prop_from_image_info (info, 0);
 
-   image_info_unref (info);
+   gimv_image_info_unref (info);
    g_free (path);
 }
 
@@ -690,7 +690,7 @@ cb_drag_data_get (GtkWidget *dirtree,
 
    if (path [strlen (path) - 1] == '/')
       path [strlen (path) - 1] = '\0';
-   urilist = g_strconcat ("file:", path, "\r\n", NULL);
+   urilist = g_strconcat ("file://", path, "\r\n", NULL);
 
    gtk_selection_data_set(seldata, seldata->target,
                           8, urilist, strlen(urilist));
@@ -812,7 +812,7 @@ cb_toolbar_drag_data_get (GtkWidget *widget,
 
 typedef struct SwapCom_Tag
 {
-   ThumbWindow *tw;
+   GimvThumbWin *tw;
    gint src;
    gint dest;
 } SwapCom;
@@ -822,7 +822,7 @@ static gint
 idle_thumbwin_swap_component (gpointer data)
 {
    SwapCom *swap = data;
-   thumbwin_swap_component (swap->tw, swap->src, swap->dest);
+   gimv_thumb_win_swap_component (swap->tw, swap->src, swap->dest);
    return FALSE;
 }
 
@@ -836,7 +836,7 @@ cb_com_swap_drag_data_received (GtkWidget *widget,
                                 guint time,
                                 gpointer data)
 {
-   ThumbWindow *tw = data;
+   GimvThumbWin *tw = data;
    GtkWidget *src_widget;
    gpointer p;
    gint src, dest;
@@ -1034,7 +1034,7 @@ dirview_create_toolbar (DirView *dv)
    g_return_val_if_fail (dv, NULL);
 
    if (dv->tw)
-      container = dv->tw->window;
+      container = GTK_WIDGET (dv->tw);
    else
       container = dv->window;
 
@@ -1307,7 +1307,8 @@ get_iter_from_path (DirView *dv, const gchar *str, GtkTreeIter *iter)
 struct AdjustTreeIdle {
    DirView     *dv;
    GtkTreeView *treeview;
-   GtkTreeIter *iter;
+   gboolean     has_iter;
+   GtkTreeIter  iter;
 };
 
 
@@ -1317,9 +1318,11 @@ idle_adjust_tree (gpointer data)
    struct AdjustTreeIdle *idle = data;
 
    idle->dv->priv->adjust_tree_id = 0;
-   adjust_tree (idle->treeview, idle->iter);
-   g_free (idle->iter);
-   g_free (idle);
+   if (idle->has_iter)
+      adjust_tree (idle->treeview, &idle->iter);
+   else
+      adjust_tree (idle->treeview, NULL);
+
    return FALSE;
 }
 
@@ -1337,13 +1340,16 @@ adjust_tree_idle (DirView *dv, GtkTreeIter *iter)
    idle->dv = dv;
    idle->treeview = treeview;
    if (iter) {
-      idle->iter = g_new0 (GtkTreeIter, 1);
-      *idle->iter = *iter;
+      idle->iter = *iter;
+      idle->has_iter = TRUE;
    } else {
-      idle->iter = NULL;
+      idle->has_iter = FALSE;
    }
 
-   dv->priv->adjust_tree_id = gtk_idle_add (idle_adjust_tree, idle);
+   dv->priv->adjust_tree_id = 
+      gtk_idle_add_full (G_PRIORITY_DEFAULT,
+                         idle_adjust_tree, NULL, idle,
+                         (GtkDestroyNotify) g_free);
 }
 
 
@@ -1855,7 +1861,7 @@ dirview_hide_toolbar (DirView *dv)
 DirView *
 dirview_create (const gchar *root_dir,
                 GtkWidget *parent_win,
-                ThumbWindow *tw)
+                GimvThumbWin *tw)
 {
    DirView *dv;
    GtkWidget *eventbox;
