@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: dnd.h,v 1.6.2.1 2003/03/30 08:45:36 makeinu Exp $
+ * $Id: dnd.h,v 1.8 2003/06/15 16:14:53 makeinu Exp $
  */
 
 #ifndef __DND_H__
@@ -69,6 +69,6 @@ void   dnd_file_operation    (const gchar          *dest_dir,
                               GdkDragContext       *context,
                               GtkSelectionData     *seldata,
                               guint                 time,
-                              ThumbWindow          *tw);
+                              GimvThumbWin         *tw);
 
 #endif /* __DND_H__ */
