@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: fileload.c,v 1.38.2.9 2003/06/09 12:46:11 makeinu Exp $
+ * $Id: fileload.c,v 1.46 2003/06/18 09:26:55 makeinu Exp $
  */
 
 #include <stdio.h>
@@ -41,17 +41,17 @@
 #include "fileload.h"
 #include "fileutil.h"
 #include "gimv_icon_stock.h"
-#include "image_info.h"
+#include "gimv_image_info.h"
 #include "gimv_image_win.h"
+#include "gimv_thumb_win.h"
 #include "thumbnail_view.h"
-#include "thumbnail_window.h"
 
 
 /* for filebrowser call back functions */
 typedef struct _FileSel
 {
-   GtkWidget   *filebrowser;
-   ThumbWindow *tw;
+   GtkWidget    *filebrowser;
+   GimvThumbWin *tw;
 } FileSel;
 
 
@@ -91,13 +91,13 @@ files_loader_new (void)
    files_loader_list = g_list_append (files_loader_list, files);
 
    if (reset_sensitive) {
-      GList *node = thumbwin_get_list();
+      GList *node = gimv_thumb_win_get_list();
 
       loading_stop = FALSE;
 
       while (node) {
-         ThumbWindow *tw = node->data;
-         thumbwin_set_sensitive (tw, THUMB_WIN_STATUS_LOADING);
+         GimvThumbWin *tw = node->data;
+         gimv_thumb_win_set_sensitive (tw, GIMV_THUMB_WIN_STATUS_LOADING);
          node = g_list_next (node);
       }
    }
@@ -126,10 +126,10 @@ files_loader_delete (FilesLoader *files)
    files_loader_list = g_list_remove (files_loader_list, files);
 
    if (!files_loader_list) {
-      GList *node = thumbwin_get_list();
+      GList *node = gimv_thumb_win_get_list();
       while (node) {
-         ThumbWindow *tw = node->data;
-         thumbwin_set_sensitive (tw, THUMB_WIN_STATUS_NORMAL);
+         GimvThumbWin *tw = node->data;
+         gimv_thumb_win_set_sensitive (tw, GIMV_THUMB_WIN_STATUS_NORMAL);
          node = g_list_next (node);
       }
    }
@@ -336,7 +336,7 @@ open_image_files_in_image_view (FilesLoader *files)
 
          /* open iamge window */
       } else {
-         ImageInfo *info = image_info_get (filename);
+         GimvImageInfo *info = gimv_image_info_get (filename);
          if (info)
             gimv_image_win_open_window (info);
       }
@@ -353,19 +353,19 @@ open_image_files_in_image_view (FilesLoader *files)
 }
 
 
-static ThumbWindow *
-select_thumbnail_window (ThumbWindow *tw)
+static GimvThumbWin *
+select_thumbnail_window (GimvThumbWin *tw)
 {
-   ThumbWindow *retval;
+   GimvThumbWin *retval;
    GList *node;
 
-   if (tw && g_list_find (thumbwin_get_list(), tw)) {
-      retval = (ThumbWindow *) tw;
+   if (tw && g_list_find (gimv_thumb_win_get_list(), tw)) {
+      retval = (GimvThumbWin *) tw;
    }
-   else if (g_list_length (thumbwin_get_list()) < 1) {
-      retval = thumbwin_open_window ();
+   else if (g_list_length (gimv_thumb_win_get_list()) < 1) {
+      retval = gimv_thumb_win_open_window ();
    } else {
-      node = g_list_last (thumbwin_get_list());
+      node = g_list_last (gimv_thumb_win_get_list());
       retval = node->data;
    }
 
@@ -385,9 +385,9 @@ select_thumbnail_window (ThumbWindow *tw)
  *  Return : Return TRUE if success or canceled by user.
  */
 gint
-open_image_files_in_thumbnail_view (FilesLoader *files, ThumbWindow *tw)
+open_image_files_in_thumbnail_view (FilesLoader *files, GimvThumbWin *tw)
 {
-   ThumbWindow *tw_tmp;
+   GimvThumbWin *tw_tmp;
    ThumbView  *tv;
    GtkWidget   *newtab;
 
@@ -398,16 +398,16 @@ open_image_files_in_thumbnail_view (FilesLoader *files, ThumbWindow *tw)
    /* select thumbnail window */
    tw_tmp = select_thumbnail_window (tw);
    if (conf.thumbwin_raise_window)
-      gdk_window_raise (tw_tmp->window->window);
+      gdk_window_raise (GTK_WIDGET (tw_tmp)->window);
 
    /* select notebook page and open files */
-   tv = thumbwin_find_thumbtable (tw_tmp, THUMBWIN_CURRENT_PAGE);
+   tv = gimv_thumb_win_find_thumbtable (tw_tmp, GIMV_THUMB_WIN_CURRENT_PAGE);
 
    if (tv && tv->mode == THUMB_VIEW_MODE_COLLECTION) {
       thumbview_append_thumbnail (tv, files, FALSE);
    } else {
       if (!(tw_tmp->pagenum) || tv) {
-         newtab = thumbwin_create_new_tab (tw_tmp);
+         newtab = gimv_thumb_win_create_new_tab (tw_tmp);
          if (!newtab)
             return FALSE;
       } else {
@@ -425,7 +425,7 @@ open_image_files_in_thumbnail_view (FilesLoader *files, ThumbWindow *tw)
          return FALSE;
    }
 
-   thumbwin_set_statusbar_page_info (tw_tmp, THUMBWIN_CURRENT_PAGE);
+   gimv_thumb_win_set_statusbar_page_info (tw_tmp, GIMV_THUMB_WIN_CURRENT_PAGE);
 
    return TRUE;
 }
@@ -466,12 +466,12 @@ open_image_files (FilesLoader *files)
  */
 gint
 open_dir_images (const gchar   *dir,
-                 ThumbWindow   *tw,
+                 GimvThumbWin  *tw,
                  ThumbLoadType  type,
                  ScanSubDirType scan_subdir)
 {
    FilesLoader *files;
-   ThumbWindow *tw_tmp = NULL;
+   GimvThumbWin *tw_tmp = NULL;
    ThumbView *tv;
    GtkWidget *newtab;
    gint retval = FALSE, flags;
@@ -490,7 +490,7 @@ open_dir_images (const gchar   *dir,
 
    if (access (dirname, R_OK)) {
       gchar error_message[BUF_SIZE], *dir_internal;
-      GtkWindow *window = tw ? GTK_WINDOW (tw->window) : NULL;
+      GtkWindow *window = tw ? GTK_WINDOW (tw) : NULL;
 
       dir_internal = charset_to_internal (dirname,
                                           conf.charset_filename,
@@ -512,7 +512,7 @@ open_dir_images (const gchar   *dir,
    {
       gint pagenum;
       tw_tmp = tv->thumb_window;
-      gdk_window_raise (tw_tmp->window->window);
+      gdk_window_raise (GTK_WIDGET (tw_tmp)->window);
       pagenum = gtk_notebook_page_num (GTK_NOTEBOOK (tw_tmp->notebook),
                                        tv->container);
       gtk_notebook_set_page (GTK_NOTEBOOK (tw_tmp->notebook), pagenum);
@@ -562,11 +562,11 @@ open_dir_images (const gchar   *dir,
    } else {
       tw_tmp = select_thumbnail_window (tw);
       if (conf.thumbwin_raise_window)
-         gdk_window_raise (tw_tmp->window->window);
+         gdk_window_raise (GTK_WIDGET (tw_tmp)->window);
 
-      tv = thumbwin_find_thumbtable (tw_tmp, THUMBWIN_CURRENT_PAGE);
+      tv = gimv_thumb_win_find_thumbtable (tw_tmp, GIMV_THUMB_WIN_CURRENT_PAGE);
       if (tw_tmp->pagenum < 1 || tv) {
-         newtab = thumbwin_create_new_tab (tw_tmp);
+         newtab = gimv_thumb_win_create_new_tab (tw_tmp);
          if (!newtab)
             goto FUNC_END;
       } else {
@@ -646,8 +646,8 @@ cb_archive_action_performed (FRArchive *archive,
                              FRProcError error, 
                              gpointer data)
 {
-   ThumbWindow *tw = data;
-   GtkWindow *window = tw ? GTK_WINDOW (tw->window) : NULL;
+   GimvThumbWin *tw = data;
+   GtkWindow *window = tw ? GTK_WINDOW (tw) : NULL;
 
    if (error != FR_PROC_ERROR_NONE) {
       if (error == FR_PROC_ERROR_COMMAND_NOT_FOUND) {
@@ -700,11 +700,11 @@ cb_archive_destroy (FRArchive *archive,
 
 gint
 open_archive_images (const gchar   *filename,
-                     ThumbWindow   *tw,
+                     GimvThumbWin  *tw,
                      ThumbLoadType  type)
 {
    FRArchive *archive;
-   ThumbWindow *tw_tmp;
+   GimvThumbWin *tw_tmp;
    ThumbView *tv;
    GtkWidget *newtab;
    gboolean success;
@@ -719,7 +719,7 @@ open_archive_images (const gchar   *filename,
    if (tv) {
       gint pagenum;
       tw_tmp = tv->thumb_window;
-      gdk_window_raise (tw_tmp->window->window);
+      gdk_window_raise (GTK_WIDGET (tw_tmp)->window);
       pagenum = gtk_notebook_page_num (GTK_NOTEBOOK (tw_tmp->notebook),
                                        tv->container);
       gtk_notebook_set_page (GTK_NOTEBOOK (tw_tmp->notebook), pagenum);
@@ -772,9 +772,9 @@ open_archive_images (const gchar   *filename,
    tw_tmp = select_thumbnail_window (tw);
    if (!tw_tmp) goto ERROR;
 
-   tv = thumbwin_find_thumbtable (tw_tmp, THUMBWIN_CURRENT_PAGE);
+   tv = gimv_thumb_win_find_thumbtable (tw_tmp, GIMV_THUMB_WIN_CURRENT_PAGE);
    if (tw_tmp->pagenum < 1 || tv) {
-      newtab = thumbwin_create_new_tab (tw_tmp);
+      newtab = gimv_thumb_win_create_new_tab (tw_tmp);
    } else {
       gint pagenum;
       pagenum = gtk_notebook_get_current_page (GTK_NOTEBOOK(tw_tmp->notebook));
@@ -784,7 +784,7 @@ open_archive_images (const gchar   *filename,
    /* get file list from archive */
    success = fr_archive_load (archive, filename);
    if (!success) {
-      GtkWindow *window = tw_tmp ? GTK_WINDOW (tw_tmp->window) : NULL;
+      GtkWindow *window = tw_tmp ? GTK_WINDOW (tw_tmp) : NULL;
       gtk_object_unref (GTK_OBJECT (archive));
       /* gtk_object_remove_data (GTK_OBJECT (archive), "progress-bar"); */
       gtkutil_message_dialog (_("Error!!"),
@@ -810,7 +810,8 @@ ERROR:
       gtk_progress_bar_update (GTK_PROGRESS_BAR(tw->progressbar), 0.0);
    }
    if (tw_tmp) {
-      thumbwin_set_statusbar_page_info (tw_tmp, THUMBWIN_CURRENT_PAGE);
+      gimv_thumb_win_set_statusbar_page_info (tw_tmp,
+                                              GIMV_THUMB_WIN_CURRENT_PAGE);
    }
    return THUMB_LOAD_DONE;
 }
@@ -825,7 +826,7 @@ ERROR:
  *  Return : Return TRUE if success or canceled by user. 
  */
 gint
-open_dirs (FilesLoader *files, ThumbWindow *tw,
+open_dirs (FilesLoader *files, GimvThumbWin *tw,
            ThumbLoadType type, gboolean scan_subdir)
 {
    gint i;
@@ -869,7 +870,7 @@ open_dirs (FilesLoader *files, ThumbWindow *tw,
  *  Return : Return TRUE if success or canceled by user. 
  */
 gint
-open_images_dirs (GList *list, ThumbWindow *tw,
+open_images_dirs (GList *list, GimvThumbWin *tw,
                   ThumbLoadType type, gboolean scan_subdir)
 {
    FilesLoader *files;
@@ -1072,7 +1073,7 @@ cb_filebrowser_ok_sel (GtkWidget *widget, FileSel *filesel)
       } else if (!(conf.detect_filetype_by_ext)
                  || gimv_image_detect_type_by_ext (filename))
       {
-         ImageInfo *info = image_info_get (filename);
+         GimvImageInfo *info = gimv_image_info_get (filename);
          if (info)
             iw = gimv_image_win_open_window_auto (info);
       } else {
@@ -1094,9 +1095,9 @@ cb_filebrowser_ok_sel (GtkWidget *widget, FileSel *filesel)
 static void
 cb_filebrowser_close (GtkWidget *widget, gpointer parent)
 {
-   ThumbWindow *tw = parent;
+   GimvThumbWin *tw = parent;
 
-   if (tw && g_list_find (thumbwin_get_list(), tw)) {
+   if (tw && g_list_find (gimv_thumb_win_get_list(), tw)) {
       tw->open_dialog = NULL;
    }
 }
@@ -1121,13 +1122,13 @@ create_filebrowser (gpointer parent)
 
    filesel = g_new0 (FileSel, 1);
    filesel->filebrowser = filebrowser;
-   filesel->tw          = (ThumbWindow *) parent;
+   filesel->tw          = (GimvThumbWin *) parent;
    gtk_object_set_data_full (GTK_OBJECT (filebrowser), "filesel",
                              filesel, (GtkDestroyNotify) g_free);
 
    if (filesel->tw)
       gtk_window_set_transient_for (GTK_WINDOW (filebrowser),
-                                    GTK_WINDOW (filesel->tw->window));
+                                    GTK_WINDOW (filesel->tw));
 
 #ifdef USE_GTK2
    gtk_file_selection_set_select_multiple (GTK_FILE_SELECTION(filebrowser),
