@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: fileload.h,v 1.8.2.2 2003/05/15 13:58:14 makeinu Exp $
+ * $Id: fileload.h,v 1.11 2003/06/15 16:14:53 makeinu Exp $
  */
 
 #ifndef __FILE_H__
@@ -93,21 +93,21 @@ void         files_loader_progress_update         (FilesLoader   *files,
 
 gint         open_image_files_in_image_view     (FilesLoader     *files);
 gint         open_image_files_in_thumbnail_view (FilesLoader     *files,
-                                                 ThumbWindow     *tw);
+                                                 GimvThumbWin    *tw);
 gint         open_image_files                   (FilesLoader     *files);
 gint         open_dir_images                    (const gchar     *dirname,
-                                                 ThumbWindow     *tw,
+                                                 GimvThumbWin    *tw,
                                                  ThumbLoadType    type,
                                                  ScanSubDirType   scan_subdir);
 gint         open_archive_images                (const gchar     *filename,
-                                                 ThumbWindow     *tw,
+                                                 GimvThumbWin    *tw,
                                                  ThumbLoadType    type);
 gint         open_dirs                          (FilesLoader     *files,
-                                                 ThumbWindow     *tw,
+                                                 GimvThumbWin    *tw,
                                                  ThumbLoadType    type,
                                                  gboolean         scan_subdir);
 gint         open_images_dirs                   (GList           *list,
-                                                 ThumbWindow     *tw,
+                                                 GimvThumbWin    *tw,
                                                  ThumbLoadType    type,
                                                  gboolean         scan_subdir);
 
