@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: fileutil.c,v 1.15.2.6 2003/05/21 14:39:21 makeinu Exp $
+ * $Id: fileutil.c,v 1.18 2003/07/05 18:00:14 makeinu Exp $
  */
 
 #include <stdio.h>
@@ -244,7 +244,7 @@ mkdirs (const char *path)
    while (path[i] && i < MAX_PATH_LEN) {
       ss[ii++] = path[i];
       ss[ii] = '\0';
-      if (path[i] == '/') {
+      if (i + 1 < MAX_PATH_LEN && path[i + 1] == '/') {
          if (!file_exists(ss)) {
             if (!makedir(ss))
                return FALSE;
