@@ -19,14 +19,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- *  $Id: fr-archive.c,v 1.13.2.3 2003/05/13 11:25:56 makeinu Exp $
+ *  $Id: fr-archive.c,v 1.18 2003/06/18 09:26:55 makeinu Exp $
  */
 
 #include <unistd.h>
 #include <string.h>
 #include <stdio.h>
 #include <glib.h>
-#include "image_info.h"
+#include "gimv_image_info.h"
 #include "fileutil.h"
 #include "fr-archive.h"
 #include "fr-command.h"
@@ -360,13 +360,13 @@ fr_archive_rename (FRArchive *archive,
 /* -- add -- */
 
 
-static ImageInfo *
+static GimvImageInfo *
 find_file_in_archive (FRArchive *archive, char *path)
 {
    GList *scan;
 
    for (scan = archive->command->file_list; scan; scan = scan->next) {
-      ImageInfo *fdata = scan->data;
+      GimvImageInfo *fdata = scan->data;
 		
       if (strcmp (path, fdata->filename) == 0)
          return fdata;
@@ -388,7 +388,7 @@ get_files_in_archive (FRArchive *archive,
    for (scan = file_list; scan; scan = scan->next) {
       gchar *filename = scan->data;
       gchar *fullpath;
-      ImageInfo *fdata;
+      GimvImageInfo *fdata;
 
 
       fdata = find_file_in_archive (archive, filename);
@@ -719,14 +719,14 @@ fr_archive_extract (FRArchive *archive,
 
       scan = archive->command->file_list;
       for (; scan; scan = scan->next) {
-         ImageInfo *fdata = scan->data;
+         GimvImageInfo *fdata = scan->data;
          file_list = g_list_prepend (file_list, g_strdup (fdata->filename));
       }
    }
 
    filtered = NULL;
    for (scan = file_list; scan; scan = scan->next) {
-      ImageInfo *fdata;
+      GimvImageInfo *fdata;
       char *filename = scan->data;
       char full_name[4096];
 
