@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gfileutil.c,v 1.31.2.8 2003/05/15 13:58:14 makeinu Exp $
+ * $Id: gfileutil.c,v 1.41 2003/07/06 16:46:21 makeinu Exp $
  */
 
 #include <gtk/gtk.h>
@@ -31,15 +31,15 @@
 #include <utime.h>
 
 #include "charset.h"
-#include "comment.h"
 #include "fileutil.h"
 #include "fr-archive.h"
 #include "gfileutil.h"
+#include "gimv_comment.h"
 #include "gimv_image.h"
+#include "gimv_thumb.h"
 #include "gtkutils.h"
 #include "intl.h"
 #include "prefs.h"
-#include "thumbnail.h"
 
 #ifndef BUF_SIZE
 #define BUF_SIZE 4096
@@ -1275,7 +1275,7 @@ get_dest_cache_dir (const gchar *src_file,
    if (!src_file || !dest_dir || !cache_type) return NULL;
 
    dest_file = g_strconcat (dest_dir, g_basename (src_file), NULL);
-   dest_cache_dir = thumbsupport_get_thumb_cache_path (dest_file, cache_type);
+   dest_cache_dir = gimv_thumb_cache_get_path (dest_file, cache_type);
 
    if (dest_cache_dir) {
       gchar *endchr;
@@ -1304,7 +1304,7 @@ get_dest_comment_dir (const gchar *src_file,
    if (!src_file || !dest_dir) return NULL;
 
    dest_file = g_strconcat (dest_dir, g_basename (src_file), NULL);
-   dest_comment_dir = comment_get_path (dest_file);
+   dest_comment_dir = gimv_comment_get_path (dest_file);
 
    if (dest_comment_dir) {
       gchar *endchr;
@@ -1343,9 +1343,9 @@ do_file_operate (const gchar *src_file,
    gchar message[BUF_SIZE];
 
    /* FIXME!! */ /* get cache file & dir */
-   src_cache        = thumbnail_find_thumbcache (src_file, &cache_type);
+   src_cache        = gimv_thumb_find_thumbcache (src_file, &cache_type);
    dest_cache_dir   = get_dest_cache_dir (src_file, dest_dir, cache_type);
-   src_comment      = comment_find_file (src_file);
+   src_comment      = gimv_comment_find_file (src_file);
    dest_comment_dir = get_dest_comment_dir (src_file, dest_dir);
 
    /* if move to different file system, change to copy */
