@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_comment.c,v 1.1 2003/07/06 16:46:21 makeinu Exp $
+ * $Id: gimv_comment.c,v 1.2 2003/09/28 11:00:10 makeinu Exp $
  */
 
 /*
@@ -77,7 +77,7 @@ GimvCommentDataEntry gimv_comment_data_entry[] = {
    {"X-IMG-Model",                N_("Model"),             NULL, TRUE, FALSE, TRUE,  FALSE, NULL},
    {"X-IMG-Comment-Time",         N_("Comment Time"),      NULL, TRUE, TRUE,  FALSE, FALSE, defval_time},
    {"X-IMG-File-URL",             N_("URL"),               NULL, TRUE, TRUE,  TRUE,  FALSE, defval_file_url},
-   {"X-IMG-File-Path-In-Arcvhie", N_("Path in Arcvhie"),   NULL, TRUE, TRUE,  TRUE,  FALSE, defval_file_path_in_archive},
+   {"X-IMG-File-Path-In-Archive", N_("Path in Archive"),   NULL, TRUE, TRUE,  TRUE,  FALSE, defval_file_path_in_archive},
    {"X-IMG-File-MTime",           N_("Modification Time"), NULL, TRUE, TRUE,  TRUE,  FALSE, defval_file_mtime},
    {"X-IMG-Image-Type",           N_("Image Type"),        NULL, TRUE, TRUE,  TRUE,  FALSE, defval_img_type},
    {"X-IMG-Image-Size",           N_("Image Size"),        NULL, TRUE, TRUE,  TRUE,  FALSE, defval_img_size},
