@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_comment_view.c,v 1.2 2003/07/07 15:24:21 makeinu Exp $
+ * $Id: gimv_comment_view.c,v 1.3 2003/09/28 05:27:48 makeinu Exp $
  */
 
 #include "gimv_comment_view.h"
@@ -673,7 +673,7 @@ create_note_page (GimvCommentView *cv)
 
    cv->note_page = scrolledwin = gtk_scrolled_window_new (NULL, NULL);
    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(scrolledwin),
-                                   GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
+                                   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
    gtk_widget_show (scrolledwin);
 
 #ifdef USE_GTK2
@@ -768,6 +768,7 @@ static void
 gimv_comment_view_set_combo_list (GimvCommentView *cv)
 {
    GList *list;
+   GtkWidget *first_label = NULL;
 
    g_return_if_fail (cv);
    g_return_if_fail (cv->key_combo);
@@ -812,8 +813,12 @@ gimv_comment_view_set_combo_list (GimvCommentView *cv)
                           GTK_SIGNAL_FUNC (cb_combo_select), cv);
       gtk_signal_connect (GTK_OBJECT(label), "deselect",
                           GTK_SIGNAL_FUNC (cb_combo_deselect), cv);
+
+      if (!first_label)
+         first_label = label;
    }
-   /* gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (cv->key_combo)->entry), "\0"); */
+
+   gtk_list_item_select (GTK_LIST_ITEM (first_label));
 }
 
 
