@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_image.c,v 1.53.2.10 2003/05/15 13:58:15 makeinu Exp $
+ * $Id: gimv_image.c,v 1.66 2003/07/20 14:38:10 makeinu Exp $
  */
 
 #include "gimageview.h"
@@ -28,12 +28,12 @@
 
 #include "gimv_anim.h"
 #include "gimv_image.h"
+#include "gimv_image_loader.h"
 #include "gimv_mime_types.h"
 #include "prefs.h"
 #include "fileutil.h"
 #include "gimv_io.h"
-#include "image_saver.h"
-#include "image_loader.h"
+#include "gimv_image_saver.h"
 
 #if defined (HAVE_GDK_PIXBUF)
 #  include <gdk-pixbuf/gdk-pixbuf.h>
@@ -45,6 +45,103 @@ typedef GdkImlibImage GimvRawImage;
 #endif /* HAVE_GDK_PIXBUF */
 
 
+static void gimv_image_class_init    (GimvImageClass *klass);
+static void gimv_image_init          (GimvImage      *image);
+static void gimv_image_destroy       (GtkObject      *object);
+static void gimv_image_backend_init  (void);
+
+
+static GtkObjectClass *parent_class = NULL;
+
+
+guint
+gimv_image_get_type (void)
+{
+   static guint gimv_image_type = 0;
+
+   if (!gimv_image_type) {
+      static const GtkTypeInfo gimv_image_info = {
+         "GimvImage",
+         sizeof (GimvImage),
+         sizeof (GimvImageClass),
+         (GtkClassInitFunc) gimv_image_class_init,
+         (GtkObjectInitFunc) gimv_image_init,
+         NULL,
+         NULL,
+         (GtkClassInitFunc) NULL,
+      };
+
+      gimv_image_type = gtk_type_unique (gtk_object_get_type (),
+                                         &gimv_image_info);
+   }
+
+   return gimv_image_type;
+}
+
+
+static void
+gimv_image_class_init (GimvImageClass *klass)
+{
+   GtkObjectClass *object_class;
+
+   gimv_image_backend_init ();
+
+   object_class = (GtkObjectClass *) klass;
+   parent_class = gtk_type_class (gtk_object_get_type ());
+
+   object_class->destroy  = gimv_image_destroy;
+}
+
+
+static void
+gimv_image_init (GimvImage *image)
+{
+   image->image           = NULL;
+   image->angle           = GIMV_IMAGE_ROTATE_0;
+   image->flags           = 0;
+   /* image->ref_count       = 1; */
+   image->comments        = NULL;
+   image->additional_data = NULL;
+
+#ifdef USE_GTK2
+   gtk_object_ref (GTK_OBJECT (image));
+   gtk_object_sink (GTK_OBJECT (image));
+#endif
+}
+
+
+static void
+gimv_image_destroy (GtkObject *object)
+{
+   GimvImage *image = GIMV_IMAGE (object);
+   GimvRawImage *rawimage;
+
+   g_return_if_fail (image);
+
+   rawimage = (GimvRawImage *) image->image;
+
+#if defined (HAVE_GDK_PIXBUF)
+   if (rawimage)
+      gdk_pixbuf_unref (rawimage);
+#elif defined (HAVE_GDK_IMLIB)
+   gdk_imlib_kill_image (rawimage);
+#endif /* HAVE_GDK_PIXBUF */
+   image->image = NULL;
+
+   gimv_image_free_comments (image);
+
+   if (GTK_OBJECT_CLASS (parent_class)->destroy)
+      (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
+}
+
+
+GimvImage *
+gimv_image_new (void)
+{
+   GimvImage *image = GIMV_IMAGE (gtk_type_new (GIMV_TYPE_IMAGE));
+   return image;
+}
+
 
 /****************************************************************************
  *
@@ -52,20 +149,20 @@ typedef GdkImlibImage GimvRawImage;
  *
  ****************************************************************************/
 void
-gimv_image_init (void)
+gimv_image_backend_init (void)
 {
 #if defined (HAVE_GDK_PIXBUF)
 #elif defined (HAVE_GDK_IMLIB)
    /*
-     GdkImlibInitParams *imlib_param;
+   GdkImlibInitParams *imlib_param;
 
-     imlib_param = g_new0 (GdkImlibInitParams, 1);
+   imlib_param = g_new0 (GdkImlibInitParams, 1);
 
-     imlib_param->flags = PARAMS_REMAP | PARAMS_FASTRENDER;
-     imlib_param->remap = 0;
-     imlib_param->fastrender = 0;
-     gdk_imlib_init_params(imlib_param);
-     g_free (imlib_param);
+   imlib_param->flags = PARAMS_REMAP | PARAMS_FASTRENDER;
+   imlib_param->remap = 0;
+   imlib_param->fastrender = 0;
+   gdk_imlib_init_params(imlib_param);
+   g_free (imlib_param);
    */
    gdk_imlib_init ();
    gtk_widget_push_visual (gdk_imlib_get_visual());
@@ -74,49 +171,43 @@ gimv_image_init (void)
 }
 
 
-void
-gimv_image_memset (GimvImage *image)
-{
-   image->image           = NULL;
-   image->angle           = GIMV_IMAGE_ROTATE_0;
-   image->flags           = 0;
-   image->ref_count       = 1;
-   image->comments        = NULL;
-   image->additional_data = NULL;
-}
-
-
-GimvImage *
-gimv_image_new (void)
-{
-   GimvImage *image = g_new0 (GimvImage, 1);
-
-   gimv_image_memset (image);
-
-   return image;
-}
-
-
 GimvImage *
 gimv_image_load_file (const gchar *filename, gboolean animation)
 {
-   ImageLoader *loader;
+   GimvImageLoader *loader;
    GimvImage *image;
 
-   loader = image_loader_new_with_file_name (filename);
+   loader = gimv_image_loader_new_with_file_name (filename);
    if (!loader) return NULL;
 
-   image_loader_set_as_animation (loader, animation);
-   image_loader_load (loader);
-   image = image_loader_get_image (loader);
+   gimv_image_loader_set_as_animation (loader, animation);
+   gimv_image_loader_load (loader);
+   image = gimv_image_loader_get_image (loader);
    if (image)
       gimv_image_ref (image);
-   image_loader_unref (loader);
+   gimv_image_loader_unref (loader);
 
    return image;
 }
 
 
+gboolean
+gimv_image_save_file  (GimvImage   *image,
+                       const gchar *filename,
+                       const gchar *format)
+{
+   GimvImageSaver *saver;
+   gboolean retval;
+
+   saver = gimv_image_saver_new_with_attr (image, filename, format);
+   /* gimv_image_saver_set_param (data, use_specific_data) */
+   retval = gimv_image_saver_save (saver);
+   gimv_image_saver_unref (saver);
+
+   return retval;
+}
+
+
 #if defined (HAVE_GDK_PIXBUF)
 static void
 free_rgb_buffer (guchar *pixels, gpointer data)
@@ -151,7 +242,7 @@ gimv_image_create_from_data (guchar *data, gint width, gint height, gboolean alp
 #endif /* HAVE_GDK_PIXBUF */
 
    if (!image->image) {
-      gimv_image_finalize (image);
+      gimv_image_unref (image);
       image = NULL;
    }
 
@@ -181,7 +272,7 @@ gimv_image_create_from_drawable (GdkDrawable *drawable, gint x, gint y,
 #endif /* HAVE_GDK_PIXBUF */
 
    if (!image->image) {
-      gimv_image_finalize (image);
+      gimv_image_unref (image);
       image = NULL;
    }
 
@@ -578,7 +669,7 @@ gimv_image_scale_get_pixmap (GimvImage *image,
       GimvImage *dest_image;
       dest_image = gimv_image_scale (image, width, height);
       gimv_image_get_pixmap_and_mask (dest_image, pixmap_return, mask_return);
-      gimv_image_finalize (dest_image);
+      gimv_image_unref (dest_image);
    }
 #elif defined (HAVE_GDK_IMLIB)
    gdk_imlib_render (image->image, width, height);
@@ -749,10 +840,7 @@ gimv_image_get_comment (GimvImage *image, const gchar *key)
 GimvImage  *
 gimv_image_ref (GimvImage *image)
 {
-   g_return_val_if_fail (image, NULL);
-
-   image->ref_count++;
-
+   gtk_object_ref (GTK_OBJECT (image));
    return image;
 }
 
@@ -760,14 +848,7 @@ gimv_image_ref (GimvImage *image)
 void
 gimv_image_unref (GimvImage *image)
 {
-   g_return_if_fail (image);
-   g_return_if_fail (image->ref_count > 0);
-
-   image->ref_count--;
-
-   if (image->ref_count < 1) {
-      gimv_image_finalize (image);
-   }
+   gtk_object_unref (GTK_OBJECT (image));
 }
 
 
@@ -794,43 +875,6 @@ gimv_image_free_comments (GimvImage *image)
 }
 
 
-void
-gimv_image_finalize (GimvImage *image)
-{
-   GimvRawImage *rawimage;
-
-   g_return_if_fail (image);
-
-   rawimage = (GimvRawImage *) image->image;
-
-   if (gimv_image_is_anim (image))
-      gimv_anim_delete_private_data ((GimvAnim *) image);
-
-#if defined (HAVE_GDK_PIXBUF)
-   if (rawimage)
-      gdk_pixbuf_unref (rawimage);
-#elif defined (HAVE_GDK_IMLIB)
-   gdk_imlib_kill_image (rawimage);
-#endif /* HAVE_GDK_PIXBUF */
-
-   gimv_image_free_comments (image);
-
-   g_free (image);
-}
-
-
-gboolean
-gimv_image_save_file  (GimvImage   *image,
-                       const gchar *filename,
-                       const gchar *format,
-                       gpointer     data,
-                       gboolean     use_specific_data)
-{
-   return image_saver_save_image (image, filename, format,
-                                  data, use_specific_data);
-}
-
-
 /*
  *  gimv_image_detect_type_by_ext:
  *     @ Detect image format by filename extension.
@@ -846,18 +890,6 @@ gimv_image_detect_type_by_ext (const gchar *str)
 }
 
 
-gboolean
-gimv_image_is_anim (GimvImage *image)
-{
-   g_return_val_if_fail (image, FALSE);
-
-   if (image->flags & GIMV_IMAGE_ANIMATION_FLAG)
-      return TRUE;
-
-   return FALSE;
-}
-
-
 
 /****************************************************************************
  *  FIXME!!
@@ -1129,7 +1161,7 @@ pixel_apply_layer_mode(guchar *src1,
 	
    alpha = (ha1 || ha2) ? MAX(b1, b2) - 1 : b1;
    switch (mode) {
-   case DISSOLVE_MODE:
+   case GIMV_IMAGE_DISSOLVE_MODE:
       for (b = 0; b < alpha; b++)
          dest[b] = src2[b];
       /*  dissolve if random value is > opacity  */
@@ -1137,7 +1169,7 @@ pixel_apply_layer_mode(guchar *src1,
       dest[alpha] = (t > src2[alpha]) ? 0 : src2[alpha];
       break;
 
-   case MULTIPLY_MODE:
+   case GIMV_IMAGE_MULTIPLY_MODE:
       for (b = 0; b < alpha; b++)
          dest[b] = (src1[b] * src2[b]) / 255;
       if (ha1 && ha2)
@@ -1146,7 +1178,7 @@ pixel_apply_layer_mode(guchar *src1,
          dest[alpha] = src2[alpha];
       break;
 
-   case SCREEN_MODE:
+   case GIMV_IMAGE_SCREEN_MODE:
       for (b = 0; b < alpha; b++)
          dest[b] = 255 - ((255 - src1[b]) * (255 - src2[b])) / 255;
       if (ha1 && ha2)
@@ -1155,7 +1187,7 @@ pixel_apply_layer_mode(guchar *src1,
          dest[alpha] = src2[alpha];
       break;
 
-   case OVERLAY_MODE:
+   case GIMV_IMAGE_OVERLAY_MODE:
       for (b = 0; b < alpha; b++) {
          /* screen */
          t = 255 - ((255 - src1[b]) * (255 - src2[b])) / 255;
@@ -1169,7 +1201,7 @@ pixel_apply_layer_mode(guchar *src1,
          dest[alpha] = src2[alpha];
       break;
 
-   case DIFFERENCE_MODE:
+   case GIMV_IMAGE_DIFFERENCE_MODE:
       for (b = 0; b < alpha; b++) {
          t = src1[b] - src2[b];
          dest[b] = (t < 0) ? -t : t;
@@ -1180,7 +1212,7 @@ pixel_apply_layer_mode(guchar *src1,
          dest[alpha] = src2[alpha];
       break;
 
-   case ADDITION_MODE:
+   case GIMV_IMAGE_ADDITION_MODE:
       for (b = 0; b < alpha; b++) {
          t = src1[b] + src2[b];
          dest[b] = (t > 255) ? 255 : t;
@@ -1191,7 +1223,7 @@ pixel_apply_layer_mode(guchar *src1,
          dest[alpha] = src2[alpha];
       break;
 
-   case SUBTRACT_MODE:
+   case GIMV_IMAGE_SUBTRACT_MODE:
       for (b = 0; b < alpha; b++) {
          t = (gint)src1[b] - (gint)src2[b];
          dest[b] = (t < 0) ? 0 : t;
@@ -1202,7 +1234,7 @@ pixel_apply_layer_mode(guchar *src1,
          dest[alpha] = src2[alpha];
       break;
 
-   case DARKEN_ONLY_MODE:
+   case GIMV_IMAGE_DARKEN_ONLY_MODE:
       for (b = 0; b < alpha; b++) {
          t = src1[b];
          t2 = src2[b];
@@ -1214,7 +1246,7 @@ pixel_apply_layer_mode(guchar *src1,
          dest[alpha] = src2[alpha];
       break;
 
-   case LIGHTEN_ONLY_MODE:
+   case GIMV_IMAGE_LIGHTEN_ONLY_MODE:
       for (b = 0; b < alpha; b++) {
          t = src1[b];
          t2 = src2[b];
@@ -1226,21 +1258,21 @@ pixel_apply_layer_mode(guchar *src1,
          dest[alpha] = src2[alpha];
       break;
 
-   case HUE_MODE:
-   case SATURATION_MODE:
-   case VALUE_MODE:
+   case GIMV_IMAGE_HUE_MODE:
+   case GIMV_IMAGE_SATURATION_MODE:
+   case GIMV_IMAGE_VALUE_MODE:
       red1 = src1[0]; green1 = src1[1]; blue1 = src1[2];
       red2 = src2[0]; green2 = src2[1]; blue2 = src2[2];
       rgb_to_hsv (&red1, &green1, &blue1);
       rgb_to_hsv (&red2, &green2, &blue2);
       switch (mode) {
-      case HUE_MODE:
+      case GIMV_IMAGE_HUE_MODE:
          red1 = red2;
          break;
-      case SATURATION_MODE:
+      case GIMV_IMAGE_SATURATION_MODE:
          green1 = green2;
          break;
-      case VALUE_MODE:
+      case GIMV_IMAGE_VALUE_MODE:
          blue1 = blue2;
          break;
       default:
@@ -1254,7 +1286,7 @@ pixel_apply_layer_mode(guchar *src1,
          dest[3] = src2[3];
       break;
 
-   case COLOR_MODE:
+   case GIMV_IMAGE_COLOR_MODE:
       red1 = src1[0]; green1 = src1[1]; blue1 = src1[2];
       red2 = src2[0]; green2 = src2[1]; blue2 = src2[2];
       rgb_to_hls (&red1, &green1, &blue1);
@@ -1269,7 +1301,7 @@ pixel_apply_layer_mode(guchar *src1,
          dest[3] = src2[3];
       break;
 
-   case NORMAL_MODE:
+   case GIMV_IMAGE_NORMAL_MODE:
    default:
       for (b = 0; b < b2; b++) dest[b] = src2[b];
       break;
@@ -1415,7 +1447,7 @@ gimv_image_rgba2rgb (GimvImage *image,
       } else {
         gimv_image_add_layer (src + (width * i * 4),
                                width, 0, 4,
-                               0, NORMAL_MODE,
+                               0, GIMV_IMAGE_NORMAL_MODE,
                                dest + (width * i * 3));
       }
    }
