@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_image_view.h,v 1.1.2.2 2003/06/10 14:54:32 makeinu Exp $
+ * $Id: gimv_image_view.h,v 1.8 2003/08/01 16:21:25 makeinu Exp $
  */
 
 #ifndef __GIMV_IMAGE_VIEW_H__
@@ -27,12 +27,14 @@
 #include "gimageview.h"
 
 #include "gimv_image.h"
-#include "image_info.h"
-#include "image_loader.h"
+#include "gimv_image_info.h"
+#include "gimv_image_loader.h"
 
-#define GIMV_IMAGE_VIEW(obj)         GTK_CHECK_CAST (obj, gimv_image_view_get_type (), GimvImageView)
-#define GIMV_IMAGE_VIEW_CLASS(klass) GTK_CHECK_CLASS_CAST (klass, gimv_image_view_get_type, GimvImageViewClass)
-#define GIMV_IS_IMAGE_VIEW(obj)      GTK_CHECK_TYPE (obj, gimv_image_view_get_type ())
+#define GIMV_TYPE_IMAGE_VIEW            (gimv_image_view_get_type ())
+#define GIMV_IMAGE_VIEW(obj)            (GTK_CHECK_CAST (obj, gimv_image_view_get_type (), GimvImageView))
+#define GIMV_IMAGE_VIEW_CLASS(klass)    (GTK_CHECK_CLASS_CAST (klass, gimv_image_view_get_type, GimvImageViewClass))
+#define GIMV_IS_IMAGE_VIEW(obj)         (GTK_CHECK_TYPE (obj, gimv_image_view_get_type ()))
+#define GIMV_IS_IMAGE_VIEW_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), GIMV_TYPE_IMAGE_VIEW))
 
 
 #define GIMV_IMAGE_VIEW_DEFAULT_VIEW_MODE N_("Default Image Viewer")
@@ -48,6 +50,9 @@ typedef enum
    GIMV_IMAGE_VIEW_ZOOM_IN,   /* Increase Image Size 5% */
    GIMV_IMAGE_VIEW_ZOOM_OUT,  /* Decrease Image Size 5% */
    GIMV_IMAGE_VIEW_ZOOM_FIT,  /* Fit to Widnow */
+   GIMV_IMAGE_VIEW_ZOOM_FIT_ZOOM_OUT_ONLY,
+   GIMV_IMAGE_VIEW_ZOOM_FIT_WIDTH,
+   GIMV_IMAGE_VIEW_ZOOM_FIT_HEIGHT,
    GIMV_IMAGE_VIEW_ZOOM_10,
    GIMV_IMAGE_VIEW_ZOOM_25,
    GIMV_IMAGE_VIEW_ZOOM_50,
@@ -152,10 +157,10 @@ struct GimvImageView_Tag
    } player;
 
    /* information about image */
-   ImageInfo       *info;
+   GimvImageInfo   *info;
 
    /* image */
-   ImageLoader     *loader;
+   GimvImageLoader *loader;
    GimvImage       *image;
 
    /* imageview status */
@@ -169,11 +174,12 @@ struct GimvImageViewClass_Tag
 {
    GtkVBoxClass parent_class;
 
+   /* signals */
    void     (*image_changed)     (GimvImageView *iv);
    void     (*load_start)        (GimvImageView *iv,
-                                  ImageInfo     *info);
+                                  GimvImageInfo *info);
    void     (*load_end)          (GimvImageView *iv,
-                                  ImageInfo     *info,
+                                  GimvImageInfo *info,
                                   gboolean       cancel);
    void     (*set_list)          (GimvImageView *iv);
    void     (*unset_list)        (GimvImageView *iv);
@@ -183,7 +189,7 @@ struct GimvImageViewClass_Tag
    void     (*toggle_buffer)     (GimvImageView *iv,
                                   gboolean       buffered);
    void     (*thumbnail_created) (GimvImageView *iv,
-                                  ImageInfo     *info);
+                                  GimvImageInfo *info);
 
    gboolean (*image_pressed)     (GimvImageView  *iv,
                                   GdkEventButton *button);
@@ -196,78 +202,78 @@ struct GimvImageViewClass_Tag
 
 GList     *gimv_image_view_get_list               (void);
 guint      gimv_image_view_get_type               (void);
-GtkWidget *gimv_image_view_new                    (ImageInfo   *info);
+GtkWidget *gimv_image_view_new                    (GimvImageInfo  *info);
 
-void       gimv_image_view_change_image           (GimvImageView   *iv,
-                                                   ImageInfo   *info);
-void       gimv_image_view_change_image_info      (GimvImageView   *iv,
-                                                   ImageInfo   *info);
-void       gimv_image_view_draw_image             (GimvImageView   *iv);
-void       gimv_image_view_show_image             (GimvImageView   *iv);
+void       gimv_image_view_change_image           (GimvImageView  *iv,
+                                                   GimvImageInfo  *info);
+void       gimv_image_view_change_image_info      (GimvImageView  *iv,
+                                                   GimvImageInfo  *info);
+void       gimv_image_view_draw_image             (GimvImageView  *iv);
+void       gimv_image_view_show_image             (GimvImageView  *iv);
 
-void       gimv_image_view_create_thumbnail       (GimvImageView      *iv);
+void       gimv_image_view_create_thumbnail       (GimvImageView  *iv);
 
 /* creating/show/hide child widgets */
-void       gimv_image_view_change_view_mode       (GimvImageView      *iv,
+void       gimv_image_view_change_view_mode       (GimvImageView  *iv,
                                                    const gchar    *label);
 GtkWidget *gimv_image_view_create_zoom_menu       (GtkWidget      *window,
-                                                   GimvImageView      *iv,
+                                                   GimvImageView  *iv,
                                                    const gchar    *path);
 GtkWidget *gimv_image_view_create_rotate_menu     (GtkWidget      *window,
-                                                   GimvImageView      *iv,
+                                                   GimvImageView  *iv,
                                                    const gchar    *path);
 GtkWidget *gimv_image_view_create_popup_menu      (GtkWidget      *window,
-                                                   GimvImageView      *iv,
+                                                   GimvImageView  *iv,
                                                    const gchar    *path);
 GtkWidget *gimv_image_view_create_movie_menu      (GtkWidget      *window,
-                                                   GimvImageView      *iv,
+                                                   GimvImageView  *iv,
                                                    const gchar    *path);
 GtkWidget *gimv_image_view_create_view_modes_menu (GtkWidget      *window,
-                                                   GimvImageView      *iv,
+                                                   GimvImageView  *iv,
                                                    const gchar    *path);
-void       gimv_image_view_set_progressbar        (GimvImageView      *iv,
+void       gimv_image_view_set_progressbar        (GimvImageView  *iv,
                                                    GtkWidget      *progressbar);
-void       gimv_image_view_set_player_visible     (GimvImageView      *iv,
+void       gimv_image_view_set_player_visible     (GimvImageView  *iv,
                                                    GimvImageViewPlayerVisibleType type);
 GimvImageViewPlayerVisibleType
-           gimv_image_view_get_player_visible     (GimvImageView      *iv);
-void       gimv_image_view_show_scrollbar         (GimvImageView      *iv);
-void       gimv_image_view_hide_scrollbar         (GimvImageView      *iv);
-void       gimv_image_view_popup_menu             (GimvImageView      *iv,
+           gimv_image_view_get_player_visible     (GimvImageView  *iv);
+void       gimv_image_view_show_scrollbar         (GimvImageView  *iv);
+void       gimv_image_view_hide_scrollbar         (GimvImageView  *iv);
+void       gimv_image_view_popup_menu             (GimvImageView  *iv,
                                                    GdkEventButton *event);
-void       gimv_image_view_set_bg_color           (GimvImageView      *iv,
+void       gimv_image_view_set_bg_color           (GimvImageView  *iv,
                                                    gint            red,
                                                    gint            green,
                                                    gint            blue);
-void       gimv_image_view_open_navwin            (GimvImageView      *iv,
-                                                   gfloat          x_root,
-                                                   gfloat          y_root);
-void       gimv_image_view_set_fullscreen         (GimvImageView      *iv,
+void       gimv_image_view_open_navwin            (GimvImageView  *iv,
+                                                   gint            x_root,
+                                                   gint            y_root);
+void       gimv_image_view_set_fullscreen         (GimvImageView  *iv,
                                                    GtkWindow      *fullscreen);
-void       gimv_image_view_unset_fullscreen       (GimvImageView      *iv);
+void       gimv_image_view_unset_fullscreen       (GimvImageView  *iv);
 
 /* loading */
-void       gimv_image_view_free_image_buf         (GimvImageView   *iv);
-void       gimv_image_view_load_image_buf         (GimvImageView   *iv);
-gboolean   gimv_image_view_is_loading             (GimvImageView   *iv);
-void       gimv_image_view_cancel_loading         (GimvImageView   *iv);
+void       gimv_image_view_free_image_buf         (GimvImageView  *iv);
+void       gimv_image_view_load_image_buf         (GimvImageView  *iv);
+gboolean   gimv_image_view_is_loading             (GimvImageView  *iv);
+void       gimv_image_view_cancel_loading         (GimvImageView  *iv);
 
 /* scalable interface */
-void       gimv_image_view_zoom_image             (GimvImageView   *iv,
+void       gimv_image_view_zoom_image             (GimvImageView  *iv,
                                                    GimvImageViewZoomType zoom,
-                                                   gfloat       x_scale,
-                                                   gfloat       y_scale);
-gboolean   gimv_image_view_get_image_size         (GimvImageView   *iv,
-                                                   gint        *width,
-                                                   gint        *height);
+                                                   gfloat x_scale,
+                                                   gfloat y_scale);
+gboolean   gimv_image_view_get_image_size         (GimvImageView  *iv,
+                                                   gint           *width,
+                                                   gint           *height);
 
 /* rotatable interface */
-void       gimv_image_view_rotate_image           (GimvImageView   *iv,
+void       gimv_image_view_rotate_image           (GimvImageView  *iv,
                                                    GimvImageViewOrientation angle);
-void       gimv_image_view_rotate_ccw             (GimvImageView   *iv);
-void       gimv_image_view_rotate_cw              (GimvImageView   *iv);
+void       gimv_image_view_rotate_ccw             (GimvImageView  *iv);
+void       gimv_image_view_rotate_cw              (GimvImageView  *iv);
 GimvImageViewOrientation
-           gimv_image_view_get_orientation        (GimvImageView   *iv);
+           gimv_image_view_get_orientation        (GimvImageView  *iv);
 
 /* scrollable interface */
 /*
@@ -290,57 +296,57 @@ GimvImageViewOrientation
  *    +------------------------------------+
  *   (0, height)                          (width, height)
  */
-void       gimv_image_view_get_image_frame_size   (GimvImageView   *iv,
-                                                   gint        *fwidth,
-                                                   gint        *fheight);
-gboolean   gimv_image_view_get_view_position      (GimvImageView   *iv,
-                                                   gint        *x,
-                                                   gint        *y);
-void       gimv_image_view_moveto                 (GimvImageView   *iv,
-                                                   gint         x,
-                                                   gint         y);
+void       gimv_image_view_get_image_frame_size   (GimvImageView  *iv,
+                                                   gint           *fwidth,
+                                                   gint           *fheight);
+gboolean   gimv_image_view_get_view_position      (GimvImageView  *iv,
+                                                   gint           *x,
+                                                   gint           *y);
+void       gimv_image_view_moveto                 (GimvImageView  *iv,
+                                                   gint            x,
+                                                   gint            y);
 #define    gimv_image_view_set_view_position(iv, x, y) \
            gimv_image_view_moveto (iv, x, y)
-void       gimv_image_view_reset_scrollbar        (GimvImageView   *iv);
+void       gimv_image_view_reset_scrollbar        (GimvImageView  *iv);
 
 /* playable interface */
-gboolean   gimv_image_view_is_playable            (GimvImageView *iv);
-void       gimv_image_view_playable_play          (GimvImageView *iv);
-void       gimv_image_view_playable_stop          (GimvImageView *iv);
-void       gimv_image_view_playable_pause         (GimvImageView *iv);
-void       gimv_image_view_playable_forward       (GimvImageView *iv);
-void       gimv_image_view_playable_reverse       (GimvImageView *iv);
-void       gimv_image_view_playable_seek          (GimvImageView *iv,
-                                             guint      pos);
-void       gimv_image_view_playable_eject         (GimvImageView *iv);
+gboolean   gimv_image_view_is_playable            (GimvImageView  *iv);
+void       gimv_image_view_playable_play          (GimvImageView  *iv);
+void       gimv_image_view_playable_stop          (GimvImageView  *iv);
+void       gimv_image_view_playable_pause         (GimvImageView  *iv);
+void       gimv_image_view_playable_forward       (GimvImageView  *iv);
+void       gimv_image_view_playable_reverse       (GimvImageView  *iv);
+void       gimv_image_view_playable_seek          (GimvImageView  *iv,
+                                                   guint           pos);
+void       gimv_image_view_playable_eject         (GimvImageView  *iv);
 GimvImageViewPlayableStatus
-           gimv_image_view_playable_get_status    (GimvImageView *iv);
-guint      gimv_image_view_playable_get_length    (GimvImageView *iv);
-guint      gimv_image_view_playable_get_position  (GimvImageView *iv);
+           gimv_image_view_playable_get_status    (GimvImageView  *iv);
+guint      gimv_image_view_playable_get_length    (GimvImageView  *iv);
+guint      gimv_image_view_playable_get_position  (GimvImageView  *iv);
 
 /* list interface */
-void       gimv_image_view_set_list               (GimvImageView       *iv,
-                                                   GList           *list,
-                                                   GList           *current,
-                                                   gpointer         list_owner,
+void       gimv_image_view_set_list               (GimvImageView  *iv,
+                                                   GList          *list,
+                                                   GList          *current,
+                                                   gpointer        list_owner,
                                                    GimvImageViewNextFn  next_fn,
                                                    GimvImageViewPrevFn  prev_fn,
                                                    GimvImageViewNthFn   nth_fn,
                                                    GimvImageViewRemoveListFn remove_list_fn,
-                                                   gpointer         user_data);
-void       gimv_image_view_remove_list            (GimvImageView       *iv,
-                                                   gpointer         list_owner);
-void       gimv_image_view_set_list_self          (GimvImageView       *iv,
-                                                   GList           *list,
-                                                   GList           *current);
-gboolean   gimv_image_view_has_list               (GimvImageView       *iv);
-gint       gimv_image_view_image_list_length      (GimvImageView       *iv);
-gint       gimv_image_view_image_list_position    (GimvImageView       *iv);
-GList     *gimv_image_view_image_list_current     (GimvImageView       *iv);
-void       gimv_image_view_next                   (GimvImageView       *iv);
-void       gimv_image_view_prev                   (GimvImageView       *iv);
-void       gimv_image_view_nth                    (GimvImageView       *iv,
-                                                   guint            nth);
+                                                   gpointer        user_data);
+void       gimv_image_view_remove_list            (GimvImageView  *iv,
+                                                   gpointer        list_owner);
+void       gimv_image_view_set_list_self          (GimvImageView  *iv,
+                                                   GList          *list,
+                                                   GList          *current);
+gboolean   gimv_image_view_has_list               (GimvImageView  *iv);
+gint       gimv_image_view_image_list_length      (GimvImageView  *iv);
+gint       gimv_image_view_image_list_position    (GimvImageView  *iv);
+GList     *gimv_image_view_image_list_current     (GimvImageView  *iv);
+void       gimv_image_view_next                   (GimvImageView  *iv);
+void       gimv_image_view_prev                   (GimvImageView  *iv);
+void       gimv_image_view_nth                    (GimvImageView  *iv,
+                                                   guint           nth);
 
 
 /****************************************************************************
@@ -359,10 +365,10 @@ struct GimvImageViewPlugin_Tag
    gint priority_hint;
 
    gboolean   (*is_supported_fn)     (GimvImageView *iv,
-                                      ImageInfo *info);;
+                                      GimvImageInfo *info);;
    GtkWidget *(*create_fn)           (GimvImageView *iv);
    void       (*create_thumbnail_fn) (GimvImageView *iv,
-                                      const gchar *type);
+                                      const gchar   *type);
    void       (*fullscreen_fn)       (GimvImageView *iv);
 
    GimvImageViewScalableIF     *scalable;
@@ -374,7 +380,7 @@ struct GimvImageViewPlugin_Tag
 
 struct GimvImageViewPlayableIF_Tag {
    gboolean (*is_playable_fn)  (GimvImageView *iv,
-                                ImageInfo *info);
+                                GimvImageInfo *info);
    gboolean (*is_seekable_fn)  (GimvImageView *iv);
    void     (*play_fn)         (GimvImageView *iv);
    void     (*stop_fn)         (GimvImageView *iv);
