@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_image_win.c,v 1.7 2003/07/06 16:46:21 makeinu Exp $
+ * $Id: gimv_image_win.c,v 1.10 2004/02/29 12:35:31 makeinu Exp $
  */
 
 #include <stdlib.h>
@@ -770,10 +770,10 @@ create_toolbar (GimvImageWin *iw, GtkWidget *container)
    GtkWidget *toolbar, *button, *spinner, *iconw, *menu;
    GtkAdjustment *adj;
    const gchar *rotate_labels[] = {
+      N_("-90"),
       N_("0"),
       N_("90"),
       N_("180"),
-      N_("270"),
       NULL,
    };
    gfloat x_scale, y_scale;
@@ -913,7 +913,7 @@ create_toolbar (GimvImageWin *iw, GtkWidget *container)
 
    /* rotate button */
    menu = create_option_menu (rotate_labels,
-                              0, cb_rotate_menu, iw);
+                              1, cb_rotate_menu, iw);
    gtk_signal_connect (GTK_OBJECT (menu), "button_press_event",
                        GTK_SIGNAL_FUNC (cb_rotate_menu_button_press), iw);
    gtk_toolbar_append_widget (GTK_TOOLBAR (toolbar), menu,
@@ -1592,6 +1592,9 @@ cb_rotate_menu (GtkWidget *widget, GimvImageWin *iw)
    gint angle;
    g_return_if_fail (GTK_IS_MENU_ITEM (widget));
    angle = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (widget), "num"));
+   angle--;
+   if (angle < 0)
+      angle = 3;
    gimv_image_view_rotate_image (iw->iv, angle);
 }
 
@@ -1843,6 +1846,7 @@ cb_rendered (GimvImageView *iv, GimvImageWin *iw)
 {
    gfloat x_scale, y_scale;
    GimvImageViewOrientation rotate;
+   gint angle = 1;
 
    g_return_if_fail (iw);
    if (!g_list_find (ImageWinList, iw)) return;
@@ -1866,13 +1870,30 @@ cb_rendered (GimvImageView *iv, GimvImageWin *iw)
                    "orientation", &rotate,
                    NULL);
 
+   switch (rotate) {
+   case GIMV_IMAGE_VIEW_ROTATE_0:
+      angle = 1;
+      break;
+   case GIMV_IMAGE_VIEW_ROTATE_90:
+      angle = 2;
+      break;
+   case GIMV_IMAGE_VIEW_ROTATE_180:
+      angle = 3;
+      break;
+   case GIMV_IMAGE_VIEW_ROTATE_270:
+      angle = 0;
+      break;
+   default:
+      break;
+   }
+
    if (iw->button.xscale)
       gtk_spin_button_set_value (GTK_SPIN_BUTTON (iw->button.xscale), x_scale);
    if (iw->button.yscale)
       gtk_spin_button_set_value (GTK_SPIN_BUTTON (iw->button.yscale), y_scale);
    if (iw->button.rotate)
       gtk_option_menu_set_history (GTK_OPTION_MENU (iw->button.rotate),
-                                   rotate);
+                                   angle);
 }
 
 
@@ -2151,9 +2172,67 @@ gimv_image_win_fullscreen_hide (GimvImageWin *iw)
 }
 
 
+#if HAVE_X11_EXTENSIONS_XINERAMA_H
+#  include <X11/Xlib.h>
+#  include <X11/extensions/Xinerama.h>
+#  include <gdk/gdkx.h>
+#endif
+static gboolean
+get_fullscreen_geometory (GimvImageWin *iw, GdkRectangle *area)
+{
+   /*
+   int width, height;
+   int x, y;
+   */
+#ifdef HAVE_X11_EXTENSIONS_XINERAMA_H
+   Display *dpy;
+   XineramaScreenInfo *xinerama;
+   int i, count;
+#endif
+
+   g_return_val_if_fail (area, FALSE);
+
+   area->x = 0;
+   area->y = 0;
+   area->width = gdk_screen_width ();
+   area->height = gdk_screen_height ();
+
+#ifdef HAVE_X11_EXTENSIONS_XINERAMA_H
+   dpy = GDK_DISPLAY ();
+   if (!XineramaIsActive (dpy)) return FALSE;
+
+   xinerama = XineramaQueryScreens (dpy, &count);
+   for (i = 0; i < count; i++) {
+      if (area->x >= xinerama[i].x_org && area->y >= xinerama[i].y_org &&
+          area->x < xinerama[i].x_org + xinerama[i].width &&
+          area->y < xinerama[i].y_org + xinerama[i].height)
+      {
+         area->x = xinerama[i].x_org;
+         area->y = xinerama[i].y_org;
+         area->width = xinerama[i].width;
+         area->height = xinerama[i].height;
+         return TRUE;
+      }
+   }
+
+   area->x = xinerama[0].x_org;
+   area->y = xinerama[0].y_org;
+   area->width = xinerama[0].width;
+   area->height = xinerama[0].height;
+
+   return TRUE;
+#else
+   return FALSE;
+#endif
+}
+
+
 static void
 gimv_image_win_real_show_fullscreen (GimvImageWin *iw)
 { 
+   GdkRectangle area;
+   gboolean need_resize;
+
    g_return_if_fail (iw);
 
    iw->priv->flags |= GimvImageWinFullScreenFlag;
@@ -2198,13 +2277,19 @@ gimv_image_win_real_show_fullscreen (GimvImageWin *iw)
 
    gtk_widget_show (iw->fullscreen);
 
+   need_resize = get_fullscreen_geometory (iw, &area);
+
 #if (GTK_MAJOR_VERION >= 2) && (GTK_MINOR_VERSION >= 2)
    gdk_window_fullscreen (iw->fullscreen->window);
+   if (need_resize) {
+      gtk_window_move (iw->fullscreen, area.x, area.y);
+      gtk_window_resize (GTK_WINDOW (iw->fullscreen),
+                         area.width, area.height);
+   }
 #else /* (GTK_MAJOR_VERION >= 2) && (GTK_MINOR_VERSION >= 2) */
-   gtk_widget_set_uposition (iw->fullscreen, 0, 0);
+   gtk_widget_set_uposition (iw->fullscreen, area.x, area.y);
    gtk_window_set_default_size (GTK_WINDOW (iw->fullscreen),
-                                gdk_screen_width (),
-                                gdk_screen_height ());
+                                area.width, area.height);
 #endif /* (GTK_MAJOR_VERION >= 2) && (GTK_MINOR_VERSION >= 2) */
 
    gimv_image_view_set_fullscreen (iw->iv, GTK_WINDOW (iw->fullscreen));
