@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_plugin.c,v 1.1.2.7 2003/06/09 12:46:11 makeinu Exp $
+ * $Id: gimv_plugin.c,v 1.4 2003/07/05 16:41:11 makeinu Exp $
  */
 
 #include <stdio.h>
@@ -32,12 +32,6 @@
 #include "gimv_plugin.h"
 #include "prefs.h"
 
-#include "fr-archive.h"
-#include "image_loader.h"
-#include "image_saver.h"
-#include "gimv_io.h"
-#include "thumbnail_support.h"
-
 #define PLUGIN_RC_DIR "pluginrc"
 
 typedef struct PluginTypeEntry_Tag
@@ -55,22 +49,22 @@ extern gboolean type##_plugin_regist (const gchar *plugin_name, \
                                       gpointer     impl, \
                                       gint         size)
 
-PLUGIN_REGIST_FUNC(image_loader);
-PLUGIN_REGIST_FUNC(image_saver);
+PLUGIN_REGIST_FUNC(gimv_image_loader);
+PLUGIN_REGIST_FUNC(gimv_image_saver);
 PLUGIN_REGIST_FUNC(gimv_io);
 PLUGIN_REGIST_FUNC(fr_archive);
-PLUGIN_REGIST_FUNC(thumbsupport);
+PLUGIN_REGIST_FUNC(gimv_thumb_cache);
 PLUGIN_REGIST_FUNC(gimv_image_view);
 PLUGIN_REGIST_FUNC(thumbview);
 
 static PluginTypeEntry plugin_types[] = {
-   {GIMV_PLUGIN_IMAGE_LOADER,      image_loader_plugin_regist,    NULL, "image_loader",   NULL},
-   {GIMV_PLUGIN_IMAGE_SAVER,       image_saver_plugin_regist,     NULL, "image_saver",    NULL},
-   {GIMV_PLUGIN_IO_STREAMER,       gimv_io_plugin_regist,         NULL, "io_stream",      NULL},
-   {GIMV_PLUGIN_EXT_ARCHIVER,      fr_archive_plugin_regist,      NULL, "ext_archiver",   NULL},
-   {GIMV_PLUGIN_THUMB_CACHE,       thumbsupport_plugin_regist,    NULL, "thumbnail",      NULL},
-   {GIMV_PLUGIN_IMAGEVIEW_EMBEDER, gimv_image_view_plugin_regist, NULL, "image_view",     NULL},
-   {GIMV_PLUGIN_THUMBVIEW_EMBEDER, thumbview_plugin_regist,       NULL, "thumbnail_view", NULL},
+   {GIMV_PLUGIN_IMAGE_LOADER,      gimv_image_loader_plugin_regist, NULL, "image_loader",   NULL},
+   {GIMV_PLUGIN_IMAGE_SAVER,       gimv_image_saver_plugin_regist,  NULL, "image_saver",    NULL},
+   {GIMV_PLUGIN_IO_STREAMER,       gimv_io_plugin_regist,           NULL, "io_stream",      NULL},
+   {GIMV_PLUGIN_EXT_ARCHIVER,      fr_archive_plugin_regist,        NULL, "ext_archiver",   NULL},
+   {GIMV_PLUGIN_THUMB_CACHE,       gimv_thumb_cache_plugin_regist,  NULL, "thumbnail",      NULL},
+   {GIMV_PLUGIN_IMAGEVIEW_EMBEDER, gimv_image_view_plugin_regist,   NULL, "image_view",     NULL},
+   {GIMV_PLUGIN_THUMBVIEW_EMBEDER, thumbview_plugin_regist,         NULL, "thumbnail_view", NULL},
 };
 static gint plugin_types_num = sizeof (plugin_types) / sizeof (PluginTypeEntry);
 
