@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_prefs_win.c,v 1.1.2.4 2003/05/15 13:58:16 makeinu Exp $
+ * $Id: gimv_prefs_win.c,v 1.4 2003/07/19 12:42:13 makeinu Exp $
  */
 
 #include "gimv_prefs_win.h"
@@ -30,7 +30,7 @@
 
 #include "gimv_hpaned.h"
 #include "gtk2-compat.h"
-#include "gimv_cellrendererpixmap.h"
+#include "gimv_cell_pixmap.h"
 #include "gimv_icon_stock.h"
 #include "help.h"
 #include "prefs.h"
@@ -823,6 +823,7 @@ gimv_prefs_win_open (const gchar *path, GtkWindow *parent)
    gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook), TRUE);
    /* gtk_notebook_popup_enable (GTK_NOTEBOOK (notebook)); */
    gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
+   gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
    gtk_widget_show (notebook);
 
    /* scrolled window */
