@@ -28,7 +28,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: gtk_prop.c,v 1.9.2.3 2003/05/16 14:48:46 makeinu Exp $
+ * $Id: gtk_prop.c,v 1.11 2003/06/18 09:26:56 makeinu Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -526,7 +526,7 @@ dlg_prop (const gchar *path, fprop * prop, gint flags)
 
 
 gboolean
-dlg_prop_from_image_info (ImageInfo *info, gint flags)
+dlg_prop_from_image_info (GimvImageInfo *info, gint flags)
 {
    fprop prop;
    gint rc = DLG_RC_CANCEL;
@@ -535,7 +535,7 @@ dlg_prop_from_image_info (ImageInfo *info, gint flags)
 
    g_return_val_if_fail (info, FALSE);
 
-   path = image_info_get_path (info);
+   path = gimv_image_info_get_path (info);
 
    prop.mode  = info->st.st_mode;
    prop.uid   = info->st.st_uid;
