@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gtkutils.c,v 1.22.2.8 2003/06/09 12:46:11 makeinu Exp $
+ * $Id: gtkutils.c,v 1.26 2003/06/18 09:26:56 makeinu Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -347,7 +347,7 @@ gtkutil_confirm_dialog (const gchar *title, const gchar *message,
 
 typedef struct OverWriteDialog_Tag
 {
-   ImageInfo *info1, *info2;
+   GimvImageInfo *info1, *info2;
    GtkWidget *window, *iv1, *iv2, *show_compare_button, *compare_area, *entry;
    gchar *new_path;
    gint new_path_len;
@@ -388,7 +388,7 @@ overwrite_confirm_rename (OverWriteDialog *dialog)
    if (!filename_internal && *filename_internal) return;
    g_return_if_fail (dialog->new_path && dialog->new_path_len > 0);
 
-   dirname = g_dirname (image_info_get_path (dialog->info1));
+   dirname = g_dirname (gimv_image_info_get_path (dialog->info1));
    g_return_if_fail (dirname);
    if (!*dirname) g_free (dirname);
    g_return_if_fail (*dirname);
@@ -452,8 +452,8 @@ gtkutil_overwrite_confirm_dialog (const gchar *title, const gchar *message,
    gchar *filename;
 
    dialog.retval = CONFIRM_NO;
-   dialog.info1 = image_info_get (dest_file);
-   dialog.info2 = image_info_get (src_file);
+   dialog.info1 = gimv_image_info_get (dest_file);
+   dialog.info2 = gimv_image_info_get (src_file);
    dialog.new_path = new_path;
    dialog.new_path_len = new_path_len;
 
@@ -649,8 +649,8 @@ gtkutil_overwrite_confirm_dialog (const gchar *title, const gchar *message,
    gtk_grab_remove (window);
    gtk_widget_destroy (window);
 
-   if (dialog.info1) image_info_unref (dialog.info1);
-   if (dialog.info2) image_info_unref (dialog.info2);
+   if (dialog.info1) gimv_image_info_unref (dialog.info1);
+   if (dialog.info2) gimv_image_info_unref (dialog.info2);
 
    return dialog.retval;
 }
