@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: help.c,v 1.33.2.8 2003/05/15 13:58:16 makeinu Exp $
+ * $Id: help.c,v 1.41 2003/07/24 15:33:03 makeinu Exp $
  */
 
 #include "gimageview.h"
@@ -113,6 +113,8 @@ N_("Main Program :\n"
    "    matsu\n"
    "    Shlomi Fish\n"
    "    Jin Suh\n"
+   "    sheepman\n"
+   "    MINAMI Hirokazu\n"
    "    And all GImageView users");
 
 static gchar *system_info = NULL;
@@ -633,7 +635,7 @@ gimvhelp_create_info_widget (void)
    scrolledwin = gtk_scrolled_window_new (NULL, NULL);
    info_win.scrolled_win = scrolledwin;
    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(scrolledwin),
-                                   GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
+                                   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
    gtk_box_pack_start (GTK_BOX (vbox),
                        scrolledwin, TRUE, TRUE, 0);
    gtk_container_set_border_width (GTK_CONTAINER (scrolledwin), 5);
@@ -695,7 +697,8 @@ gimvhelp_create_info_widget (void)
 
 
 void
-gimvhelp_open_info_window (void) {
+gimvhelp_open_info_window (void)
+{
    GtkWidget *widget, *window, *button;
    gchar buf[BUF_SIZE];
 
@@ -707,7 +710,7 @@ gimvhelp_open_info_window (void) {
    g_snprintf (buf, BUF_SIZE, _("About %s"), GIMV_PROG_NAME);
    gtk_window_set_wmclass(GTK_WINDOW(window), "about", "GImageView");
    gtk_window_set_title (GTK_WINDOW (window), buf); 
-   gtk_window_set_default_size (GTK_WINDOW (window), 430, 400);
+   gtk_window_set_default_size (GTK_WINDOW (window), 500, 400);
 
    /* main content */
    widget = gimvhelp_create_info_widget ();
