@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 3; indent-tabs-mode: nil; c-basic-offset: 3 -*- */
+
 /*
  * GImageView
  * Copyright (C) 2001 Takuro Ashie
@@ -15,12 +17,17 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ * $Id: help.h,v 1.4 2002/10/23 21:42:24 makeinu Exp $
  */
 
 #ifndef __HELP_H__
 #define __HELP_H__
 
-GtkWidget *gimvhelp_create_menu (GtkWidget *window);
-void       gimvhelp_info        ();
+#include <gtk/gtk.h>
+
+GtkWidget *gimvhelp_create_menu        (GtkWidget *window);
+GtkWidget *gimvhelp_create_info_widget (void);
+void       gimvhelp_open_info_window   (void);
 
 #endif /* __HELP_H__ */
