@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs.c,v 1.71.2.16 2003/06/09 12:46:12 makeinu Exp $
+ * $Id: prefs.c,v 1.76 2003/06/15 16:14:53 makeinu Exp $
  */
 
 #include <stdio.h>
@@ -30,9 +30,9 @@
 
 #include "gimv_icon_stock.h"
 #include "gimv_image_win.h"
-#include "prefs.h"
 #include "gimv_plugin.h"
-#include "thumbnail_window.h"
+#include "gimv_thumb_win.h"
+#include "prefs.h"
 
 Config conf;
 KeyConf akey;
