@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs_ui_etc.c,v 1.2.2.3 2003/05/16 14:48:46 makeinu Exp $
+ * $Id: prefs_ui_etc.c,v 1.5 2003/07/06 16:46:21 makeinu Exp $
  */
 
 #include <string.h>
@@ -26,7 +26,7 @@
 #include "gimageview.h"
 
 #include "charset.h"
-#include "comment.h"
+#include "gimv_comment.h"
 #include "gimv_elist.h"
 #include "gtk2-compat.h"
 #include "gtkutils.h"
@@ -34,7 +34,7 @@
 #include "prefs_ui_etc.h"
 #include "gimv_prefs_ui_utils.h"
 #include "gimv_prefs_win.h"
-#include "thumbnail_support.h"
+#include "gimv_thumb_cache.h"
 #include "utils.h"
 
 
@@ -80,7 +80,7 @@ set_sensitive_cache_write (void)
    label = gtk_object_get_data (GTK_OBJECT (menu_item), "label");
    if (!label) return;
 
-   if (thumbsupport_has_save_prefs (label)) {
+   if (gimv_thumb_cache_has_save_prefs (label)) {
       gtk_widget_set_sensitive (button, TRUE);
    } else {
       gtk_widget_set_sensitive (button, FALSE);
@@ -123,7 +123,7 @@ cb_cache_write_prefs_button_pressed (GtkWidget *option_menu)
    label = gtk_object_get_data (GTK_OBJECT (menu_item), "label");
    if (!label) return;
 
-   widget = thumbsupport_get_save_prefs (label, NULL);
+   widget = gimv_thumb_cache_get_save_prefs (label, NULL);
    if (!widget) return;
 
    /* create dialog window */
@@ -206,7 +206,7 @@ check_duplicate_comment_key (const gchar *key, gint this_row)
    g_return_val_if_fail (key && *key, FALSE);
 
    for (row = 0; row < rows; row++) {
-      CommentDataEntry *entry;
+      GimvCommentDataEntry *entry;
 
       if (row == this_row) continue;
 
@@ -231,15 +231,15 @@ set_default_comment_key_list (void)
    gchar *text[16];
    gint row;
 
-   for (list = comment_get_data_entry_list ();
+   for (list = gimv_comment_get_data_entry_list ();
         list;
         list = g_list_next (list))
    {
-      CommentDataEntry *dentry = list->data, *rowdata;
+      GimvCommentDataEntry *dentry = list->data, *rowdata;
 
       if (!dentry) continue;
 
-      rowdata = comment_data_entry_dup (dentry);
+      rowdata = gimv_comment_data_entry_dup (dentry);
 
       text[0] = dentry->key;
       text[1] = _(dentry->display_name);
@@ -254,9 +254,9 @@ set_default_comment_key_list (void)
 
       if (row >= 0) {
          gimv_elist_set_row_data_full (editlist, row, rowdata,
-                                          (GtkDestroyNotify) comment_data_entry_delete);
+                                       (GtkDestroyNotify) gimv_comment_data_entry_delete);
       } else {
-         comment_data_entry_delete (rowdata);
+         gimv_comment_data_entry_delete (rowdata);
       }
    }
 }
@@ -277,7 +277,7 @@ cb_comment_editlist_updated (GimvEList *editlist)
    string = g_strdup ("");
 
    for (row = 0; row < rows; row++) {
-      CommentDataEntry *entry;
+      GimvCommentDataEntry *entry;
       gchar *dname_internal;
 
       entry = gimv_elist_get_row_data (editlist, row);     
@@ -316,7 +316,7 @@ cb_comment_editlist_confirm (GimvEList *editlist,
    GtkWidget *t_auto = prefs_win.comment_auto_toggle;
    GtkWidget *key_entry  = prefs_win.comment_key_entry;
    GtkWidget *name_entry = prefs_win.comment_name_entry;
-   CommentDataEntry *entry = NULL;
+   GimvCommentDataEntry *entry = NULL;
    const gchar *key, *name;
    gchar message[BUF_SIZE];
    gboolean duplicate = FALSE;
@@ -404,7 +404,7 @@ cb_editlist_deftype_get_data (GimvEList *editlist,
                               GtkWidget *widget,
                               gpointer coldata)
 {
-   CommentDataEntry *entry;
+   GimvCommentDataEntry *entry;
    gint selected;
 
    g_return_val_if_fail (GIMV_IS_ELIST (editlist), NULL);
@@ -436,7 +436,7 @@ cb_editlist_get_row_data (GimvEList *editlist,
    GtkToggleButton *t_ins  = GTK_TOGGLE_BUTTON (prefs_win.comment_status_toggle);
    GtkToggleButton *t_auto = GTK_TOGGLE_BUTTON (prefs_win.comment_auto_toggle);
    GtkToggleButton *t_disp = GTK_TOGGLE_BUTTON (prefs_win.comment_disp_toggle);
-   CommentDataEntry *entry;
+   GimvCommentDataEntry *entry;
    gint row = gimv_elist_get_selected_row (editlist);
    const gchar *key, *name;
 
@@ -446,7 +446,7 @@ cb_editlist_get_row_data (GimvEList *editlist,
    name = gtk_entry_get_text (entry2);
 
    if (type == GIMV_ELIST_ACTION_ADD) {
-      entry = g_new0 (CommentDataEntry, 1);
+      entry = g_new0 (GimvCommentDataEntry, 1);
       entry->key          = NULL;
       entry->display_name = NULL;
       entry->value        = NULL;
@@ -478,7 +478,7 @@ cb_editlist_get_row_data (GimvEList *editlist,
    if (type == GIMV_ELIST_ACTION_ADD) {
       g_return_val_if_fail (rowdata && destroy_fn, FALSE);
       *rowdata = entry;
-      *destroy_fn = (GtkDestroyNotify) comment_data_entry_delete;
+      *destroy_fn = (GtkDestroyNotify) gimv_comment_data_entry_delete;
       return TRUE;
    } else {
       return FALSE;
@@ -514,7 +514,7 @@ prefs_cache_page (void)
    main_vbox = gtk_vbox_new (FALSE, 0);
    gtk_container_set_border_width(GTK_CONTAINER(main_vbox), 5);
 
-   list = thumbsupport_get_loader_list ();
+   list = gimv_thumb_cache_get_loader_list ();
    frame = gimv_prefs_ui_double_clist (_("Cache reading"),
                                        _("Available cache type"),
                                        _("Cache type to use"),
@@ -532,7 +532,7 @@ prefs_cache_page (void)
    gimv_prefs_ui_create_frame(_("Cache writing"), frame, vbox, main_vbox, FALSE);
 
    /* Cache write type menu */
-   list = node = thumbsupport_get_saver_list ();
+   list = node = gimv_thumb_cache_get_saver_list ();
    /* list = node = g_list_prepend (list, "NONE"); */
 
    hbox = gtk_hbox_new (FALSE, 0);
@@ -965,7 +965,7 @@ prefs_dnd_page (void)
 gboolean
 prefs_comment_apply (GimvPrefsWinAction action)
 {
-   comment_update_data_entry_list ();
+   gimv_comment_update_data_entry_list ();
    return FALSE;
 }
 
