@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs_ui_thumbwin.c,v 1.3.2.9 2003/06/09 12:46:13 makeinu Exp $
+ * $Id: prefs_ui_thumbwin.c,v 1.6 2003/06/18 09:26:56 makeinu Exp $
  */
 
 #include <string.h>
@@ -26,14 +26,14 @@
 #include "gimageview.h"
 
 #include "dirview.h"
+#include "gimv_prefs_ui_utils.h"
+#include "gimv_prefs_win.h"
+#include "gimv_thumb_win.h"
 #include "gtkutils.h"
 #include "gtk2-compat.h"
 #include "menu.h"
 #include "prefs.h"
-#include "gimv_prefs_ui_utils.h"
-#include "gimv_prefs_win.h"
 #include "thumbnail_view.h"
-#include "thumbnail_window.h"
 
 
 typedef struct PrefsWin_Tag {
@@ -782,7 +782,8 @@ prefs_thumbview_page (void)
    gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, TRUE, 0);
 
    adj = (GtkAdjustment *) gtk_adjustment_new (conf.thumbwin_thumb_size,
-                                               MIN_THUMB_SIZE, MAX_THUMB_SIZE,
+                                               GIMV_THUMB_WIN_MIN_THUMB_SIZE,
+                                               GIMV_THUMB_WIN_MAX_THUMB_SIZE,
                                                1.0, 5.0, 0.0);
    spinner = gtkutil_create_spin_button (adj);
    prefs_win.thumbview_thumb_size = spinner;
@@ -1115,7 +1116,7 @@ prefs_preview_mouse_page (void)
 gboolean
 prefs_ui_thumbwin_apply (GimvPrefsWinAction action)
 {
-   ThumbWindow *tw;
+   GimvThumbWin *tw;
    GList *node;
    Config *dest;
 
@@ -1129,7 +1130,7 @@ prefs_ui_thumbwin_apply (GimvPrefsWinAction action)
       break;
    }
 
-   for (node = thumbwin_get_list(); node; node = g_list_next (node)) {
+   for (node = gimv_thumb_win_get_list(); node; node = g_list_next (node)) {
       tw = node->data;
       gtk_toolbar_set_style (GTK_TOOLBAR(tw->toolbar),
                              dest->thumbwin_toolbar_style);
@@ -1185,8 +1186,8 @@ prefs_ui_dirview_apply (GimvPrefsWinAction action)
 #ifndef ENABLE_TREEVIEW
    {
       GList *node;
-      for (node = thumbwin_get_list(); node; node = g_list_next (node)) {
-         ThumbWindow *tw = node->data;
+      for (node = gimv_thumb_win_get_list(); node; node = g_list_next (node)) {
+         GimvThumbWin *tw = node->data;
          if (tw->dv) {
             gtk_ctree_set_line_style (GTK_CTREE (tw->dv->dirtree),
                                       dest->dirview_line_style);
@@ -1204,7 +1205,7 @@ prefs_ui_dirview_apply (GimvPrefsWinAction action)
 gboolean
 prefs_ui_preview_apply (GimvPrefsWinAction action)
 {
-   ThumbWindow *tw;
+   GimvThumbWin *tw;
    GList *node;
    Config *dest;
 
@@ -1218,7 +1219,7 @@ prefs_ui_preview_apply (GimvPrefsWinAction action)
       break;
    }
 
-   for (node = thumbwin_get_list(); node; node = g_list_next (node)) {
+   for (node = gimv_thumb_win_get_list(); node; node = g_list_next (node)) {
       tw = node->data;
 
       if (tw->iv) {
