@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: thumbnail_view_album.c,v 1.1.2.9 2003/05/16 14:48:46 makeinu Exp $
+ * $Id: thumbnail_view_album.c,v 1.4 2003/06/18 09:26:56 makeinu Exp $
  */
 
 #include <string.h>
@@ -26,14 +26,47 @@
 #include "gimageview.h"
 
 #include "dnd.h"
-#include "gtkutils.h"
-#include "prefs.h"
-#include "thumbnail.h"
-#include "thumbnail_view.h"
-#include "thumbnail_view_album.h"
-#include "thumbnail_window.h"
+#include "gimv_thumb.h"
+#include "gimv_thumb_win.h"
 #include "gimv_zalbum.h"
 #include "gtk2-compat.h"
+#include "gtkutils.h"
+#include "prefs.h"
+#include "thumbnail_view.h"
+
+
+#define THUMBALBUM_LABEL  "Album"
+#define THUMBALBUM2_LABEL "Album 2"
+#define THUMBALBUM3_LABEL "Album 3"
+
+
+static GList     *thumbalbum_append_thumb_frames      (ThumbView      *tv,
+                                                       GList          *start,
+                                                       gchar          *dest_mode);
+static GtkWidget *thumbalbum_add_thumbnail            (GimvThumb      *thumb,
+                                                       gchar          *dest_mode,
+                                                       ThumbLoadType   type);
+static void       thumbalbum_redraw                   (ThumbView      *tv,
+                                                       gchar          *mode,
+                                                       GtkWidget      *scroll_win,
+                                                       GList         **loadlist);
+#if 0
+static GtkWidget *thumbalbum_resize                   (ThumbView      *tv);
+#endif
+static gboolean   thumbalbum_refresh_thumbnail        (GimvThumb      *thumb,
+                                                       ThumbLoadType   type);
+static void       thumbalbum_adjust                   (ThumbView      *tv,
+                                                       GimvThumb      *thumb);
+static GtkWidget *thumbalbum_create                   (ThumbView      *tv,
+                                                       gchar          *dest_mode);
+static void       thumbalbum_remove_thumbview_data    (ThumbView      *tv);
+static gboolean   thumbalbum_set_selection            (GimvThumb      *thumb,
+                                                       gboolean        select);
+static void       thumbalbum_set_focus                (ThumbView      *tv,
+                                                       GimvThumb      *thumb);
+static GimvThumb *thumbalbum_get_focus                (ThumbView      *tv);
+static gboolean   thumbalbum_thumbnail_is_in_viewport (ThumbView      *tv,
+                                                       GimvThumb      *thumb);
 
 ThumbViewPlugin thumbalbum_modes[] =
 {
@@ -102,7 +135,7 @@ typedef struct ThumbViewData_Tag
 
 /* defined in thumbview_list.c */
 void   album_create_title_idx_list  (void);
-gchar *album_create_label_str       (Thumbnail *thumb);
+gchar *album_create_label_str       (GimvThumb *thumb);
 
 
 /******************************************************************************
@@ -115,7 +148,7 @@ cb_album_button_press (GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
    ThumbView *tv = data;
    gint row;
-   Thumbnail *thumb;
+   GimvThumb *thumb;
    gboolean retval = event->button == 3 ? TRUE : FALSE;
 
    g_return_val_if_fail (tv, retval);
@@ -124,7 +157,7 @@ cb_album_button_press (GtkWidget *widget, GdkEventButton *event, gpointer data)
    if (row < 0) {
       gtk_drag_source_unset (widget);
       gtk_object_set_data (GTK_OBJECT (widget), "drag-unset", GINT_TO_POINTER (1));
-      thumbwin_notebook_drag_src_unset (tv->thumb_window);   /* FIXME!! */
+      gimv_thumb_win_notebook_drag_src_unset (tv->thumb_window);   /* FIXME!! */
       return retval;
    }
 
@@ -141,7 +174,7 @@ static gboolean
 cb_album_button_release (GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
    ThumbView *tv = data;
-   Thumbnail *thumb;
+   GimvThumb *thumb;
    gint row;
    gpointer dnd_unset;
    gboolean retval;
@@ -155,7 +188,7 @@ cb_album_button_release (GtkWidget *widget, GdkEventButton *event, gpointer data
 
    row = gimv_zlist_cell_index_from_xy (GIMV_ZLIST (widget), event->x, event->y);
    if (row < 0) {
-      thumbwin_notebook_drag_src_reset (tv->thumb_window);   /* FIXME!! */
+      gimv_thumb_win_notebook_drag_src_reset (tv->thumb_window);   /* FIXME!! */
       return FALSE;
    }
 
@@ -174,7 +207,7 @@ cb_album_button_release (GtkWidget *widget, GdkEventButton *event, gpointer data
 static void
 cb_select_cell (GimvZAlbum *album, gint idx, ThumbView *tv)
 {
-   Thumbnail *thumb;
+   GimvThumb *thumb;
 
    g_return_if_fail (GIMV_IS_ZALBUM (album));
    g_return_if_fail (tv);
@@ -188,7 +221,7 @@ cb_select_cell (GimvZAlbum *album, gint idx, ThumbView *tv)
 static void
 cb_unselect_cell (GimvZAlbum *album, gint idx, ThumbView *tv)
 {
-   Thumbnail *thumb;
+   GimvThumb *thumb;
 
    g_return_if_fail (GIMV_IS_ZALBUM (album));
    g_return_if_fail (tv);
@@ -205,7 +238,7 @@ cb_album_key_press (GtkWidget *widget,
                     GdkEventKey *event,
                     ThumbView *tv)
 {
-   Thumbnail *thumb = NULL;
+   GimvThumb *thumb = NULL;
 
    g_return_val_if_fail (tv, FALSE);
 
@@ -278,7 +311,7 @@ thumbalbum_new (ThumbView *tv)
 
 
 static gboolean
-thumbalbum_append_thumb_frame (ThumbView *tv, Thumbnail *thumb, gchar *dest_mode)
+thumbalbum_append_thumb_frame (ThumbView *tv, GimvThumb *thumb, gchar *dest_mode)
 {
    ThumbViewData *tv_data;
    const gchar *filename;
@@ -293,7 +326,7 @@ thumbalbum_append_thumb_frame (ThumbView *tv, Thumbnail *thumb, gchar *dest_mode
    tv_data = g_hash_table_lookup (tv->disp_mode_data, THUMBALBUM_LABEL);
    g_return_val_if_fail (tv_data, FALSE);
 
-   filename = g_basename(image_info_get_path (thumb->info));
+   filename = g_basename(gimv_image_info_get_path (thumb->info));
 
    if (!strcmp (dest_mode, THUMBALBUM3_LABEL)) {
       label = album_create_label_str (thumb);
@@ -309,9 +342,9 @@ thumbalbum_append_thumb_frame (ThumbView *tv, Thumbnail *thumb, gchar *dest_mode
    thumbalbum_set_selection (thumb, thumb->selected);
 
    if (!strcmp (THUMBALBUM2_LABEL, dest_mode)) {
-      thumbnail_get_icon (thumb, &pixmap, &mask);
+      gimv_thumb_get_icon (thumb, &pixmap, &mask);
    } else {
-      thumbnail_get_thumb (thumb, &pixmap, &mask);
+      gimv_thumb_get_thumb (thumb, &pixmap, &mask);
    }
    if (!pixmap) return FALSE;
 
@@ -326,7 +359,7 @@ thumbalbum_append_thumb_frame (ThumbView *tv, Thumbnail *thumb, gchar *dest_mode
  *   public functions.
  *
  ******************************************************************************/
-void
+static void
 thumbalbum_remove_thumbview_data (ThumbView *tv)
 {
    ThumbViewData *tv_data;
@@ -341,7 +374,7 @@ thumbalbum_remove_thumbview_data (ThumbView *tv)
 }
 
 
-GList *
+static GList *
 thumbalbum_append_thumb_frames (ThumbView *tv,
                                  GList *start,
                                  gchar *dest_mode)
@@ -353,7 +386,7 @@ thumbalbum_append_thumb_frames (ThumbView *tv,
 
    node = start;
    while (node) {
-      Thumbnail  *thumb = node->data;
+      GimvThumb  *thumb = node->data;
 
       thumb_loaded = thumbalbum_append_thumb_frame (tv, thumb, dest_mode);
       if (!thumb_loaded)
@@ -366,8 +399,8 @@ thumbalbum_append_thumb_frames (ThumbView *tv,
 }
 
 
-GtkWidget *
-thumbalbum_add_thumbnail (Thumbnail *thumb,
+static GtkWidget *
+thumbalbum_add_thumbnail (GimvThumb *thumb,
                            gchar *dest_mode,
                            ThumbLoadType type)
 {
@@ -391,9 +424,9 @@ thumbalbum_add_thumbnail (Thumbnail *thumb,
 
    /* set thumbnail */
    if (!strcmp (THUMBALBUM2_LABEL, dest_mode)) {
-      thumbnail_get_icon (thumb, &pixmap, &mask);
+      gimv_thumb_get_icon (thumb, &pixmap, &mask);
    } else {
-      thumbnail_get_thumb (thumb, &pixmap, &mask);
+      gimv_thumb_get_thumb (thumb, &pixmap, &mask);
    }
    if (pixmap)
       gimv_zalbum_set_pixmap (GIMV_ZALBUM (tv_data->album), pos, pixmap, mask);
@@ -402,7 +435,7 @@ thumbalbum_add_thumbnail (Thumbnail *thumb,
 }
 
 
-void
+static void
 thumbalbum_redraw (ThumbView *tv, gchar *dest_mode,
                     GtkWidget *scroll_win, GList **loadlist)
 {
@@ -431,14 +464,14 @@ thumbalbum_redraw (ThumbView *tv, gchar *dest_mode,
    *loadlist = NULL;
    node = tv->thumblist;
    while (node) {
-      Thumbnail *thumb = node->data;
+      GimvThumb *thumb = node->data;
       GdkPixmap *pixmap = NULL;
       GdkBitmap *mask = NULL;
 
       if (!strcmp (THUMBALBUM2_LABEL, dest_mode)) {
-         thumbnail_get_icon (thumb, &pixmap, &mask);
+         gimv_thumb_get_icon (thumb, &pixmap, &mask);
       } else {
-         thumbnail_get_thumb (thumb, &pixmap, &mask);
+         gimv_thumb_get_thumb (thumb, &pixmap, &mask);
       }
       if (!pixmap)
          *loadlist = g_list_append (*loadlist, thumb);
@@ -448,7 +481,8 @@ thumbalbum_redraw (ThumbView *tv, gchar *dest_mode,
 }
 
 
-GtkWidget *
+#if 0
+static GtkWidget *
 thumbalbum_resize (ThumbView *tv)
 {
    ThumbViewData *tv_data;
@@ -466,10 +500,11 @@ thumbalbum_resize (ThumbView *tv)
 
    return tv_data->album;
 }
+#endif
 
 
 gboolean
-thumbalbum_refresh_thumbnail (Thumbnail *thumb, ThumbLoadType type)
+thumbalbum_refresh_thumbnail (GimvThumb *thumb, ThumbLoadType type)
 {
    GtkWidget *widget;
    ThumbView *tv;
@@ -488,8 +523,8 @@ thumbalbum_refresh_thumbnail (Thumbnail *thumb, ThumbLoadType type)
 }
 
 
-gboolean
-thumbalbum_set_selection (Thumbnail *thumb, gboolean select)
+static gboolean
+thumbalbum_set_selection (GimvThumb *thumb, gboolean select)
 {
    ThumbView *tv;
    ThumbViewData *tv_data;
@@ -520,8 +555,8 @@ thumbalbum_set_selection (Thumbnail *thumb, gboolean select)
 }
 
 
-void
-thumbalbum_set_focus (ThumbView *tv, Thumbnail *thumb)
+static void
+thumbalbum_set_focus (ThumbView *tv, GimvThumb *thumb)
 {
    ThumbViewData *tv_data;
    gint pos;
@@ -540,7 +575,7 @@ thumbalbum_set_focus (ThumbView *tv, Thumbnail *thumb)
 }
 
 
-Thumbnail *
+static GimvThumb *
 thumbalbum_get_focus (ThumbView *tv)
 {
    ThumbViewData *tv_data;
@@ -563,8 +598,8 @@ thumbalbum_get_focus (ThumbView *tv)
 }
 
 
-gboolean
-thumbalbum_thumbnail_is_in_viewport (ThumbView *tv, Thumbnail *thumb)
+static gboolean
+thumbalbum_thumbnail_is_in_viewport (ThumbView *tv, GimvThumb *thumb)
 {
    ThumbViewData *tv_data;
    GList *node;
@@ -596,8 +631,8 @@ thumbalbum_thumbnail_is_in_viewport (ThumbView *tv, Thumbnail *thumb)
 }
 
 
-void
-thumbalbum_adjust (ThumbView *tv, Thumbnail *thumb)
+static void
+thumbalbum_adjust (ThumbView *tv, GimvThumb *thumb)
 {
    ThumbViewData *tv_data;
    GList *node;
@@ -621,7 +656,7 @@ thumbalbum_adjust (ThumbView *tv, Thumbnail *thumb)
 }
 
 
-GtkWidget *
+static GtkWidget *
 thumbalbum_create (ThumbView *tv, gchar *dest_mode)
 {
    ThumbViewData *tv_data;
@@ -730,7 +765,7 @@ thumbalbum_create (ThumbView *tv, gchar *dest_mode)
 static gboolean show_data_title = FALSE;
 static const gchar *data_order = DEFAULT_DATA_ORDER;
 static gchar *
-label_filename (Thumbnail *thumb)
+label_filename (GimvThumb *thumb)
 {
    const gchar *filename;
    gchar *tmpstr;
@@ -738,7 +773,7 @@ label_filename (Thumbnail *thumb)
 
    g_return_val_if_fail (thumb, NULL);
 
-   filename = g_basename(image_info_get_path (thumb->info));
+   filename = g_basename(gimv_image_info_get_path (thumb->info));
 
    tmpstr = gimv_filename_to_internal (filename);
 
@@ -754,7 +789,7 @@ label_filename (Thumbnail *thumb)
 
 
 static gchar *
-label_size (Thumbnail *thumb)
+label_size (GimvThumb *thumb)
 {
    gchar *size_str, buf[BUF_SIZE];
 
@@ -772,7 +807,7 @@ label_size (Thumbnail *thumb)
 
 
 static gchar *
-label_mtime (Thumbnail *thumb)
+label_mtime (GimvThumb *thumb)
 {
    gchar *time_str, *str;
 
@@ -790,14 +825,14 @@ label_mtime (Thumbnail *thumb)
 
 
 static gchar *
-label_image_type (Thumbnail *thumb)
+label_image_type (GimvThumb *thumb)
 {
    gchar buf[BUF_SIZE];
    const gchar *filename;
 
    g_return_val_if_fail (thumb, NULL);
 
-   filename = image_info_get_path (thumb->info);
+   filename = gimv_image_info_get_path (thumb->info);
    if (show_data_title)
       g_snprintf (buf, BUF_SIZE, _("Type: %s"),
                   gimv_image_detect_type_by_ext (filename));
@@ -806,7 +841,7 @@ label_image_type (Thumbnail *thumb)
 
    return g_strdup (buf);
 }
-typedef gchar *(*AlbumDataStr) (Thumbnail *thumb);
+typedef gchar *(*AlbumDataStr) (GimvThumb *thumb);
 typedef struct _AlbumDisplayData
 {
    gchar             *title;
@@ -825,7 +860,7 @@ static AlbumDisplayData album_display_data [] =
 static gint album_display_data_num
 = sizeof (album_display_data) / sizeof (AlbumDisplayData);
 gchar *
-album_create_label_str (Thumbnail *thumb)
+album_create_label_str (GimvThumb *thumb)
 {
    GList *node;
    gchar *label;
